# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/vision/Faces.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.vision import Face_pb2 as rst_dot_vision_dot_Face__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/vision/Faces.proto',
  package='rst.vision',
  syntax='proto2',
  serialized_pb=_b('\n\x16rst/vision/Faces.proto\x12\nrst.vision\x1a\x15rst/vision/Face.proto\"G\n\x05\x46\x61\x63\x65s\x12\x1f\n\x05\x66\x61\x63\x65s\x18\x01 \x03(\x0b\x32\x10.rst.vision.Face\x12\r\n\x05width\x18\x02 \x02(\r\x12\x0e\n\x06height\x18\x03 \x02(\rB\x0b\x42\tFacesType')
  ,
  dependencies=[rst_dot_vision_dot_Face__pb2.DESCRIPTOR,])




_FACES = _descriptor.Descriptor(
  name='Faces',
  full_name='rst.vision.Faces',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='faces', full_name='rst.vision.Faces.faces', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='width', full_name='rst.vision.Faces.width', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='height', full_name='rst.vision.Faces.height', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=61,
  serialized_end=132,
)

_FACES.fields_by_name['faces'].message_type = rst_dot_vision_dot_Face__pb2._FACE
DESCRIPTOR.message_types_by_name['Faces'] = _FACES
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Faces = _reflection.GeneratedProtocolMessageType('Faces', (_message.Message,), dict(
  DESCRIPTOR = _FACES,
  __module__ = 'rst.vision.Faces_pb2'
  # @@protoc_insertion_point(class_scope:rst.vision.Faces)
  ))
_sym_db.RegisterMessage(Faces)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\tFacesType'))
# @@protoc_insertion_point(module_scope)
