# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/dialog/DialogManagerCommand.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/dialog/DialogManagerCommand.proto',
  package='rst.dialog',
  syntax='proto2',
  serialized_pb=_b('\n%rst/dialog/DialogManagerCommand.proto\x12\nrst.dialog\"\x9c\x01\n\x14\x44ialogManagerCommand\x12\x39\n\x07\x63ommand\x18\x01 \x02(\x0e\x32(.rst.dialog.DialogManagerCommand.Command\x12\x14\n\x0cpattern_name\x18\x02 \x01(\t\"3\n\x07\x43ommand\x12\x15\n\x11RESET_INTERACTION\x10\x00\x12\x11\n\rRESET_PATTERN\x10\x01\x42\x1a\x42\x18\x44ialogManagerCommandType')
)



_DIALOGMANAGERCOMMAND_COMMAND = _descriptor.EnumDescriptor(
  name='Command',
  full_name='rst.dialog.DialogManagerCommand.Command',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RESET_INTERACTION', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RESET_PATTERN', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=159,
  serialized_end=210,
)
_sym_db.RegisterEnumDescriptor(_DIALOGMANAGERCOMMAND_COMMAND)


_DIALOGMANAGERCOMMAND = _descriptor.Descriptor(
  name='DialogManagerCommand',
  full_name='rst.dialog.DialogManagerCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='command', full_name='rst.dialog.DialogManagerCommand.command', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pattern_name', full_name='rst.dialog.DialogManagerCommand.pattern_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _DIALOGMANAGERCOMMAND_COMMAND,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=54,
  serialized_end=210,
)

_DIALOGMANAGERCOMMAND.fields_by_name['command'].enum_type = _DIALOGMANAGERCOMMAND_COMMAND
_DIALOGMANAGERCOMMAND_COMMAND.containing_type = _DIALOGMANAGERCOMMAND
DESCRIPTOR.message_types_by_name['DialogManagerCommand'] = _DIALOGMANAGERCOMMAND
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DialogManagerCommand = _reflection.GeneratedProtocolMessageType('DialogManagerCommand', (_message.Message,), dict(
  DESCRIPTOR = _DIALOGMANAGERCOMMAND,
  __module__ = 'rst.dialog.DialogManagerCommand_pb2'
  # @@protoc_insertion_point(class_scope:rst.dialog.DialogManagerCommand)
  ))
_sym_db.RegisterMessage(DialogManagerCommand)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\030DialogManagerCommandType'))
# @@protoc_insertion_point(module_scope)
