# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/dialog/SpeechHypothesis.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.timing import Interval_pb2 as rst_dot_timing_dot_Interval__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/dialog/SpeechHypothesis.proto',
  package='rst.dialog',
  syntax='proto2',
  serialized_pb=_b('\n!rst/dialog/SpeechHypothesis.proto\x12\nrst.dialog\x1a\x19rst/timing/Interval.proto\"\xff\x06\n\x10SpeechHypothesis\x12\x30\n\x05words\x18\x01 \x03(\x0b\x32!.rst.dialog.SpeechHypothesis.Word\x12\x12\n\nconfidence\x18\x02 \x01(\x02\x12\'\n\ttimestamp\x18\x03 \x01(\x0b\x32\x14.rst.timing.Interval\x12\x14\n\x0cgrammar_tree\x18\x04 \x01(\t\x1a\xe5\x05\n\x04Word\x12\x0c\n\x04word\x18\x01 \x02(\t\x12(\n\ntimestamps\x18\x02 \x01(\x0b\x32\x14.rst.timing.Interval\x12M\n\x12part_of_speech_tag\x18\x03 \x01(\x0e\x32\x31.rst.dialog.SpeechHypothesis.Word.PartOfSpeechTag\"\xd5\x04\n\x0fPartOfSpeechTag\x12\x08\n\x04\x41\x44JA\x10\x01\x12\x08\n\x04\x41\x44JD\x10\x02\x12\x07\n\x03\x41\x44V\x10\x03\x12\x08\n\x04\x41PPR\x10\x04\x12\x0b\n\x07\x41PPRART\x10\x05\x12\x08\n\x04\x41PPO\x10\x06\x12\x08\n\x04\x41PZR\x10\x07\x12\x07\n\x03\x41RT\x10\x08\x12\x08\n\x04\x43\x41RD\x10\t\x12\x06\n\x02\x46M\x10\n\x12\x07\n\x03ITJ\x10\x0b\x12\x07\n\x03ORD\x10\x0c\x12\x08\n\x04KOUI\x10\r\x12\x08\n\x04KOUS\x10\x0e\x12\x07\n\x03KON\x10\x0f\x12\t\n\x05KOKOM\x10\x10\x12\x06\n\x02NN\x10\x11\x12\x06\n\x02NE\x10\x12\x12\x07\n\x03PDS\x10\x13\x12\x08\n\x04PDAT\x10\x14\x12\x07\n\x03PIS\x10\x15\x12\x08\n\x04PIAT\x10\x16\x12\t\n\x05PIDAT\x10\x17\x12\x08\n\x04PPER\x10\x18\x12\t\n\x05PPOSS\x10\x19\x12\n\n\x06PPOSAT\x10\x1a\x12\t\n\x05PRELS\x10\x1b\x12\n\n\x06PRELAT\x10\x1c\x12\x07\n\x03PRF\x10\x1d\x12\x07\n\x03PWS\x10\x1e\x12\x08\n\x04PWAT\x10\x1f\x12\x08\n\x04PWAV\x10 \x12\x07\n\x03PAV\x10!\x12\t\n\x05PTKZU\x10\"\x12\n\n\x06PTKNEG\x10#\x12\t\n\x05PTKVZ\x10$\x12\n\n\x06PTKANT\x10%\x12\x08\n\x04PTKA\x10&\x12\x08\n\x04SGML\x10\'\x12\t\n\x05SPELL\x10(\x12\t\n\x05TRUNC\x10)\x12\t\n\x05VVFIN\x10*\x12\t\n\x05VVIMP\x10+\x12\t\n\x05VVINF\x10,\x12\t\n\x05VVIZU\x10-\x12\x08\n\x04VVPP\x10.\x12\t\n\x05VAFIN\x10/\x12\t\n\x05VAIMP\x10\x30\x12\t\n\x05VAINF\x10\x31\x12\x08\n\x04VAPP\x10\x32\x12\t\n\x05VMFIN\x10\x33\x12\t\n\x05VMINF\x10\x34\x12\x08\n\x04VMPP\x10\x35\x12\x06\n\x02XY\x10\x36\x12\x08\n\x04KOMM\x10\x37\x12\x07\n\x03\x45ND\x10\x38\x12\t\n\x05IPNCT\x10\x39\x42\x16\x42\x14SpeechHypothesisType')
  ,
  dependencies=[rst_dot_timing_dot_Interval__pb2.DESCRIPTOR,])



_SPEECHHYPOTHESIS_WORD_PARTOFSPEECHTAG = _descriptor.EnumDescriptor(
  name='PartOfSpeechTag',
  full_name='rst.dialog.SpeechHypothesis.Word.PartOfSpeechTag',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ADJA', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADJD', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADV', index=2, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='APPR', index=3, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='APPRART', index=4, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='APPO', index=5, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='APZR', index=6, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ART', index=7, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CARD', index=8, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FM', index=9, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITJ', index=10, number=11,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ORD', index=11, number=12,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KOUI', index=12, number=13,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KOUS', index=13, number=14,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KON', index=14, number=15,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KOKOM', index=15, number=16,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NN', index=16, number=17,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NE', index=17, number=18,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PDS', index=18, number=19,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PDAT', index=19, number=20,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PIS', index=20, number=21,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PIAT', index=21, number=22,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PIDAT', index=22, number=23,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PPER', index=23, number=24,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PPOSS', index=24, number=25,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PPOSAT', index=25, number=26,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRELS', index=26, number=27,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRELAT', index=27, number=28,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRF', index=28, number=29,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PWS', index=29, number=30,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PWAT', index=30, number=31,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PWAV', index=31, number=32,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PAV', index=32, number=33,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PTKZU', index=33, number=34,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PTKNEG', index=34, number=35,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PTKVZ', index=35, number=36,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PTKANT', index=36, number=37,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PTKA', index=37, number=38,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SGML', index=38, number=39,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SPELL', index=39, number=40,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TRUNC', index=40, number=41,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VVFIN', index=41, number=42,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VVIMP', index=42, number=43,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VVINF', index=43, number=44,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VVIZU', index=44, number=45,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VVPP', index=45, number=46,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VAFIN', index=46, number=47,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VAIMP', index=47, number=48,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VAINF', index=48, number=49,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VAPP', index=49, number=50,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VMFIN', index=50, number=51,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VMINF', index=51, number=52,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VMPP', index=52, number=53,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='XY', index=53, number=54,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KOMM', index=54, number=55,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='END', index=55, number=56,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IPNCT', index=56, number=57,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=375,
  serialized_end=972,
)
_sym_db.RegisterEnumDescriptor(_SPEECHHYPOTHESIS_WORD_PARTOFSPEECHTAG)


_SPEECHHYPOTHESIS_WORD = _descriptor.Descriptor(
  name='Word',
  full_name='rst.dialog.SpeechHypothesis.Word',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='word', full_name='rst.dialog.SpeechHypothesis.Word.word', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timestamps', full_name='rst.dialog.SpeechHypothesis.Word.timestamps', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='part_of_speech_tag', full_name='rst.dialog.SpeechHypothesis.Word.part_of_speech_tag', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SPEECHHYPOTHESIS_WORD_PARTOFSPEECHTAG,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=231,
  serialized_end=972,
)

_SPEECHHYPOTHESIS = _descriptor.Descriptor(
  name='SpeechHypothesis',
  full_name='rst.dialog.SpeechHypothesis',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='words', full_name='rst.dialog.SpeechHypothesis.words', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='confidence', full_name='rst.dialog.SpeechHypothesis.confidence', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='rst.dialog.SpeechHypothesis.timestamp', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='grammar_tree', full_name='rst.dialog.SpeechHypothesis.grammar_tree', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_SPEECHHYPOTHESIS_WORD, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=77,
  serialized_end=972,
)

_SPEECHHYPOTHESIS_WORD.fields_by_name['timestamps'].message_type = rst_dot_timing_dot_Interval__pb2._INTERVAL
_SPEECHHYPOTHESIS_WORD.fields_by_name['part_of_speech_tag'].enum_type = _SPEECHHYPOTHESIS_WORD_PARTOFSPEECHTAG
_SPEECHHYPOTHESIS_WORD.containing_type = _SPEECHHYPOTHESIS
_SPEECHHYPOTHESIS_WORD_PARTOFSPEECHTAG.containing_type = _SPEECHHYPOTHESIS_WORD
_SPEECHHYPOTHESIS.fields_by_name['words'].message_type = _SPEECHHYPOTHESIS_WORD
_SPEECHHYPOTHESIS.fields_by_name['timestamp'].message_type = rst_dot_timing_dot_Interval__pb2._INTERVAL
DESCRIPTOR.message_types_by_name['SpeechHypothesis'] = _SPEECHHYPOTHESIS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SpeechHypothesis = _reflection.GeneratedProtocolMessageType('SpeechHypothesis', (_message.Message,), dict(

  Word = _reflection.GeneratedProtocolMessageType('Word', (_message.Message,), dict(
    DESCRIPTOR = _SPEECHHYPOTHESIS_WORD,
    __module__ = 'rst.dialog.SpeechHypothesis_pb2'
    # @@protoc_insertion_point(class_scope:rst.dialog.SpeechHypothesis.Word)
    ))
  ,
  DESCRIPTOR = _SPEECHHYPOTHESIS,
  __module__ = 'rst.dialog.SpeechHypothesis_pb2'
  # @@protoc_insertion_point(class_scope:rst.dialog.SpeechHypothesis)
  ))
_sym_db.RegisterMessage(SpeechHypothesis)
_sym_db.RegisterMessage(SpeechHypothesis.Word)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\024SpeechHypothesisType'))
# @@protoc_insertion_point(module_scope)
