# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/calendar/Attendee.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/calendar/Attendee.proto',
  package='rst.calendar',
  syntax='proto2',
  serialized_pb=_b('\n\x1brst/calendar/Attendee.proto\x12\x0crst.calendar\"\x9c\x05\n\x08\x41ttendee\x12\x17\n\x0f\x63\x61lendar_adress\x18\x01 \x02(\t\x12G\n\x12\x63\x61lendar_user_type\x18\x06 \x01(\x0e\x32\x1f.rst.calendar.Attendee.UserType:\nINDIVIDUAL\x12\x0e\n\x06member\x18\x07 \x03(\t\x12M\n\x12participation_role\x18\x08 \x01(\x0e\x32\x1b.rst.calendar.Attendee.Role:\x14REQUIRED_PARTICIPANT\x12V\n\x14participation_status\x18\t \x01(\x0e\x32*.rst.calendar.Attendee.ParticipationStatus:\x0cNEEDS_ACTION\x12\x1e\n\x0freply_requested\x18\n \x01(\x08:\x05\x66\x61lse\x12\x14\n\x0c\x64\x65legated_to\x18\x0b \x01(\t\x12\x16\n\x0e\x64\x65legated_from\x18\x0c \x01(\t\x12\x0f\n\x07sent_by\x18\x04 \x01(\t\x12\x13\n\x0b\x63ommon_name\x18\x02 \x01(\t\x12\x11\n\tdirectory\x18\x03 \x01(\t\x12\x10\n\x08language\x18\x05 \x01(\t\"=\n\x08UserType\x12\x0e\n\nINDIVIDUAL\x10\x01\x12\t\n\x05GROUP\x10\x02\x12\x0c\n\x08RESOURCE\x10\x03\x12\x08\n\x04ROOM\x10\x04\"Z\n\x04Role\x12\t\n\x05\x43HAIR\x10\x01\x12\x18\n\x14REQUIRED_PARTICIPANT\x10\x02\x12\x18\n\x14OPTIONAL_PARTICIPANT\x10\x03\x12\x13\n\x0fNON_PARTICIPANT\x10\x04\"C\n\x13ParticipationStatus\x12\x10\n\x0cNEEDS_ACTION\x10\x01\x12\x0c\n\x08\x41\x43\x43\x45PTED\x10\x02\x12\x0c\n\x08\x44\x45\x43LINED\x10\x03\x42\x0e\x42\x0c\x41ttendeeType')
)



_ATTENDEE_USERTYPE = _descriptor.EnumDescriptor(
  name='UserType',
  full_name='rst.calendar.Attendee.UserType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='INDIVIDUAL', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GROUP', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RESOURCE', index=2, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ROOM', index=3, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=492,
  serialized_end=553,
)
_sym_db.RegisterEnumDescriptor(_ATTENDEE_USERTYPE)

_ATTENDEE_ROLE = _descriptor.EnumDescriptor(
  name='Role',
  full_name='rst.calendar.Attendee.Role',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CHAIR', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REQUIRED_PARTICIPANT', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OPTIONAL_PARTICIPANT', index=2, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NON_PARTICIPANT', index=3, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=555,
  serialized_end=645,
)
_sym_db.RegisterEnumDescriptor(_ATTENDEE_ROLE)

_ATTENDEE_PARTICIPATIONSTATUS = _descriptor.EnumDescriptor(
  name='ParticipationStatus',
  full_name='rst.calendar.Attendee.ParticipationStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NEEDS_ACTION', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ACCEPTED', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DECLINED', index=2, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=647,
  serialized_end=714,
)
_sym_db.RegisterEnumDescriptor(_ATTENDEE_PARTICIPATIONSTATUS)


_ATTENDEE = _descriptor.Descriptor(
  name='Attendee',
  full_name='rst.calendar.Attendee',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='calendar_adress', full_name='rst.calendar.Attendee.calendar_adress', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='calendar_user_type', full_name='rst.calendar.Attendee.calendar_user_type', index=1,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='member', full_name='rst.calendar.Attendee.member', index=2,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='participation_role', full_name='rst.calendar.Attendee.participation_role', index=3,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='participation_status', full_name='rst.calendar.Attendee.participation_status', index=4,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reply_requested', full_name='rst.calendar.Attendee.reply_requested', index=5,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='delegated_to', full_name='rst.calendar.Attendee.delegated_to', index=6,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='delegated_from', full_name='rst.calendar.Attendee.delegated_from', index=7,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sent_by', full_name='rst.calendar.Attendee.sent_by', index=8,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='common_name', full_name='rst.calendar.Attendee.common_name', index=9,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='directory', full_name='rst.calendar.Attendee.directory', index=10,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='language', full_name='rst.calendar.Attendee.language', index=11,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ATTENDEE_USERTYPE,
    _ATTENDEE_ROLE,
    _ATTENDEE_PARTICIPATIONSTATUS,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=46,
  serialized_end=714,
)

_ATTENDEE.fields_by_name['calendar_user_type'].enum_type = _ATTENDEE_USERTYPE
_ATTENDEE.fields_by_name['participation_role'].enum_type = _ATTENDEE_ROLE
_ATTENDEE.fields_by_name['participation_status'].enum_type = _ATTENDEE_PARTICIPATIONSTATUS
_ATTENDEE_USERTYPE.containing_type = _ATTENDEE
_ATTENDEE_ROLE.containing_type = _ATTENDEE
_ATTENDEE_PARTICIPATIONSTATUS.containing_type = _ATTENDEE
DESCRIPTOR.message_types_by_name['Attendee'] = _ATTENDEE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Attendee = _reflection.GeneratedProtocolMessageType('Attendee', (_message.Message,), dict(
  DESCRIPTOR = _ATTENDEE,
  __module__ = 'rst.calendar.Attendee_pb2'
  # @@protoc_insertion_point(class_scope:rst.calendar.Attendee)
  ))
_sym_db.RegisterMessage(Attendee)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\014AttendeeType'))
# @@protoc_insertion_point(module_scope)
