# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/timing/Interval.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.timing import Timestamp_pb2 as rst_dot_timing_dot_Timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/timing/Interval.proto',
  package='rst.timing',
  syntax='proto2',
  serialized_pb=_b('\n\x19rst/timing/Interval.proto\x12\nrst.timing\x1a\x1arst/timing/Timestamp.proto\"T\n\x08Interval\x12$\n\x05\x62\x65gin\x18\x01 \x01(\x0b\x32\x15.rst.timing.Timestamp\x12\"\n\x03\x65nd\x18\x02 \x01(\x0b\x32\x15.rst.timing.TimestampB\x0e\x42\x0cIntervalType')
  ,
  dependencies=[rst_dot_timing_dot_Timestamp__pb2.DESCRIPTOR,])




_INTERVAL = _descriptor.Descriptor(
  name='Interval',
  full_name='rst.timing.Interval',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='begin', full_name='rst.timing.Interval.begin', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='end', full_name='rst.timing.Interval.end', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=69,
  serialized_end=153,
)

_INTERVAL.fields_by_name['begin'].message_type = rst_dot_timing_dot_Timestamp__pb2._TIMESTAMP
_INTERVAL.fields_by_name['end'].message_type = rst_dot_timing_dot_Timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['Interval'] = _INTERVAL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Interval = _reflection.GeneratedProtocolMessageType('Interval', (_message.Message,), dict(
  DESCRIPTOR = _INTERVAL,
  __module__ = 'rst.timing.Interval_pb2'
  # @@protoc_insertion_point(class_scope:rst.timing.Interval)
  ))
_sym_db.RegisterMessage(Interval)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\014IntervalType'))
# @@protoc_insertion_point(module_scope)
