# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/vision/SimpleXYZImage.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/vision/SimpleXYZImage.proto',
  package='rst.vision',
  syntax='proto2',
  serialized_pb=_b('\n\x1frst/vision/SimpleXYZImage.proto\x12\nrst.vision\"P\n\x0eSimpleXYZImage\x12\r\n\x05width\x18\x01 \x02(\r\x12\x0e\n\x06height\x18\x02 \x02(\r\x12\t\n\x01x\x18\x03 \x03(\x02\x12\t\n\x01y\x18\x04 \x03(\x02\x12\t\n\x01z\x18\x05 \x03(\x02\x42\x14\x42\x12SimpleXYZImageType')
)




_SIMPLEXYZIMAGE = _descriptor.Descriptor(
  name='SimpleXYZImage',
  full_name='rst.vision.SimpleXYZImage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='width', full_name='rst.vision.SimpleXYZImage.width', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='height', full_name='rst.vision.SimpleXYZImage.height', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='x', full_name='rst.vision.SimpleXYZImage.x', index=2,
      number=3, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='y', full_name='rst.vision.SimpleXYZImage.y', index=3,
      number=4, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='z', full_name='rst.vision.SimpleXYZImage.z', index=4,
      number=5, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=47,
  serialized_end=127,
)

DESCRIPTOR.message_types_by_name['SimpleXYZImage'] = _SIMPLEXYZIMAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SimpleXYZImage = _reflection.GeneratedProtocolMessageType('SimpleXYZImage', (_message.Message,), dict(
  DESCRIPTOR = _SIMPLEXYZIMAGE,
  __module__ = 'rst.vision.SimpleXYZImage_pb2'
  # @@protoc_insertion_point(class_scope:rst.vision.SimpleXYZImage)
  ))
_sym_db.RegisterMessage(SimpleXYZImage)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\022SimpleXYZImageType'))
# @@protoc_insertion_point(module_scope)
