# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/geometry/BoundingBox3DFloat.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.geometry import Pose_pb2 as rst_dot_geometry_dot_Pose__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/geometry/BoundingBox3DFloat.proto',
  package='rst.geometry',
  syntax='proto2',
  serialized_pb=_b('\n%rst/geometry/BoundingBox3DFloat.proto\x12\x0crst.geometry\x1a\x17rst/geometry/Pose.proto\"n\n\x12\x42oundingBox3DFloat\x12*\n\x0etransformation\x18\x01 \x02(\x0b\x32\x12.rst.geometry.Pose\x12\r\n\x05width\x18\x02 \x02(\x02\x12\r\n\x05\x64\x65pth\x18\x03 \x02(\x02\x12\x0e\n\x06height\x18\x04 \x02(\x02\x42\x18\x42\x16\x42oundingBox3DFloatType')
  ,
  dependencies=[rst_dot_geometry_dot_Pose__pb2.DESCRIPTOR,])




_BOUNDINGBOX3DFLOAT = _descriptor.Descriptor(
  name='BoundingBox3DFloat',
  full_name='rst.geometry.BoundingBox3DFloat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='transformation', full_name='rst.geometry.BoundingBox3DFloat.transformation', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='width', full_name='rst.geometry.BoundingBox3DFloat.width', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='depth', full_name='rst.geometry.BoundingBox3DFloat.depth', index=2,
      number=3, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='height', full_name='rst.geometry.BoundingBox3DFloat.height', index=3,
      number=4, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=80,
  serialized_end=190,
)

_BOUNDINGBOX3DFLOAT.fields_by_name['transformation'].message_type = rst_dot_geometry_dot_Pose__pb2._POSE
DESCRIPTOR.message_types_by_name['BoundingBox3DFloat'] = _BOUNDINGBOX3DFLOAT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BoundingBox3DFloat = _reflection.GeneratedProtocolMessageType('BoundingBox3DFloat', (_message.Message,), dict(
  DESCRIPTOR = _BOUNDINGBOX3DFLOAT,
  __module__ = 'rst.geometry.BoundingBox3DFloat_pb2'
  # @@protoc_insertion_point(class_scope:rst.geometry.BoundingBox3DFloat)
  ))
_sym_db.RegisterMessage(BoundingBox3DFloat)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\026BoundingBox3DFloatType'))
# @@protoc_insertion_point(module_scope)
