# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/classification/ClassificationResults.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.classification import ClassificationResult_pb2 as rst_dot_classification_dot_ClassificationResult__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/classification/ClassificationResults.proto',
  package='rst.classification',
  syntax='proto2',
  serialized_pb=_b('\n.rst/classification/ClassificationResults.proto\x12\x12rst.classification\x1a-rst/classification/ClassificationResult.proto\"R\n\x15\x43lassificationResults\x12\x39\n\x07\x63lasses\x18\x01 \x03(\x0b\x32(.rst.classification.ClassificationResultB\x1b\x42\x19\x43lassificationResultsType')
  ,
  dependencies=[rst_dot_classification_dot_ClassificationResult__pb2.DESCRIPTOR,])




_CLASSIFICATIONRESULTS = _descriptor.Descriptor(
  name='ClassificationResults',
  full_name='rst.classification.ClassificationResults',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='classes', full_name='rst.classification.ClassificationResults.classes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=117,
  serialized_end=199,
)

_CLASSIFICATIONRESULTS.fields_by_name['classes'].message_type = rst_dot_classification_dot_ClassificationResult__pb2._CLASSIFICATIONRESULT
DESCRIPTOR.message_types_by_name['ClassificationResults'] = _CLASSIFICATIONRESULTS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ClassificationResults = _reflection.GeneratedProtocolMessageType('ClassificationResults', (_message.Message,), dict(
  DESCRIPTOR = _CLASSIFICATIONRESULTS,
  __module__ = 'rst.classification.ClassificationResults_pb2'
  # @@protoc_insertion_point(class_scope:rst.classification.ClassificationResults)
  ))
_sym_db.RegisterMessage(ClassificationResults)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\031ClassificationResultsType'))
# @@protoc_insertion_point(module_scope)
