# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/navigation/ExecutionParameters.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/navigation/ExecutionParameters.proto',
  package='rst.navigation',
  syntax='proto2',
  serialized_pb=_b('\n(rst/navigation/ExecutionParameters.proto\x12\x0erst.navigation\"`\n\x13\x45xecutionParameters\x12\x0f\n\x07timeout\x18\x01 \x01(\x02\x12\x19\n\x11max_replan_cycles\x18\x64 \x01(\r\x12\x1d\n\x15use_fine_localization\x18\x65 \x01(\x08\x42\x19\x42\x17\x45xecutionParametersType')
)




_EXECUTIONPARAMETERS = _descriptor.Descriptor(
  name='ExecutionParameters',
  full_name='rst.navigation.ExecutionParameters',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timeout', full_name='rst.navigation.ExecutionParameters.timeout', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_replan_cycles', full_name='rst.navigation.ExecutionParameters.max_replan_cycles', index=1,
      number=100, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='use_fine_localization', full_name='rst.navigation.ExecutionParameters.use_fine_localization', index=2,
      number=101, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=60,
  serialized_end=156,
)

DESCRIPTOR.message_types_by_name['ExecutionParameters'] = _EXECUTIONPARAMETERS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ExecutionParameters = _reflection.GeneratedProtocolMessageType('ExecutionParameters', (_message.Message,), dict(
  DESCRIPTOR = _EXECUTIONPARAMETERS,
  __module__ = 'rst.navigation.ExecutionParameters_pb2'
  # @@protoc_insertion_point(class_scope:rst.navigation.ExecutionParameters)
  ))
_sym_db.RegisterMessage(ExecutionParameters)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\027ExecutionParametersType'))
# @@protoc_insertion_point(module_scope)
