# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/devices/generic/MemoryState.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/devices/generic/MemoryState.proto',
  package='rst.devices.generic',
  syntax='proto2',
  serialized_pb=_b('\n%rst/devices/generic/MemoryState.proto\x12\x13rst.devices.generic\"a\n\x0bMemoryState\x12\r\n\x05total\x18\x02 \x01(\x02\x12\x0c\n\x04used\x18\x03 \x01(\x02\x12\x0e\n\x06usable\x18\x04 \x01(\x04\x12\x12\n\nswap_total\x18\x05 \x01(\x04\x12\x11\n\tswap_used\x18\x06 \x01(\x04\x42\x11\x42\x0fMemoryStateType')
)




_MEMORYSTATE = _descriptor.Descriptor(
  name='MemoryState',
  full_name='rst.devices.generic.MemoryState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='total', full_name='rst.devices.generic.MemoryState.total', index=0,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='used', full_name='rst.devices.generic.MemoryState.used', index=1,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='usable', full_name='rst.devices.generic.MemoryState.usable', index=2,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='swap_total', full_name='rst.devices.generic.MemoryState.swap_total', index=3,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='swap_used', full_name='rst.devices.generic.MemoryState.swap_used', index=4,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=62,
  serialized_end=159,
)

DESCRIPTOR.message_types_by_name['MemoryState'] = _MEMORYSTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MemoryState = _reflection.GeneratedProtocolMessageType('MemoryState', (_message.Message,), dict(
  DESCRIPTOR = _MEMORYSTATE,
  __module__ = 'rst.devices.generic.MemoryState_pb2'
  # @@protoc_insertion_point(class_scope:rst.devices.generic.MemoryState)
  ))
_sym_db.RegisterMessage(MemoryState)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\017MemoryStateType'))
# @@protoc_insertion_point(module_scope)
