# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/devices/rfid/Tag.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/devices/rfid/Tag.proto',
  package='rst.devices.rfid',
  syntax='proto2',
  serialized_pb=_b('\n\x1arst/devices/rfid/Tag.proto\x12\x10rst.devices.rfid\"1\n\x03Tag\x12\n\n\x02id\x18\x01 \x02(\x0c\x12\x0e\n\x06vendor\x18\x02 \x01(\x0c\x12\x0e\n\x06source\x18\x03 \x01(\x0c\x42\tB\x07TagType')
)




_TAG = _descriptor.Descriptor(
  name='Tag',
  full_name='rst.devices.rfid.Tag',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='rst.devices.rfid.Tag.id', index=0,
      number=1, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='vendor', full_name='rst.devices.rfid.Tag.vendor', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='source', full_name='rst.devices.rfid.Tag.source', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=48,
  serialized_end=97,
)

DESCRIPTOR.message_types_by_name['Tag'] = _TAG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Tag = _reflection.GeneratedProtocolMessageType('Tag', (_message.Message,), dict(
  DESCRIPTOR = _TAG,
  __module__ = 'rst.devices.rfid.Tag_pb2'
  # @@protoc_insertion_point(class_scope:rst.devices.rfid.Tag)
  ))
_sym_db.RegisterMessage(Tag)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\007TagType'))
# @@protoc_insertion_point(module_scope)
