# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/hri/BodyList.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.hri import Body_pb2 as rst_dot_hri_dot_Body__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/hri/BodyList.proto',
  package='rst.hri',
  syntax='proto2',
  serialized_pb=_b('\n\x16rst/hri/BodyList.proto\x12\x07rst.hri\x1a\x12rst/hri/Body.proto\"*\n\x08\x42odyList\x12\x1e\n\x07\x65lement\x18\x01 \x03(\x0b\x32\r.rst.hri.BodyB\x0e\x42\x0c\x42odyListType')
  ,
  dependencies=[rst_dot_hri_dot_Body__pb2.DESCRIPTOR,])




_BODYLIST = _descriptor.Descriptor(
  name='BodyList',
  full_name='rst.hri.BodyList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='element', full_name='rst.hri.BodyList.element', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55,
  serialized_end=97,
)

_BODYLIST.fields_by_name['element'].message_type = rst_dot_hri_dot_Body__pb2._BODY
DESCRIPTOR.message_types_by_name['BodyList'] = _BODYLIST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BodyList = _reflection.GeneratedProtocolMessageType('BodyList', (_message.Message,), dict(
  DESCRIPTOR = _BODYLIST,
  __module__ = 'rst.hri.BodyList_pb2'
  # @@protoc_insertion_point(class_scope:rst.hri.BodyList)
  ))
_sym_db.RegisterMessage(BodyList)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\014BodyListType'))
# @@protoc_insertion_point(module_scope)
