# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/animation/EmotionExpression.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/animation/EmotionExpression.proto',
  package='rst.animation',
  syntax='proto2',
  serialized_pb=_b('\n%rst/animation/EmotionExpression.proto\x12\rrst.animation\"\xb0\x01\n\x11\x45motionExpression\x12\x39\n\x07\x65motion\x18\x01 \x02(\x0e\x32(.rst.animation.EmotionExpression.Emotion\x12\x10\n\x08\x64uration\x18\x02 \x02(\r\"N\n\x07\x45motion\x12\x0b\n\x07NEUTRAL\x10\x00\x12\t\n\x05HAPPY\x10\x01\x12\x07\n\x03SAD\x10\x02\x12\t\n\x05\x41NGRY\x10\x03\x12\r\n\tSURPRISED\x10\x04\x12\x08\n\x04\x46\x45\x41R\x10\x05\x42\x17\x42\x15\x45motionExpressionType')
)



_EMOTIONEXPRESSION_EMOTION = _descriptor.EnumDescriptor(
  name='Emotion',
  full_name='rst.animation.EmotionExpression.Emotion',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NEUTRAL', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HAPPY', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SAD', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ANGRY', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SURPRISED', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FEAR', index=5, number=5,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=155,
  serialized_end=233,
)
_sym_db.RegisterEnumDescriptor(_EMOTIONEXPRESSION_EMOTION)


_EMOTIONEXPRESSION = _descriptor.Descriptor(
  name='EmotionExpression',
  full_name='rst.animation.EmotionExpression',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='emotion', full_name='rst.animation.EmotionExpression.emotion', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='duration', full_name='rst.animation.EmotionExpression.duration', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _EMOTIONEXPRESSION_EMOTION,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=57,
  serialized_end=233,
)

_EMOTIONEXPRESSION.fields_by_name['emotion'].enum_type = _EMOTIONEXPRESSION_EMOTION
_EMOTIONEXPRESSION_EMOTION.containing_type = _EMOTIONEXPRESSION
DESCRIPTOR.message_types_by_name['EmotionExpression'] = _EMOTIONEXPRESSION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

EmotionExpression = _reflection.GeneratedProtocolMessageType('EmotionExpression', (_message.Message,), dict(
  DESCRIPTOR = _EMOTIONEXPRESSION,
  __module__ = 'rst.animation.EmotionExpression_pb2'
  # @@protoc_insertion_point(class_scope:rst.animation.EmotionExpression)
  ))
_sym_db.RegisterMessage(EmotionExpression)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\025EmotionExpressionType'))
# @@protoc_insertion_point(module_scope)
