# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/tts/TextToSpeechInstruction.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.tts import Prosody_pb2 as rst_dot_tts_dot_Prosody__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/tts/TextToSpeechInstruction.proto',
  package='rst.tts',
  syntax='proto2',
  serialized_pb=_b('\n%rst/tts/TextToSpeechInstruction.proto\x12\x07rst.tts\x1a\x15rst/tts/Prosody.proto\"\xd7\x01\n\x17TextToSpeechInstruction\x12\x0c\n\x04text\x18\x01 \x01(\t\x12!\n\x07prosody\x18\x02 \x01(\x0b\x32\x10.rst.tts.Prosody\x12N\n\x0fplayback_option\x18\x03 \x01(\x0e\x32/.rst.tts.TextToSpeechInstruction.PlaybackOption:\x04PLAY\";\n\x0ePlaybackOption\x12\x08\n\x04PLAY\x10\x00\x12\x08\n\x04STOP\x10\x01\x12\t\n\x05PAUSE\x10\x02\x12\n\n\x06RESUME\x10\x03\x42\x1d\x42\x1bTextToSpeechInstructionType')
  ,
  dependencies=[rst_dot_tts_dot_Prosody__pb2.DESCRIPTOR,])



_TEXTTOSPEECHINSTRUCTION_PLAYBACKOPTION = _descriptor.EnumDescriptor(
  name='PlaybackOption',
  full_name='rst.tts.TextToSpeechInstruction.PlaybackOption',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PLAY', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STOP', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PAUSE', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RESUME', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=230,
  serialized_end=289,
)
_sym_db.RegisterEnumDescriptor(_TEXTTOSPEECHINSTRUCTION_PLAYBACKOPTION)


_TEXTTOSPEECHINSTRUCTION = _descriptor.Descriptor(
  name='TextToSpeechInstruction',
  full_name='rst.tts.TextToSpeechInstruction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='text', full_name='rst.tts.TextToSpeechInstruction.text', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='prosody', full_name='rst.tts.TextToSpeechInstruction.prosody', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='playback_option', full_name='rst.tts.TextToSpeechInstruction.playback_option', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TEXTTOSPEECHINSTRUCTION_PLAYBACKOPTION,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=74,
  serialized_end=289,
)

_TEXTTOSPEECHINSTRUCTION.fields_by_name['prosody'].message_type = rst_dot_tts_dot_Prosody__pb2._PROSODY
_TEXTTOSPEECHINSTRUCTION.fields_by_name['playback_option'].enum_type = _TEXTTOSPEECHINSTRUCTION_PLAYBACKOPTION
_TEXTTOSPEECHINSTRUCTION_PLAYBACKOPTION.containing_type = _TEXTTOSPEECHINSTRUCTION
DESCRIPTOR.message_types_by_name['TextToSpeechInstruction'] = _TEXTTOSPEECHINSTRUCTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TextToSpeechInstruction = _reflection.GeneratedProtocolMessageType('TextToSpeechInstruction', (_message.Message,), dict(
  DESCRIPTOR = _TEXTTOSPEECHINSTRUCTION,
  __module__ = 'rst.tts.TextToSpeechInstruction_pb2'
  # @@protoc_insertion_point(class_scope:rst.tts.TextToSpeechInstruction)
  ))
_sym_db.RegisterMessage(TextToSpeechInstruction)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\033TextToSpeechInstructionType'))
# @@protoc_insertion_point(module_scope)
