# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/scene/SceneObjectQuery.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/scene/SceneObjectQuery.proto',
  package='rst.scene',
  syntax='proto2',
  serialized_pb=_b('\n rst/scene/SceneObjectQuery.proto\x12\trst.scene\"D\n\x10SceneObjectQuery\x12\x17\n\x0bname_filter\x18\x01 \x01(\t:\x02.*\x12\x17\n\x0bkind_filter\x18\x02 \x01(\t:\x02.*B\x16\x42\x14SceneObjectQueryType')
)




_SCENEOBJECTQUERY = _descriptor.Descriptor(
  name='SceneObjectQuery',
  full_name='rst.scene.SceneObjectQuery',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name_filter', full_name='rst.scene.SceneObjectQuery.name_filter', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=_b(".*").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='kind_filter', full_name='rst.scene.SceneObjectQuery.kind_filter', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=_b(".*").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=47,
  serialized_end=115,
)

DESCRIPTOR.message_types_by_name['SceneObjectQuery'] = _SCENEOBJECTQUERY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SceneObjectQuery = _reflection.GeneratedProtocolMessageType('SceneObjectQuery', (_message.Message,), dict(
  DESCRIPTOR = _SCENEOBJECTQUERY,
  __module__ = 'rst.scene.SceneObjectQuery_pb2'
  # @@protoc_insertion_point(class_scope:rst.scene.SceneObjectQuery)
  ))
_sym_db.RegisterMessage(SceneObjectQuery)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\024SceneObjectQueryType'))
# @@protoc_insertion_point(module_scope)
