# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/navigation/CoordinateCommand.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.navigation import ExecutionParameters_pb2 as rst_dot_navigation_dot_ExecutionParameters__pb2
from rst.navigation import MotionParameters_pb2 as rst_dot_navigation_dot_MotionParameters__pb2
from rst.geometry import Pose_pb2 as rst_dot_geometry_dot_Pose__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/navigation/CoordinateCommand.proto',
  package='rst.navigation',
  syntax='proto2',
  serialized_pb=_b('\n&rst/navigation/CoordinateCommand.proto\x12\x0erst.navigation\x1a(rst/navigation/ExecutionParameters.proto\x1a%rst/navigation/MotionParameters.proto\x1a\x17rst/geometry/Pose.proto\"\xb5\x01\n\x11\x43oordinateCommand\x12 \n\x04goal\x18\x01 \x02(\x0b\x32\x12.rst.geometry.Pose\x12;\n\x11motion_parameters\x18\x02 \x01(\x0b\x32 .rst.navigation.MotionParameters\x12\x41\n\x14\x65xecution_parameters\x18\x03 \x01(\x0b\x32#.rst.navigation.ExecutionParametersB\x17\x42\x15\x43oordinateCommandType')
  ,
  dependencies=[rst_dot_navigation_dot_ExecutionParameters__pb2.DESCRIPTOR,rst_dot_navigation_dot_MotionParameters__pb2.DESCRIPTOR,rst_dot_geometry_dot_Pose__pb2.DESCRIPTOR,])




_COORDINATECOMMAND = _descriptor.Descriptor(
  name='CoordinateCommand',
  full_name='rst.navigation.CoordinateCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='goal', full_name='rst.navigation.CoordinateCommand.goal', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='motion_parameters', full_name='rst.navigation.CoordinateCommand.motion_parameters', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='execution_parameters', full_name='rst.navigation.CoordinateCommand.execution_parameters', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=165,
  serialized_end=346,
)

_COORDINATECOMMAND.fields_by_name['goal'].message_type = rst_dot_geometry_dot_Pose__pb2._POSE
_COORDINATECOMMAND.fields_by_name['motion_parameters'].message_type = rst_dot_navigation_dot_MotionParameters__pb2._MOTIONPARAMETERS
_COORDINATECOMMAND.fields_by_name['execution_parameters'].message_type = rst_dot_navigation_dot_ExecutionParameters__pb2._EXECUTIONPARAMETERS
DESCRIPTOR.message_types_by_name['CoordinateCommand'] = _COORDINATECOMMAND
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CoordinateCommand = _reflection.GeneratedProtocolMessageType('CoordinateCommand', (_message.Message,), dict(
  DESCRIPTOR = _COORDINATECOMMAND,
  __module__ = 'rst.navigation.CoordinateCommand_pb2'
  # @@protoc_insertion_point(class_scope:rst.navigation.CoordinateCommand)
  ))
_sym_db.RegisterMessage(CoordinateCommand)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\025CoordinateCommandType'))
# @@protoc_insertion_point(module_scope)
