# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/robot/RobotCollision.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.kinematics import ObjectCollision_pb2 as rst_dot_kinematics_dot_ObjectCollision__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/robot/RobotCollision.proto',
  package='rst.robot',
  syntax='proto2',
  serialized_pb=_b('\n\x1erst/robot/RobotCollision.proto\x12\trst.robot\x1a$rst/kinematics/ObjectCollision.proto\"\xb8\x01\n\x0eRobotCollision\x12\x35\n\x04kind\x18\x01 \x02(\x0e\x32\'.rst.robot.RobotCollision.CollisionKind\x12\x39\n\x10\x63ollision_detail\x18\x02 \x02(\x0b\x32\x1f.rst.kinematics.ObjectCollision\"4\n\rCollisionKind\x12\x08\n\x04SELF\x10\x01\x12\x0c\n\x08\x45XTERNAL\x10\x02\x12\x0b\n\x07UNKNOWN\x10\x03\x42\x14\x42\x12RobotCollisionType')
  ,
  dependencies=[rst_dot_kinematics_dot_ObjectCollision__pb2.DESCRIPTOR,])



_ROBOTCOLLISION_COLLISIONKIND = _descriptor.EnumDescriptor(
  name='CollisionKind',
  full_name='rst.robot.RobotCollision.CollisionKind',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SELF', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EXTERNAL', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=2, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=216,
  serialized_end=268,
)
_sym_db.RegisterEnumDescriptor(_ROBOTCOLLISION_COLLISIONKIND)


_ROBOTCOLLISION = _descriptor.Descriptor(
  name='RobotCollision',
  full_name='rst.robot.RobotCollision',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='kind', full_name='rst.robot.RobotCollision.kind', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='collision_detail', full_name='rst.robot.RobotCollision.collision_detail', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ROBOTCOLLISION_COLLISIONKIND,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=84,
  serialized_end=268,
)

_ROBOTCOLLISION.fields_by_name['kind'].enum_type = _ROBOTCOLLISION_COLLISIONKIND
_ROBOTCOLLISION.fields_by_name['collision_detail'].message_type = rst_dot_kinematics_dot_ObjectCollision__pb2._OBJECTCOLLISION
_ROBOTCOLLISION_COLLISIONKIND.containing_type = _ROBOTCOLLISION
DESCRIPTOR.message_types_by_name['RobotCollision'] = _ROBOTCOLLISION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RobotCollision = _reflection.GeneratedProtocolMessageType('RobotCollision', (_message.Message,), dict(
  DESCRIPTOR = _ROBOTCOLLISION,
  __module__ = 'rst.robot.RobotCollision_pb2'
  # @@protoc_insertion_point(class_scope:rst.robot.RobotCollision)
  ))
_sym_db.RegisterMessage(RobotCollision)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\022RobotCollisionType'))
# @@protoc_insertion_point(module_scope)
