# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/calendar/TimeZone.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.calendar import DateTime_pb2 as rst_dot_calendar_dot_DateTime__pb2
from rst.calendar import Observance_pb2 as rst_dot_calendar_dot_Observance__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/calendar/TimeZone.proto',
  package='rst.calendar',
  syntax='proto2',
  serialized_pb=_b('\n\x1brst/calendar/TimeZone.proto\x12\x0crst.calendar\x1a\x1brst/calendar/DateTime.proto\x1a\x1drst/calendar/Observance.proto\"\xd6\x01\n\x08TimeZone\x12\x13\n\x0btimezone_id\x18\x01 \x02(\t\x12\x31\n\x11last_modified_utc\x18\x02 \x01(\x0b\x32\x16.rst.calendar.DateTime\x12\x14\n\x0ctimezone_url\x18\x03 \x01(\t\x12\x12\n\nx_location\x18\x04 \x01(\t\x12+\n\tstandards\x18\x05 \x03(\x0b\x32\x18.rst.calendar.Observance\x12+\n\tdaylights\x18\x06 \x03(\x0b\x32\x18.rst.calendar.ObservanceB\x0e\x42\x0cTimeZoneType')
  ,
  dependencies=[rst_dot_calendar_dot_DateTime__pb2.DESCRIPTOR,rst_dot_calendar_dot_Observance__pb2.DESCRIPTOR,])




_TIMEZONE = _descriptor.Descriptor(
  name='TimeZone',
  full_name='rst.calendar.TimeZone',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timezone_id', full_name='rst.calendar.TimeZone.timezone_id', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='last_modified_utc', full_name='rst.calendar.TimeZone.last_modified_utc', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timezone_url', full_name='rst.calendar.TimeZone.timezone_url', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='x_location', full_name='rst.calendar.TimeZone.x_location', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='standards', full_name='rst.calendar.TimeZone.standards', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='daylights', full_name='rst.calendar.TimeZone.daylights', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=106,
  serialized_end=320,
)

_TIMEZONE.fields_by_name['last_modified_utc'].message_type = rst_dot_calendar_dot_DateTime__pb2._DATETIME
_TIMEZONE.fields_by_name['standards'].message_type = rst_dot_calendar_dot_Observance__pb2._OBSERVANCE
_TIMEZONE.fields_by_name['daylights'].message_type = rst_dot_calendar_dot_Observance__pb2._OBSERVANCE
DESCRIPTOR.message_types_by_name['TimeZone'] = _TIMEZONE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TimeZone = _reflection.GeneratedProtocolMessageType('TimeZone', (_message.Message,), dict(
  DESCRIPTOR = _TIMEZONE,
  __module__ = 'rst.calendar.TimeZone_pb2'
  # @@protoc_insertion_point(class_scope:rst.calendar.TimeZone)
  ))
_sym_db.RegisterMessage(TimeZone)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\014TimeZoneType'))
# @@protoc_insertion_point(module_scope)
