# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/dialog/IncrementalUnit.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.timing import Interval_pb2 as rst_dot_timing_dot_Interval__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/dialog/IncrementalUnit.proto',
  package='rst.dialog',
  syntax='proto2',
  serialized_pb=_b('\n rst/dialog/IncrementalUnit.proto\x12\nrst.dialog\x1a\x19rst/timing/Interval.proto\"\xd6\x01\n\x0fIncrementalUnit\x12(\n\ntimestamps\x18\x02 \x01(\x0b\x32\x14.rst.timing.Interval\x12\n\n\x02id\x18\x03 \x02(\x0c\x12\x0e\n\x06sll_id\x18\x04 \x03(\x0c\x12\x0e\n\x06gil_id\x18\x05 \x03(\x0c\x12\x33\n\x05state\x18\x06 \x02(\x0e\x32$.rst.dialog.IncrementalUnit.EditType\"8\n\x08\x45\x64itType\x12\x07\n\x03\x41\x44\x44\x10\x00\x12\x0b\n\x07UPDATED\x10\x01\x12\n\n\x06REVOKE\x10\x02\x12\n\n\x06\x43OMMIT\x10\x03\x42\x15\x42\x13IncrementalUnitType')
  ,
  dependencies=[rst_dot_timing_dot_Interval__pb2.DESCRIPTOR,])



_INCREMENTALUNIT_EDITTYPE = _descriptor.EnumDescriptor(
  name='EditType',
  full_name='rst.dialog.IncrementalUnit.EditType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ADD', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UPDATED', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REVOKE', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COMMIT', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=234,
  serialized_end=290,
)
_sym_db.RegisterEnumDescriptor(_INCREMENTALUNIT_EDITTYPE)


_INCREMENTALUNIT = _descriptor.Descriptor(
  name='IncrementalUnit',
  full_name='rst.dialog.IncrementalUnit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamps', full_name='rst.dialog.IncrementalUnit.timestamps', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='id', full_name='rst.dialog.IncrementalUnit.id', index=1,
      number=3, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sll_id', full_name='rst.dialog.IncrementalUnit.sll_id', index=2,
      number=4, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='gil_id', full_name='rst.dialog.IncrementalUnit.gil_id', index=3,
      number=5, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='state', full_name='rst.dialog.IncrementalUnit.state', index=4,
      number=6, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _INCREMENTALUNIT_EDITTYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=76,
  serialized_end=290,
)

_INCREMENTALUNIT.fields_by_name['timestamps'].message_type = rst_dot_timing_dot_Interval__pb2._INTERVAL
_INCREMENTALUNIT.fields_by_name['state'].enum_type = _INCREMENTALUNIT_EDITTYPE
_INCREMENTALUNIT_EDITTYPE.containing_type = _INCREMENTALUNIT
DESCRIPTOR.message_types_by_name['IncrementalUnit'] = _INCREMENTALUNIT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

IncrementalUnit = _reflection.GeneratedProtocolMessageType('IncrementalUnit', (_message.Message,), dict(
  DESCRIPTOR = _INCREMENTALUNIT,
  __module__ = 'rst.dialog.IncrementalUnit_pb2'
  # @@protoc_insertion_point(class_scope:rst.dialog.IncrementalUnit)
  ))
_sym_db.RegisterMessage(IncrementalUnit)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\023IncrementalUnitType'))
# @@protoc_insertion_point(module_scope)
