# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/stochastics/MixtureOfGaussian1D.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.stochastics import Gaussian1D_pb2 as rst_dot_stochastics_dot_Gaussian1D__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/stochastics/MixtureOfGaussian1D.proto',
  package='rst.stochastics',
  syntax='proto2',
  serialized_pb=_b('\n)rst/stochastics/MixtureOfGaussian1D.proto\x12\x0frst.stochastics\x1a rst/stochastics/Gaussian1D.proto\"\xd4\x01\n\x13MixtureOfGaussian1D\x12L\n\ncomponents\x18\x01 \x03(\x0b\x32\x38.rst.stochastics.MixtureOfGaussian1D.GaussianComponent1D\x1ao\n\x13GaussianComponent1D\x12-\n\x08gaussian\x18\x01 \x02(\x0b\x32\x1b.rst.stochastics.Gaussian1D\x12\x0e\n\x06weight\x18\x02 \x02(\x02\x12\x19\n\x11probability_state\x18\x03 \x02(\x02\x42\x19\x42\x17MixtureOfGaussian1DType')
  ,
  dependencies=[rst_dot_stochastics_dot_Gaussian1D__pb2.DESCRIPTOR,])




_MIXTUREOFGAUSSIAN1D_GAUSSIANCOMPONENT1D = _descriptor.Descriptor(
  name='GaussianComponent1D',
  full_name='rst.stochastics.MixtureOfGaussian1D.GaussianComponent1D',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gaussian', full_name='rst.stochastics.MixtureOfGaussian1D.GaussianComponent1D.gaussian', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='weight', full_name='rst.stochastics.MixtureOfGaussian1D.GaussianComponent1D.weight', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='probability_state', full_name='rst.stochastics.MixtureOfGaussian1D.GaussianComponent1D.probability_state', index=2,
      number=3, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=198,
  serialized_end=309,
)

_MIXTUREOFGAUSSIAN1D = _descriptor.Descriptor(
  name='MixtureOfGaussian1D',
  full_name='rst.stochastics.MixtureOfGaussian1D',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='components', full_name='rst.stochastics.MixtureOfGaussian1D.components', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_MIXTUREOFGAUSSIAN1D_GAUSSIANCOMPONENT1D, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=97,
  serialized_end=309,
)

_MIXTUREOFGAUSSIAN1D_GAUSSIANCOMPONENT1D.fields_by_name['gaussian'].message_type = rst_dot_stochastics_dot_Gaussian1D__pb2._GAUSSIAN1D
_MIXTUREOFGAUSSIAN1D_GAUSSIANCOMPONENT1D.containing_type = _MIXTUREOFGAUSSIAN1D
_MIXTUREOFGAUSSIAN1D.fields_by_name['components'].message_type = _MIXTUREOFGAUSSIAN1D_GAUSSIANCOMPONENT1D
DESCRIPTOR.message_types_by_name['MixtureOfGaussian1D'] = _MIXTUREOFGAUSSIAN1D
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MixtureOfGaussian1D = _reflection.GeneratedProtocolMessageType('MixtureOfGaussian1D', (_message.Message,), dict(

  GaussianComponent1D = _reflection.GeneratedProtocolMessageType('GaussianComponent1D', (_message.Message,), dict(
    DESCRIPTOR = _MIXTUREOFGAUSSIAN1D_GAUSSIANCOMPONENT1D,
    __module__ = 'rst.stochastics.MixtureOfGaussian1D_pb2'
    # @@protoc_insertion_point(class_scope:rst.stochastics.MixtureOfGaussian1D.GaussianComponent1D)
    ))
  ,
  DESCRIPTOR = _MIXTUREOFGAUSSIAN1D,
  __module__ = 'rst.stochastics.MixtureOfGaussian1D_pb2'
  # @@protoc_insertion_point(class_scope:rst.stochastics.MixtureOfGaussian1D)
  ))
_sym_db.RegisterMessage(MixtureOfGaussian1D)
_sym_db.RegisterMessage(MixtureOfGaussian1D.GaussianComponent1D)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\027MixtureOfGaussian1DType'))
# @@protoc_insertion_point(module_scope)
