# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/communicationpatterns/TaskState.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/communicationpatterns/TaskState.proto',
  package='rst.communicationpatterns',
  syntax='proto2',
  serialized_pb=_b('\n)rst/communicationpatterns/TaskState.proto\x12\x19rst.communicationpatterns\"\x90\x03\n\tTaskState\x12;\n\x06origin\x18\x01 \x02(\x0e\x32+.rst.communicationpatterns.TaskState.Origin\x12\x39\n\x05state\x18\x02 \x02(\x0e\x32*.rst.communicationpatterns.TaskState.State\x12\x0e\n\x06serial\x18\x03 \x02(\r\x12\x13\n\x0bwire_schema\x18\x04 \x02(\x0c\x12\x0f\n\x07payload\x18\x05 \x02(\x0c\"\xae\x01\n\x05State\x12\r\n\tINITIATED\x10\x00\x12\x0c\n\x08\x41\x43\x43\x45PTED\x10\x01\x12\x0c\n\x08REJECTED\x10\x02\x12\n\n\x06UPDATE\x10\x03\x12\x13\n\x0fUPDATE_REJECTED\x10\x04\x12\t\n\x05\x41\x42ORT\x10\x05\x12\x0b\n\x07\x41\x42ORTED\x10\x06\x12\x10\n\x0c\x41\x42ORT_FAILED\x10\x07\x12\x14\n\x10RESULT_AVAILABLE\x10\x08\x12\r\n\tCOMPLETED\x10\t\x12\n\n\x06\x46\x41ILED\x10\n\"$\n\x06Origin\x12\r\n\tSUBMITTER\x10\x00\x12\x0b\n\x07HANDLER\x10\x01\x42\x0f\x42\rTaskStateType')
)



_TASKSTATE_STATE = _descriptor.EnumDescriptor(
  name='State',
  full_name='rst.communicationpatterns.TaskState.State',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='INITIATED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ACCEPTED', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REJECTED', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UPDATE', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UPDATE_REJECTED', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ABORT', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ABORTED', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ABORT_FAILED', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RESULT_AVAILABLE', index=8, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COMPLETED', index=9, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILED', index=10, number=10,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=261,
  serialized_end=435,
)
_sym_db.RegisterEnumDescriptor(_TASKSTATE_STATE)

_TASKSTATE_ORIGIN = _descriptor.EnumDescriptor(
  name='Origin',
  full_name='rst.communicationpatterns.TaskState.Origin',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUBMITTER', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HANDLER', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=437,
  serialized_end=473,
)
_sym_db.RegisterEnumDescriptor(_TASKSTATE_ORIGIN)


_TASKSTATE = _descriptor.Descriptor(
  name='TaskState',
  full_name='rst.communicationpatterns.TaskState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='origin', full_name='rst.communicationpatterns.TaskState.origin', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='state', full_name='rst.communicationpatterns.TaskState.state', index=1,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='serial', full_name='rst.communicationpatterns.TaskState.serial', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='wire_schema', full_name='rst.communicationpatterns.TaskState.wire_schema', index=3,
      number=4, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='payload', full_name='rst.communicationpatterns.TaskState.payload', index=4,
      number=5, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TASKSTATE_STATE,
    _TASKSTATE_ORIGIN,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=73,
  serialized_end=473,
)

_TASKSTATE.fields_by_name['origin'].enum_type = _TASKSTATE_ORIGIN
_TASKSTATE.fields_by_name['state'].enum_type = _TASKSTATE_STATE
_TASKSTATE_STATE.containing_type = _TASKSTATE
_TASKSTATE_ORIGIN.containing_type = _TASKSTATE
DESCRIPTOR.message_types_by_name['TaskState'] = _TASKSTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TaskState = _reflection.GeneratedProtocolMessageType('TaskState', (_message.Message,), dict(
  DESCRIPTOR = _TASKSTATE,
  __module__ = 'rst.communicationpatterns.TaskState_pb2'
  # @@protoc_insertion_point(class_scope:rst.communicationpatterns.TaskState)
  ))
_sym_db.RegisterMessage(TaskState)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\rTaskStateType'))
# @@protoc_insertion_point(module_scope)
