# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/geometry/RotationCollection.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.geometry import Rotation_pb2 as rst_dot_geometry_dot_Rotation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/geometry/RotationCollection.proto',
  package='rst.geometry',
  syntax='proto2',
  serialized_pb=_b('\n%rst/geometry/RotationCollection.proto\x12\x0crst.geometry\x1a\x1brst/geometry/Rotation.proto\"=\n\x12RotationCollection\x12\'\n\x07\x65lement\x18\x01 \x03(\x0b\x32\x16.rst.geometry.RotationB\x18\x42\x16RotationCollectionType')
  ,
  dependencies=[rst_dot_geometry_dot_Rotation__pb2.DESCRIPTOR,])




_ROTATIONCOLLECTION = _descriptor.Descriptor(
  name='RotationCollection',
  full_name='rst.geometry.RotationCollection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='element', full_name='rst.geometry.RotationCollection.element', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=84,
  serialized_end=145,
)

_ROTATIONCOLLECTION.fields_by_name['element'].message_type = rst_dot_geometry_dot_Rotation__pb2._ROTATION
DESCRIPTOR.message_types_by_name['RotationCollection'] = _ROTATIONCOLLECTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RotationCollection = _reflection.GeneratedProtocolMessageType('RotationCollection', (_message.Message,), dict(
  DESCRIPTOR = _ROTATIONCOLLECTION,
  __module__ = 'rst.geometry.RotationCollection_pb2'
  # @@protoc_insertion_point(class_scope:rst.geometry.RotationCollection)
  ))
_sym_db.RegisterMessage(RotationCollection)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\026RotationCollectionType'))
# @@protoc_insertion_point(module_scope)
