# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/generic/Dictionary.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.generic import KeyValuePair_pb2 as rst_dot_generic_dot_KeyValuePair__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/generic/Dictionary.proto',
  package='rst.generic',
  syntax='proto2',
  serialized_pb=_b('\n\x1crst/generic/Dictionary.proto\x12\x0brst.generic\x1a\x1erst/generic/KeyValuePair.proto\"8\n\nDictionary\x12*\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x19.rst.generic.KeyValuePairB\x10\x42\x0e\x44ictionaryType')
  ,
  dependencies=[rst_dot_generic_dot_KeyValuePair__pb2.DESCRIPTOR,])




_DICTIONARY = _descriptor.Descriptor(
  name='Dictionary',
  full_name='rst.generic.Dictionary',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entries', full_name='rst.generic.Dictionary.entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=77,
  serialized_end=133,
)

_DICTIONARY.fields_by_name['entries'].message_type = rst_dot_generic_dot_KeyValuePair__pb2._KEYVALUEPAIR
DESCRIPTOR.message_types_by_name['Dictionary'] = _DICTIONARY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Dictionary = _reflection.GeneratedProtocolMessageType('Dictionary', (_message.Message,), dict(
  DESCRIPTOR = _DICTIONARY,
  __module__ = 'rst.generic.Dictionary_pb2'
  # @@protoc_insertion_point(class_scope:rst.generic.Dictionary)
  ))
_sym_db.RegisterMessage(Dictionary)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\016DictionaryType'))
# @@protoc_insertion_point(module_scope)
