# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/devices/generic/BatteryState.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/devices/generic/BatteryState.proto',
  package='rst.devices.generic',
  syntax='proto2',
  serialized_pb=_b('\n&rst/devices/generic/BatteryState.proto\x12\x13rst.devices.generic\"R\n\x0c\x42\x61tteryState\x12\x0f\n\x07\x63urrent\x18\x01 \x01(\x02\x12\x14\n\x0c\x63harge_level\x18\x02 \x02(\x02\x12\x1b\n\x13\x62\x61ttery_temperature\x18\x03 \x01(\x02\x42\x12\x42\x10\x42\x61tteryStateType')
)




_BATTERYSTATE = _descriptor.Descriptor(
  name='BatteryState',
  full_name='rst.devices.generic.BatteryState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='current', full_name='rst.devices.generic.BatteryState.current', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='charge_level', full_name='rst.devices.generic.BatteryState.charge_level', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='battery_temperature', full_name='rst.devices.generic.BatteryState.battery_temperature', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=63,
  serialized_end=145,
)

DESCRIPTOR.message_types_by_name['BatteryState'] = _BATTERYSTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BatteryState = _reflection.GeneratedProtocolMessageType('BatteryState', (_message.Message,), dict(
  DESCRIPTOR = _BATTERYSTATE,
  __module__ = 'rst.devices.generic.BatteryState_pb2'
  # @@protoc_insertion_point(class_scope:rst.devices.generic.BatteryState)
  ))
_sym_db.RegisterMessage(BatteryState)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\020BatteryStateType'))
# @@protoc_insertion_point(module_scope)
