# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/vision/Image.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/vision/Image.proto',
  package='rst.vision',
  syntax='proto2',
  serialized_pb=_b('\n\x16rst/vision/Image.proto\x12\nrst.vision\"\xc3\x03\n\x05Image\x12\x0c\n\x04\x64\x61ta\x18\x01 \x02(\x0c\x12\r\n\x05width\x18\x02 \x02(\r\x12\x0e\n\x06height\x18\x03 \x02(\r\x12\x13\n\x08\x63hannels\x18\x04 \x01(\r:\x01\x33\x12\x30\n\x05\x64\x65pth\x18\x05 \x01(\x0e\x32\x17.rst.vision.Image.Depth:\x08\x44\x45PTH_8U\x12:\n\ncolor_mode\x18\x06 \x01(\x0e\x32\x1b.rst.vision.Image.ColorMode:\tCOLOR_RGB\x12>\n\ndata_order\x18\x07 \x01(\x0e\x32\x1b.rst.vision.Image.DataOrder:\rDATA_SEPARATE\"3\n\x05\x44\x65pth\x12\x0c\n\x08\x44\x45PTH_8U\x10\x08\x12\r\n\tDEPTH_16U\x10\x10\x12\r\n\tDEPTH_32F\x10 \"_\n\tColorMode\x12\x13\n\x0f\x43OLOR_GRAYSCALE\x10\x00\x12\r\n\tCOLOR_RGB\x10\x01\x12\r\n\tCOLOR_BGR\x10\x02\x12\r\n\tCOLOR_YUV\x10\x04\x12\x10\n\x0c\x43OLOR_YUV422\x10\x08\"4\n\tDataOrder\x12\x11\n\rDATA_SEPARATE\x10\x00\x12\x14\n\x10\x44\x41TA_INTERLEAVED\x10\x01\x42\x0b\x42\tImageType')
)



_IMAGE_DEPTH = _descriptor.EnumDescriptor(
  name='Depth',
  full_name='rst.vision.Image.Depth',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DEPTH_8U', index=0, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEPTH_16U', index=1, number=16,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEPTH_32F', index=2, number=32,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=288,
  serialized_end=339,
)
_sym_db.RegisterEnumDescriptor(_IMAGE_DEPTH)

_IMAGE_COLORMODE = _descriptor.EnumDescriptor(
  name='ColorMode',
  full_name='rst.vision.Image.ColorMode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='COLOR_GRAYSCALE', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COLOR_RGB', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COLOR_BGR', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COLOR_YUV', index=3, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COLOR_YUV422', index=4, number=8,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=341,
  serialized_end=436,
)
_sym_db.RegisterEnumDescriptor(_IMAGE_COLORMODE)

_IMAGE_DATAORDER = _descriptor.EnumDescriptor(
  name='DataOrder',
  full_name='rst.vision.Image.DataOrder',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DATA_SEPARATE', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DATA_INTERLEAVED', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=438,
  serialized_end=490,
)
_sym_db.RegisterEnumDescriptor(_IMAGE_DATAORDER)


_IMAGE = _descriptor.Descriptor(
  name='Image',
  full_name='rst.vision.Image',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='rst.vision.Image.data', index=0,
      number=1, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='width', full_name='rst.vision.Image.width', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='height', full_name='rst.vision.Image.height', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='channels', full_name='rst.vision.Image.channels', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=3,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='depth', full_name='rst.vision.Image.depth', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=8,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='color_mode', full_name='rst.vision.Image.color_mode', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='data_order', full_name='rst.vision.Image.data_order', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _IMAGE_DEPTH,
    _IMAGE_COLORMODE,
    _IMAGE_DATAORDER,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=39,
  serialized_end=490,
)

_IMAGE.fields_by_name['depth'].enum_type = _IMAGE_DEPTH
_IMAGE.fields_by_name['color_mode'].enum_type = _IMAGE_COLORMODE
_IMAGE.fields_by_name['data_order'].enum_type = _IMAGE_DATAORDER
_IMAGE_DEPTH.containing_type = _IMAGE
_IMAGE_COLORMODE.containing_type = _IMAGE
_IMAGE_DATAORDER.containing_type = _IMAGE
DESCRIPTOR.message_types_by_name['Image'] = _IMAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Image = _reflection.GeneratedProtocolMessageType('Image', (_message.Message,), dict(
  DESCRIPTOR = _IMAGE,
  __module__ = 'rst.vision.Image_pb2'
  # @@protoc_insertion_point(class_scope:rst.vision.Image)
  ))
_sym_db.RegisterMessage(Image)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\tImageType'))
# @@protoc_insertion_point(module_scope)
