# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/calendar/CalendarUpdate.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.calendar import Event_pb2 as rst_dot_calendar_dot_Event__pb2
from rst.calendar import Todo_pb2 as rst_dot_calendar_dot_Todo__pb2
from rst.calendar import TimeZone_pb2 as rst_dot_calendar_dot_TimeZone__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/calendar/CalendarUpdate.proto',
  package='rst.calendar',
  syntax='proto2',
  serialized_pb=_b('\n!rst/calendar/CalendarUpdate.proto\x12\x0crst.calendar\x1a\x18rst/calendar/Event.proto\x1a\x17rst/calendar/Todo.proto\x1a\x1brst/calendar/TimeZone.proto\"\xae\x01\n\x0e\x43\x61lendarUpdate\x12)\n\ttimezones\x18\x03 \x03(\x0b\x32\x16.rst.calendar.TimeZone\x12+\n\x0e\x63hanged_events\x18\x04 \x03(\x0b\x32\x13.rst.calendar.Event\x12)\n\rchanged_todos\x18\x05 \x03(\x0b\x32\x12.rst.calendar.Todo\x12\x19\n\x11removed_entry_ids\x18\x06 \x03(\tB\x14\x42\x12\x43\x61lendarUpdateType')
  ,
  dependencies=[rst_dot_calendar_dot_Event__pb2.DESCRIPTOR,rst_dot_calendar_dot_Todo__pb2.DESCRIPTOR,rst_dot_calendar_dot_TimeZone__pb2.DESCRIPTOR,])




_CALENDARUPDATE = _descriptor.Descriptor(
  name='CalendarUpdate',
  full_name='rst.calendar.CalendarUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timezones', full_name='rst.calendar.CalendarUpdate.timezones', index=0,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='changed_events', full_name='rst.calendar.CalendarUpdate.changed_events', index=1,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='changed_todos', full_name='rst.calendar.CalendarUpdate.changed_todos', index=2,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='removed_entry_ids', full_name='rst.calendar.CalendarUpdate.removed_entry_ids', index=3,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=132,
  serialized_end=306,
)

_CALENDARUPDATE.fields_by_name['timezones'].message_type = rst_dot_calendar_dot_TimeZone__pb2._TIMEZONE
_CALENDARUPDATE.fields_by_name['changed_events'].message_type = rst_dot_calendar_dot_Event__pb2._EVENT
_CALENDARUPDATE.fields_by_name['changed_todos'].message_type = rst_dot_calendar_dot_Todo__pb2._TODO
DESCRIPTOR.message_types_by_name['CalendarUpdate'] = _CALENDARUPDATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CalendarUpdate = _reflection.GeneratedProtocolMessageType('CalendarUpdate', (_message.Message,), dict(
  DESCRIPTOR = _CALENDARUPDATE,
  __module__ = 'rst.calendar.CalendarUpdate_pb2'
  # @@protoc_insertion_point(class_scope:rst.calendar.CalendarUpdate)
  ))
_sym_db.RegisterMessage(CalendarUpdate)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\022CalendarUpdateType'))
# @@protoc_insertion_point(module_scope)
