# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/statemachine/StateChange.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/statemachine/StateChange.proto',
  package='rst.statemachine',
  syntax='proto2',
  serialized_pb=_b('\n\"rst/statemachine/StateChange.proto\x12\x10rst.statemachine\"S\n\x0bStateChange\x12\x12\n\nfrom_state\x18\x01 \x02(\t\x12\x10\n\x08to_state\x18\x02 \x02(\t\x12\r\n\x05\x63\x61use\x18\x03 \x01(\t\x12\x0f\n\x07machine\x18\x04 \x01(\tB\x11\x42\x0fStateChangeType')
)




_STATECHANGE = _descriptor.Descriptor(
  name='StateChange',
  full_name='rst.statemachine.StateChange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='from_state', full_name='rst.statemachine.StateChange.from_state', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='to_state', full_name='rst.statemachine.StateChange.to_state', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cause', full_name='rst.statemachine.StateChange.cause', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='machine', full_name='rst.statemachine.StateChange.machine', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=56,
  serialized_end=139,
)

DESCRIPTOR.message_types_by_name['StateChange'] = _STATECHANGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StateChange = _reflection.GeneratedProtocolMessageType('StateChange', (_message.Message,), dict(
  DESCRIPTOR = _STATECHANGE,
  __module__ = 'rst.statemachine.StateChange_pb2'
  # @@protoc_insertion_point(class_scope:rst.statemachine.StateChange)
  ))
_sym_db.RegisterMessage(StateChange)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\017StateChangeType'))
# @@protoc_insertion_point(module_scope)
