# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/math/MatrixDouble.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/math/MatrixDouble.proto',
  package='rst.math',
  syntax='proto2',
  serialized_pb=_b('\n\x1brst/math/MatrixDouble.proto\x12\x08rst.math\"\x9d\x01\n\x0cMatrixDouble\x12)\n\x04size\x18\x01 \x02(\x0b\x32\x1b.rst.math.MatrixDouble.Size\x12)\n\x04\x64\x61ta\x18\x02 \x02(\x0b\x32\x1b.rst.math.MatrixDouble.Data\x1a\x1c\n\x04Size\x12\t\n\x01m\x18\x01 \x02(\r\x12\t\n\x01n\x18\x02 \x02(\r\x1a\x19\n\x04\x44\x61ta\x12\x11\n\x05value\x18\x01 \x03(\x01\x42\x02\x10\x01\x42\x12\x42\x10MatrixDoubleType')
)




_MATRIXDOUBLE_SIZE = _descriptor.Descriptor(
  name='Size',
  full_name='rst.math.MatrixDouble.Size',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='m', full_name='rst.math.MatrixDouble.Size.m', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='n', full_name='rst.math.MatrixDouble.Size.n', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=144,
  serialized_end=172,
)

_MATRIXDOUBLE_DATA = _descriptor.Descriptor(
  name='Data',
  full_name='rst.math.MatrixDouble.Data',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='rst.math.MatrixDouble.Data.value', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=174,
  serialized_end=199,
)

_MATRIXDOUBLE = _descriptor.Descriptor(
  name='MatrixDouble',
  full_name='rst.math.MatrixDouble',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='size', full_name='rst.math.MatrixDouble.size', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='data', full_name='rst.math.MatrixDouble.data', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_MATRIXDOUBLE_SIZE, _MATRIXDOUBLE_DATA, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=42,
  serialized_end=199,
)

_MATRIXDOUBLE_SIZE.containing_type = _MATRIXDOUBLE
_MATRIXDOUBLE_DATA.containing_type = _MATRIXDOUBLE
_MATRIXDOUBLE.fields_by_name['size'].message_type = _MATRIXDOUBLE_SIZE
_MATRIXDOUBLE.fields_by_name['data'].message_type = _MATRIXDOUBLE_DATA
DESCRIPTOR.message_types_by_name['MatrixDouble'] = _MATRIXDOUBLE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MatrixDouble = _reflection.GeneratedProtocolMessageType('MatrixDouble', (_message.Message,), dict(

  Size = _reflection.GeneratedProtocolMessageType('Size', (_message.Message,), dict(
    DESCRIPTOR = _MATRIXDOUBLE_SIZE,
    __module__ = 'rst.math.MatrixDouble_pb2'
    # @@protoc_insertion_point(class_scope:rst.math.MatrixDouble.Size)
    ))
  ,

  Data = _reflection.GeneratedProtocolMessageType('Data', (_message.Message,), dict(
    DESCRIPTOR = _MATRIXDOUBLE_DATA,
    __module__ = 'rst.math.MatrixDouble_pb2'
    # @@protoc_insertion_point(class_scope:rst.math.MatrixDouble.Data)
    ))
  ,
  DESCRIPTOR = _MATRIXDOUBLE,
  __module__ = 'rst.math.MatrixDouble_pb2'
  # @@protoc_insertion_point(class_scope:rst.math.MatrixDouble)
  ))
_sym_db.RegisterMessage(MatrixDouble)
_sym_db.RegisterMessage(MatrixDouble.Size)
_sym_db.RegisterMessage(MatrixDouble.Data)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\020MatrixDoubleType'))
_MATRIXDOUBLE_DATA.fields_by_name['value'].has_options = True
_MATRIXDOUBLE_DATA.fields_by_name['value']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))
# @@protoc_insertion_point(module_scope)
