# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/calendar/Organizer.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/calendar/Organizer.proto',
  package='rst.calendar',
  syntax='proto2',
  serialized_pb=_b('\n\x1crst/calendar/Organizer.proto\x12\x0crst.calendar\"p\n\tOrganizer\x12\x18\n\x10\x63\x61lendar_address\x18\x01 \x02(\t\x12\x13\n\x0b\x63ommon_name\x18\x02 \x01(\t\x12\x11\n\tdirectory\x18\x03 \x01(\t\x12\x0f\n\x07sent_by\x18\x04 \x01(\t\x12\x10\n\x08language\x18\x05 \x01(\tB\x0f\x42\rOrganizerType')
)




_ORGANIZER = _descriptor.Descriptor(
  name='Organizer',
  full_name='rst.calendar.Organizer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='calendar_address', full_name='rst.calendar.Organizer.calendar_address', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='common_name', full_name='rst.calendar.Organizer.common_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='directory', full_name='rst.calendar.Organizer.directory', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sent_by', full_name='rst.calendar.Organizer.sent_by', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='language', full_name='rst.calendar.Organizer.language', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=46,
  serialized_end=158,
)

DESCRIPTOR.message_types_by_name['Organizer'] = _ORGANIZER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Organizer = _reflection.GeneratedProtocolMessageType('Organizer', (_message.Message,), dict(
  DESCRIPTOR = _ORGANIZER,
  __module__ = 'rst.calendar.Organizer_pb2'
  # @@protoc_insertion_point(class_scope:rst.calendar.Organizer)
  ))
_sym_db.RegisterMessage(Organizer)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\rOrganizerType'))
# @@protoc_insertion_point(module_scope)
