# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/navigation/LabelCommand.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.navigation import ExecutionParameters_pb2 as rst_dot_navigation_dot_ExecutionParameters__pb2
from rst.navigation import MotionParameters_pb2 as rst_dot_navigation_dot_MotionParameters__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/navigation/LabelCommand.proto',
  package='rst.navigation',
  syntax='proto2',
  serialized_pb=_b('\n!rst/navigation/LabelCommand.proto\x12\x0erst.navigation\x1a(rst/navigation/ExecutionParameters.proto\x1a%rst/navigation/MotionParameters.proto\"\x9c\x01\n\x0cLabelCommand\x12\x0c\n\x04goal\x18\x01 \x02(\t\x12;\n\x11motion_parameters\x18\x02 \x01(\x0b\x32 .rst.navigation.MotionParameters\x12\x41\n\x14\x65xecution_parameters\x18\x03 \x01(\x0b\x32#.rst.navigation.ExecutionParametersB\x12\x42\x10LabelCommandType')
  ,
  dependencies=[rst_dot_navigation_dot_ExecutionParameters__pb2.DESCRIPTOR,rst_dot_navigation_dot_MotionParameters__pb2.DESCRIPTOR,])




_LABELCOMMAND = _descriptor.Descriptor(
  name='LabelCommand',
  full_name='rst.navigation.LabelCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='goal', full_name='rst.navigation.LabelCommand.goal', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='motion_parameters', full_name='rst.navigation.LabelCommand.motion_parameters', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='execution_parameters', full_name='rst.navigation.LabelCommand.execution_parameters', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=135,
  serialized_end=291,
)

_LABELCOMMAND.fields_by_name['motion_parameters'].message_type = rst_dot_navigation_dot_MotionParameters__pb2._MOTIONPARAMETERS
_LABELCOMMAND.fields_by_name['execution_parameters'].message_type = rst_dot_navigation_dot_ExecutionParameters__pb2._EXECUTIONPARAMETERS
DESCRIPTOR.message_types_by_name['LabelCommand'] = _LABELCOMMAND
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LabelCommand = _reflection.GeneratedProtocolMessageType('LabelCommand', (_message.Message,), dict(
  DESCRIPTOR = _LABELCOMMAND,
  __module__ = 'rst.navigation.LabelCommand_pb2'
  # @@protoc_insertion_point(class_scope:rst.navigation.LabelCommand)
  ))
_sym_db.RegisterMessage(LabelCommand)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\020LabelCommandType'))
# @@protoc_insertion_point(module_scope)
