# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/tracking/TrackedPosture3DFloat.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.tracking import TrackingInfo_pb2 as rst_dot_tracking_dot_TrackingInfo__pb2
from rst.kinematics import Posture3DFloat_pb2 as rst_dot_kinematics_dot_Posture3DFloat__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/tracking/TrackedPosture3DFloat.proto',
  package='rst.tracking',
  syntax='proto2',
  serialized_pb=_b('\n(rst/tracking/TrackedPosture3DFloat.proto\x12\x0crst.tracking\x1a\x1frst/tracking/TrackingInfo.proto\x1a#rst/kinematics/Posture3DFloat.proto\"\x86\x01\n\x15TrackedPosture3DFloat\x12(\n\x04info\x18\x01 \x02(\x0b\x32\x1a.rst.tracking.TrackingInfo\x12/\n\x07posture\x18\x02 \x02(\x0b\x32\x1e.rst.kinematics.Posture3DFloat\x12\x12\n\nconfidence\x18\x03 \x03(\x02\x42\x1b\x42\x19TrackedPosture3DFloatType')
  ,
  dependencies=[rst_dot_tracking_dot_TrackingInfo__pb2.DESCRIPTOR,rst_dot_kinematics_dot_Posture3DFloat__pb2.DESCRIPTOR,])




_TRACKEDPOSTURE3DFLOAT = _descriptor.Descriptor(
  name='TrackedPosture3DFloat',
  full_name='rst.tracking.TrackedPosture3DFloat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='info', full_name='rst.tracking.TrackedPosture3DFloat.info', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='posture', full_name='rst.tracking.TrackedPosture3DFloat.posture', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='confidence', full_name='rst.tracking.TrackedPosture3DFloat.confidence', index=2,
      number=3, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=129,
  serialized_end=263,
)

_TRACKEDPOSTURE3DFLOAT.fields_by_name['info'].message_type = rst_dot_tracking_dot_TrackingInfo__pb2._TRACKINGINFO
_TRACKEDPOSTURE3DFLOAT.fields_by_name['posture'].message_type = rst_dot_kinematics_dot_Posture3DFloat__pb2._POSTURE3DFLOAT
DESCRIPTOR.message_types_by_name['TrackedPosture3DFloat'] = _TRACKEDPOSTURE3DFLOAT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TrackedPosture3DFloat = _reflection.GeneratedProtocolMessageType('TrackedPosture3DFloat', (_message.Message,), dict(
  DESCRIPTOR = _TRACKEDPOSTURE3DFLOAT,
  __module__ = 'rst.tracking.TrackedPosture3DFloat_pb2'
  # @@protoc_insertion_point(class_scope:rst.tracking.TrackedPosture3DFloat)
  ))
_sym_db.RegisterMessage(TrackedPosture3DFloat)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\031TrackedPosture3DFloatType'))
# @@protoc_insertion_point(module_scope)
