# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/tracking/TrackedPositions3DFloat.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.tracking import TrackedPosition3DFloat_pb2 as rst_dot_tracking_dot_TrackedPosition3DFloat__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/tracking/TrackedPositions3DFloat.proto',
  package='rst.tracking',
  syntax='proto2',
  serialized_pb=_b('\n*rst/tracking/TrackedPositions3DFloat.proto\x12\x0crst.tracking\x1a)rst/tracking/TrackedPosition3DFloat.proto\"Q\n\x17TrackedPositions3DFloat\x12\x36\n\x08position\x18\x01 \x03(\x0b\x32$.rst.tracking.TrackedPosition3DFloatB\x1d\x42\x1bTrackedPositions3DFloatType')
  ,
  dependencies=[rst_dot_tracking_dot_TrackedPosition3DFloat__pb2.DESCRIPTOR,])




_TRACKEDPOSITIONS3DFLOAT = _descriptor.Descriptor(
  name='TrackedPositions3DFloat',
  full_name='rst.tracking.TrackedPositions3DFloat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='position', full_name='rst.tracking.TrackedPositions3DFloat.position', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=103,
  serialized_end=184,
)

_TRACKEDPOSITIONS3DFLOAT.fields_by_name['position'].message_type = rst_dot_tracking_dot_TrackedPosition3DFloat__pb2._TRACKEDPOSITION3DFLOAT
DESCRIPTOR.message_types_by_name['TrackedPositions3DFloat'] = _TRACKEDPOSITIONS3DFLOAT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TrackedPositions3DFloat = _reflection.GeneratedProtocolMessageType('TrackedPositions3DFloat', (_message.Message,), dict(
  DESCRIPTOR = _TRACKEDPOSITIONS3DFLOAT,
  __module__ = 'rst.tracking.TrackedPositions3DFloat_pb2'
  # @@protoc_insertion_point(class_scope:rst.tracking.TrackedPositions3DFloat)
  ))
_sym_db.RegisterMessage(TrackedPositions3DFloat)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\033TrackedPositions3DFloatType'))
# @@protoc_insertion_point(module_scope)
