# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/timing/Point2DTimeseries.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.timing import Point2DTimestampPair_pb2 as rst_dot_timing_dot_Point2DTimestampPair__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/timing/Point2DTimeseries.proto',
  package='rst.timing',
  syntax='proto2',
  serialized_pb=_b('\n\"rst/timing/Point2DTimeseries.proto\x12\nrst.timing\x1a%rst/timing/Point2DTimestampPair.proto\"D\n\x11Point2DTimeseries\x12/\n\x05\x65ntry\x18\x01 \x03(\x0b\x32 .rst.timing.Point2DTimestampPairB\x17\x42\x15Point2DTimeseriesType')
  ,
  dependencies=[rst_dot_timing_dot_Point2DTimestampPair__pb2.DESCRIPTOR,])




_POINT2DTIMESERIES = _descriptor.Descriptor(
  name='Point2DTimeseries',
  full_name='rst.timing.Point2DTimeseries',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entry', full_name='rst.timing.Point2DTimeseries.entry', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=89,
  serialized_end=157,
)

_POINT2DTIMESERIES.fields_by_name['entry'].message_type = rst_dot_timing_dot_Point2DTimestampPair__pb2._POINT2DTIMESTAMPPAIR
DESCRIPTOR.message_types_by_name['Point2DTimeseries'] = _POINT2DTIMESERIES
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Point2DTimeseries = _reflection.GeneratedProtocolMessageType('Point2DTimeseries', (_message.Message,), dict(
  DESCRIPTOR = _POINT2DTIMESERIES,
  __module__ = 'rst.timing.Point2DTimeseries_pb2'
  # @@protoc_insertion_point(class_scope:rst.timing.Point2DTimeseries)
  ))
_sym_db.RegisterMessage(Point2DTimeseries)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\025Point2DTimeseriesType'))
# @@protoc_insertion_point(module_scope)
