# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/audition/Utterance.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.audition import PhonemeCollection_pb2 as rst_dot_audition_dot_PhonemeCollection__pb2
from rst.audition import SoundChunk_pb2 as rst_dot_audition_dot_SoundChunk__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/audition/Utterance.proto',
  package='rst.audition',
  syntax='proto2',
  serialized_pb=_b('\n\x1crst/audition/Utterance.proto\x12\x0crst.audition\x1a$rst/audition/PhonemeCollection.proto\x1a\x1drst/audition/SoundChunk.proto\"\x87\x01\n\tUtterance\x12\x31\n\x08phonemes\x18\x01 \x02(\x0b\x32\x1f.rst.audition.PhonemeCollection\x12\'\n\x05\x61udio\x18\x02 \x02(\x0b\x32\x18.rst.audition.SoundChunk\x12\x1e\n\x16textual_representation\x18\x03 \x02(\tB\x0f\x42\rUtteranceType')
  ,
  dependencies=[rst_dot_audition_dot_PhonemeCollection__pb2.DESCRIPTOR,rst_dot_audition_dot_SoundChunk__pb2.DESCRIPTOR,])




_UTTERANCE = _descriptor.Descriptor(
  name='Utterance',
  full_name='rst.audition.Utterance',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='phonemes', full_name='rst.audition.Utterance.phonemes', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='audio', full_name='rst.audition.Utterance.audio', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='textual_representation', full_name='rst.audition.Utterance.textual_representation', index=2,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=116,
  serialized_end=251,
)

_UTTERANCE.fields_by_name['phonemes'].message_type = rst_dot_audition_dot_PhonemeCollection__pb2._PHONEMECOLLECTION
_UTTERANCE.fields_by_name['audio'].message_type = rst_dot_audition_dot_SoundChunk__pb2._SOUNDCHUNK
DESCRIPTOR.message_types_by_name['Utterance'] = _UTTERANCE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Utterance = _reflection.GeneratedProtocolMessageType('Utterance', (_message.Message,), dict(
  DESCRIPTOR = _UTTERANCE,
  __module__ = 'rst.audition.Utterance_pb2'
  # @@protoc_insertion_point(class_scope:rst.audition.Utterance)
  ))
_sym_db.RegisterMessage(Utterance)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\rUtteranceType'))
# @@protoc_insertion_point(module_scope)
