# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/vision/LocatedXYZImage.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.geometry import ViewFrustum_pb2 as rst_dot_geometry_dot_ViewFrustum__pb2
from rst.geometry import CameraPose_pb2 as rst_dot_geometry_dot_CameraPose__pb2
from rst.vision import SimpleXYZImage_pb2 as rst_dot_vision_dot_SimpleXYZImage__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/vision/LocatedXYZImage.proto',
  package='rst.vision',
  syntax='proto2',
  serialized_pb=_b('\n rst/vision/LocatedXYZImage.proto\x12\nrst.vision\x1a\x1erst/geometry/ViewFrustum.proto\x1a\x1drst/geometry/CameraPose.proto\x1a\x1frst/vision/SimpleXYZImage.proto\"\x92\x01\n\x0fLocatedXYZImage\x12)\n\x05image\x18\x01 \x02(\x0b\x32\x1a.rst.vision.SimpleXYZImage\x12(\n\x06\x63\x61mera\x18\x02 \x02(\x0b\x32\x18.rst.geometry.CameraPose\x12*\n\x07\x66rustum\x18\x03 \x02(\x0b\x32\x19.rst.geometry.ViewFrustumB\x15\x42\x13LocatedXYZImageType')
  ,
  dependencies=[rst_dot_geometry_dot_ViewFrustum__pb2.DESCRIPTOR,rst_dot_geometry_dot_CameraPose__pb2.DESCRIPTOR,rst_dot_vision_dot_SimpleXYZImage__pb2.DESCRIPTOR,])




_LOCATEDXYZIMAGE = _descriptor.Descriptor(
  name='LocatedXYZImage',
  full_name='rst.vision.LocatedXYZImage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='image', full_name='rst.vision.LocatedXYZImage.image', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='camera', full_name='rst.vision.LocatedXYZImage.camera', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='frustum', full_name='rst.vision.LocatedXYZImage.frustum', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=145,
  serialized_end=291,
)

_LOCATEDXYZIMAGE.fields_by_name['image'].message_type = rst_dot_vision_dot_SimpleXYZImage__pb2._SIMPLEXYZIMAGE
_LOCATEDXYZIMAGE.fields_by_name['camera'].message_type = rst_dot_geometry_dot_CameraPose__pb2._CAMERAPOSE
_LOCATEDXYZIMAGE.fields_by_name['frustum'].message_type = rst_dot_geometry_dot_ViewFrustum__pb2._VIEWFRUSTUM
DESCRIPTOR.message_types_by_name['LocatedXYZImage'] = _LOCATEDXYZIMAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LocatedXYZImage = _reflection.GeneratedProtocolMessageType('LocatedXYZImage', (_message.Message,), dict(
  DESCRIPTOR = _LOCATEDXYZIMAGE,
  __module__ = 'rst.vision.LocatedXYZImage_pb2'
  # @@protoc_insertion_point(class_scope:rst.vision.LocatedXYZImage)
  ))
_sym_db.RegisterMessage(LocatedXYZImage)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\023LocatedXYZImageType'))
# @@protoc_insertion_point(module_scope)
