# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/tracking/TrackedClassifiedRegion3D.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.tracking import TrackingInfo_pb2 as rst_dot_tracking_dot_TrackingInfo__pb2
from rst.classification import ClassifiedRegion3D_pb2 as rst_dot_classification_dot_ClassifiedRegion3D__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/tracking/TrackedClassifiedRegion3D.proto',
  package='rst.tracking',
  syntax='proto2',
  serialized_pb=_b('\n,rst/tracking/TrackedClassifiedRegion3D.proto\x12\x0crst.tracking\x1a\x1frst/tracking/TrackingInfo.proto\x1a+rst/classification/ClassifiedRegion3D.proto\"}\n\x19TrackedClassifiedRegion3D\x12(\n\x04info\x18\x01 \x02(\x0b\x32\x1a.rst.tracking.TrackingInfo\x12\x36\n\x06region\x18\x02 \x02(\x0b\x32&.rst.classification.ClassifiedRegion3DB\x1f\x42\x1dTrackedClassifiedRegion3DType')
  ,
  dependencies=[rst_dot_tracking_dot_TrackingInfo__pb2.DESCRIPTOR,rst_dot_classification_dot_ClassifiedRegion3D__pb2.DESCRIPTOR,])




_TRACKEDCLASSIFIEDREGION3D = _descriptor.Descriptor(
  name='TrackedClassifiedRegion3D',
  full_name='rst.tracking.TrackedClassifiedRegion3D',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='info', full_name='rst.tracking.TrackedClassifiedRegion3D.info', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='region', full_name='rst.tracking.TrackedClassifiedRegion3D.region', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=140,
  serialized_end=265,
)

_TRACKEDCLASSIFIEDREGION3D.fields_by_name['info'].message_type = rst_dot_tracking_dot_TrackingInfo__pb2._TRACKINGINFO
_TRACKEDCLASSIFIEDREGION3D.fields_by_name['region'].message_type = rst_dot_classification_dot_ClassifiedRegion3D__pb2._CLASSIFIEDREGION3D
DESCRIPTOR.message_types_by_name['TrackedClassifiedRegion3D'] = _TRACKEDCLASSIFIEDREGION3D
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TrackedClassifiedRegion3D = _reflection.GeneratedProtocolMessageType('TrackedClassifiedRegion3D', (_message.Message,), dict(
  DESCRIPTOR = _TRACKEDCLASSIFIEDREGION3D,
  __module__ = 'rst.tracking.TrackedClassifiedRegion3D_pb2'
  # @@protoc_insertion_point(class_scope:rst.tracking.TrackedClassifiedRegion3D)
  ))
_sym_db.RegisterMessage(TrackedClassifiedRegion3D)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\035TrackedClassifiedRegion3DType'))
# @@protoc_insertion_point(module_scope)
