# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/calendar/Entry.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.calendar import TimeZone_pb2 as rst_dot_calendar_dot_TimeZone__pb2
from rst.calendar import DateTime_pb2 as rst_dot_calendar_dot_DateTime__pb2
from rst.calendar import RecurrenceId_pb2 as rst_dot_calendar_dot_RecurrenceId__pb2
from rst.calendar import Attendee_pb2 as rst_dot_calendar_dot_Attendee__pb2
from rst.calendar import Organizer_pb2 as rst_dot_calendar_dot_Organizer__pb2
from rst.calendar import Recurrence_pb2 as rst_dot_calendar_dot_Recurrence__pb2
from rst.calendar import RequestStatus_pb2 as rst_dot_calendar_dot_RequestStatus__pb2
from rst.calendar import Relationship_pb2 as rst_dot_calendar_dot_Relationship__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/calendar/Entry.proto',
  package='rst.calendar',
  syntax='proto2',
  serialized_pb=_b('\n\x18rst/calendar/Entry.proto\x12\x0crst.calendar\x1a\x1brst/calendar/TimeZone.proto\x1a\x1brst/calendar/DateTime.proto\x1a\x1frst/calendar/RecurrenceId.proto\x1a\x1brst/calendar/Attendee.proto\x1a\x1crst/calendar/Organizer.proto\x1a\x1drst/calendar/Recurrence.proto\x1a rst/calendar/RequestStatus.proto\x1a\x1frst/calendar/Relationship.proto\"\xe5\x06\n\x05\x45ntry\x12:\n\nvisibility\x18\x01 \x01(\x0e\x32\x1e.rst.calendar.Entry.Visibility:\x06PUBLIC\x12+\n\x0b\x63reated_utc\x18\x02 \x01(\x0b\x32\x16.rst.calendar.DateTime\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12/\n\x0f\x64\x61te_time_start\x18\x04 \x01(\x0b\x32\x16.rst.calendar.DateTime\x12\x17\n\x0cgeo_latitude\x18\x05 \x01(\x01:\x01\x30\x12\x18\n\rgeo_longitude\x18\x06 \x01(\x01:\x01\x30\x12-\n\rlast_modified\x18\x07 \x01(\x0b\x32\x16.rst.calendar.DateTime\x12\x10\n\x08location\x18\x08 \x01(\t\x12*\n\torganizer\x18\t \x01(\x0b\x32\x17.rst.calendar.Organizer\x12\x13\n\x08priority\x18\n \x01(\r:\x01\x30\x12/\n\x0f\x64\x61te_time_stamp\x18\x0b \x01(\x0b\x32\x16.rst.calendar.DateTime\x12\x1a\n\x0fsequence_number\x18\x0c \x01(\r:\x01\x30\x12\x0f\n\x07summary\x18\r \x01(\t\x12\x0b\n\x03uid\x18\x0e \x01(\t\x12\x0b\n\x03url\x18\x0f \x01(\t\x12\x31\n\rrecurrence_id\x18\x10 \x01(\x0b\x32\x1a.rst.calendar.RecurrenceId\x12\x0e\n\x06\x61ttach\x18\x11 \x03(\t\x12)\n\tattendees\x18\x12 \x03(\x0b\x32\x16.rst.calendar.Attendee\x12\x12\n\ncategories\x18\x13 \x03(\t\x12\x10\n\x08\x63omments\x18\x14 \x03(\t\x12\x10\n\x08\x63ontacts\x18\x15 \x03(\t\x12,\n\nrecurrence\x18\x16 \x01(\x0b\x32\x18.rst.calendar.Recurrence\x12\x33\n\x0erequest_status\x18\x17 \x03(\x0b\x32\x1b.rst.calendar.RequestStatus\x12+\n\x07related\x18\x18 \x03(\x0b\x32\x1a.rst.calendar.Relationship\x12\x11\n\tresources\x18\x19 \x03(\t\"7\n\nVisibility\x12\n\n\x06PUBLIC\x10\x01\x12\x0b\n\x07PRIVATE\x10\x02\x12\x10\n\x0c\x43ONFIDENTIAL\x10\x03\x42\x0b\x42\tEntryType')
  ,
  dependencies=[rst_dot_calendar_dot_TimeZone__pb2.DESCRIPTOR,rst_dot_calendar_dot_DateTime__pb2.DESCRIPTOR,rst_dot_calendar_dot_RecurrenceId__pb2.DESCRIPTOR,rst_dot_calendar_dot_Attendee__pb2.DESCRIPTOR,rst_dot_calendar_dot_Organizer__pb2.DESCRIPTOR,rst_dot_calendar_dot_Recurrence__pb2.DESCRIPTOR,rst_dot_calendar_dot_RequestStatus__pb2.DESCRIPTOR,rst_dot_calendar_dot_Relationship__pb2.DESCRIPTOR,])



_ENTRY_VISIBILITY = _descriptor.EnumDescriptor(
  name='Visibility',
  full_name='rst.calendar.Entry.Visibility',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PUBLIC', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRIVATE', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONFIDENTIAL', index=2, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1105,
  serialized_end=1160,
)
_sym_db.RegisterEnumDescriptor(_ENTRY_VISIBILITY)


_ENTRY = _descriptor.Descriptor(
  name='Entry',
  full_name='rst.calendar.Entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='visibility', full_name='rst.calendar.Entry.visibility', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='created_utc', full_name='rst.calendar.Entry.created_utc', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='description', full_name='rst.calendar.Entry.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='date_time_start', full_name='rst.calendar.Entry.date_time_start', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='geo_latitude', full_name='rst.calendar.Entry.geo_latitude', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='geo_longitude', full_name='rst.calendar.Entry.geo_longitude', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='last_modified', full_name='rst.calendar.Entry.last_modified', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='location', full_name='rst.calendar.Entry.location', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='organizer', full_name='rst.calendar.Entry.organizer', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='priority', full_name='rst.calendar.Entry.priority', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='date_time_stamp', full_name='rst.calendar.Entry.date_time_stamp', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sequence_number', full_name='rst.calendar.Entry.sequence_number', index=11,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='summary', full_name='rst.calendar.Entry.summary', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='uid', full_name='rst.calendar.Entry.uid', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='url', full_name='rst.calendar.Entry.url', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='recurrence_id', full_name='rst.calendar.Entry.recurrence_id', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='attach', full_name='rst.calendar.Entry.attach', index=16,
      number=17, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='attendees', full_name='rst.calendar.Entry.attendees', index=17,
      number=18, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='categories', full_name='rst.calendar.Entry.categories', index=18,
      number=19, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='comments', full_name='rst.calendar.Entry.comments', index=19,
      number=20, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='contacts', full_name='rst.calendar.Entry.contacts', index=20,
      number=21, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='recurrence', full_name='rst.calendar.Entry.recurrence', index=21,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='request_status', full_name='rst.calendar.Entry.request_status', index=22,
      number=23, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='related', full_name='rst.calendar.Entry.related', index=23,
      number=24, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='resources', full_name='rst.calendar.Entry.resources', index=24,
      number=25, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ENTRY_VISIBILITY,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=291,
  serialized_end=1160,
)

_ENTRY.fields_by_name['visibility'].enum_type = _ENTRY_VISIBILITY
_ENTRY.fields_by_name['created_utc'].message_type = rst_dot_calendar_dot_DateTime__pb2._DATETIME
_ENTRY.fields_by_name['date_time_start'].message_type = rst_dot_calendar_dot_DateTime__pb2._DATETIME
_ENTRY.fields_by_name['last_modified'].message_type = rst_dot_calendar_dot_DateTime__pb2._DATETIME
_ENTRY.fields_by_name['organizer'].message_type = rst_dot_calendar_dot_Organizer__pb2._ORGANIZER
_ENTRY.fields_by_name['date_time_stamp'].message_type = rst_dot_calendar_dot_DateTime__pb2._DATETIME
_ENTRY.fields_by_name['recurrence_id'].message_type = rst_dot_calendar_dot_RecurrenceId__pb2._RECURRENCEID
_ENTRY.fields_by_name['attendees'].message_type = rst_dot_calendar_dot_Attendee__pb2._ATTENDEE
_ENTRY.fields_by_name['recurrence'].message_type = rst_dot_calendar_dot_Recurrence__pb2._RECURRENCE
_ENTRY.fields_by_name['request_status'].message_type = rst_dot_calendar_dot_RequestStatus__pb2._REQUESTSTATUS
_ENTRY.fields_by_name['related'].message_type = rst_dot_calendar_dot_Relationship__pb2._RELATIONSHIP
_ENTRY_VISIBILITY.containing_type = _ENTRY
DESCRIPTOR.message_types_by_name['Entry'] = _ENTRY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Entry = _reflection.GeneratedProtocolMessageType('Entry', (_message.Message,), dict(
  DESCRIPTOR = _ENTRY,
  __module__ = 'rst.calendar.Entry_pb2'
  # @@protoc_insertion_point(class_scope:rst.calendar.Entry)
  ))
_sym_db.RegisterMessage(Entry)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\tEntryType'))
# @@protoc_insertion_point(module_scope)
