# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/vision/FaceWithGaze.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.vision import Face_pb2 as rst_dot_vision_dot_Face__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/vision/FaceWithGaze.proto',
  package='rst.vision',
  syntax='proto2',
  serialized_pb=_b('\n\x1drst/vision/FaceWithGaze.proto\x12\nrst.vision\x1a\x15rst/vision/Face.proto\"\x8a\x01\n\x0c\x46\x61\x63\x65WithGaze\x12 \n\x06region\x18\x01 \x02(\x0b\x32\x10.rst.vision.Face\x12\x12\n\nlid_closed\x18\x02 \x01(\x08\x12\"\n\x1ahorizontal_gaze_estimation\x18\x03 \x01(\x01\x12 \n\x18vertical_gaze_estimation\x18\x04 \x01(\x01\x42\x12\x42\x10\x46\x61\x63\x65WithGazeType')
  ,
  dependencies=[rst_dot_vision_dot_Face__pb2.DESCRIPTOR,])




_FACEWITHGAZE = _descriptor.Descriptor(
  name='FaceWithGaze',
  full_name='rst.vision.FaceWithGaze',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='region', full_name='rst.vision.FaceWithGaze.region', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lid_closed', full_name='rst.vision.FaceWithGaze.lid_closed', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='horizontal_gaze_estimation', full_name='rst.vision.FaceWithGaze.horizontal_gaze_estimation', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='vertical_gaze_estimation', full_name='rst.vision.FaceWithGaze.vertical_gaze_estimation', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=69,
  serialized_end=207,
)

_FACEWITHGAZE.fields_by_name['region'].message_type = rst_dot_vision_dot_Face__pb2._FACE
DESCRIPTOR.message_types_by_name['FaceWithGaze'] = _FACEWITHGAZE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FaceWithGaze = _reflection.GeneratedProtocolMessageType('FaceWithGaze', (_message.Message,), dict(
  DESCRIPTOR = _FACEWITHGAZE,
  __module__ = 'rst.vision.FaceWithGaze_pb2'
  # @@protoc_insertion_point(class_scope:rst.vision.FaceWithGaze)
  ))
_sym_db.RegisterMessage(FaceWithGaze)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\020FaceWithGazeType'))
# @@protoc_insertion_point(module_scope)
