# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/math/Vec3DInt.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/math/Vec3DInt.proto',
  package='rst.math',
  syntax='proto2',
  serialized_pb=_b('\n\x17rst/math/Vec3DInt.proto\x12\x08rst.math\"4\n\x08Vec3DInt\x12\x0c\n\x01x\x18\x01 \x02(\x05:\x01\x30\x12\x0c\n\x01y\x18\x02 \x02(\x05:\x01\x30\x12\x0c\n\x01z\x18\x03 \x02(\x05:\x01\x30\x42\x0e\x42\x0cVec3DIntType')
)




_VEC3DINT = _descriptor.Descriptor(
  name='Vec3DInt',
  full_name='rst.math.Vec3DInt',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='rst.math.Vec3DInt.x', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='y', full_name='rst.math.Vec3DInt.y', index=1,
      number=2, type=5, cpp_type=1, label=2,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='z', full_name='rst.math.Vec3DInt.z', index=2,
      number=3, type=5, cpp_type=1, label=2,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=37,
  serialized_end=89,
)

DESCRIPTOR.message_types_by_name['Vec3DInt'] = _VEC3DINT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Vec3DInt = _reflection.GeneratedProtocolMessageType('Vec3DInt', (_message.Message,), dict(
  DESCRIPTOR = _VEC3DINT,
  __module__ = 'rst.math.Vec3DInt_pb2'
  # @@protoc_insertion_point(class_scope:rst.math.Vec3DInt)
  ))
_sym_db.RegisterMessage(Vec3DInt)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\014Vec3DIntType'))
# @@protoc_insertion_point(module_scope)
