# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/kinematics/ObjectCollision.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.kinematics import CollisionGeometry_pb2 as rst_dot_kinematics_dot_CollisionGeometry__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/kinematics/ObjectCollision.proto',
  package='rst.kinematics',
  syntax='proto2',
  serialized_pb=_b('\n$rst/kinematics/ObjectCollision.proto\x12\x0erst.kinematics\x1a&rst/kinematics/CollisionGeometry.proto\"j\n\x0fObjectCollision\x12\x33\n\x08geometry\x18\x01 \x01(\x0b\x32!.rst.kinematics.CollisionGeometry\x12\x10\n\x08object_1\x18\x02 \x01(\t\x12\x10\n\x08object_2\x18\x03 \x01(\tB\x15\x42\x13ObjectCollisionType')
  ,
  dependencies=[rst_dot_kinematics_dot_CollisionGeometry__pb2.DESCRIPTOR,])




_OBJECTCOLLISION = _descriptor.Descriptor(
  name='ObjectCollision',
  full_name='rst.kinematics.ObjectCollision',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='geometry', full_name='rst.kinematics.ObjectCollision.geometry', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='object_1', full_name='rst.kinematics.ObjectCollision.object_1', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='object_2', full_name='rst.kinematics.ObjectCollision.object_2', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=96,
  serialized_end=202,
)

_OBJECTCOLLISION.fields_by_name['geometry'].message_type = rst_dot_kinematics_dot_CollisionGeometry__pb2._COLLISIONGEOMETRY
DESCRIPTOR.message_types_by_name['ObjectCollision'] = _OBJECTCOLLISION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ObjectCollision = _reflection.GeneratedProtocolMessageType('ObjectCollision', (_message.Message,), dict(
  DESCRIPTOR = _OBJECTCOLLISION,
  __module__ = 'rst.kinematics.ObjectCollision_pb2'
  # @@protoc_insertion_point(class_scope:rst.kinematics.ObjectCollision)
  ))
_sym_db.RegisterMessage(ObjectCollision)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\023ObjectCollisionType'))
# @@protoc_insertion_point(module_scope)
