# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/graph/Node.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.generic import Value_pb2 as rst_dot_generic_dot_Value__pb2
from rst.generic import Dictionary_pb2 as rst_dot_generic_dot_Dictionary__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/graph/Node.proto',
  package='rst.graph',
  syntax='proto2',
  serialized_pb=_b('\n\x14rst/graph/Node.proto\x12\trst.graph\x1a\x17rst/generic/Value.proto\x1a\x1crst/generic/Dictionary.proto\"U\n\x04Node\x12 \n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x12.rst.generic.Value\x12+\n\nproperties\x18\x02 \x01(\x0b\x32\x17.rst.generic.DictionaryB\nB\x08NodeType')
  ,
  dependencies=[rst_dot_generic_dot_Value__pb2.DESCRIPTOR,rst_dot_generic_dot_Dictionary__pb2.DESCRIPTOR,])




_NODE = _descriptor.Descriptor(
  name='Node',
  full_name='rst.graph.Node',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='rst.graph.Node.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='properties', full_name='rst.graph.Node.properties', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=90,
  serialized_end=175,
)

_NODE.fields_by_name['data'].message_type = rst_dot_generic_dot_Value__pb2._VALUE
_NODE.fields_by_name['properties'].message_type = rst_dot_generic_dot_Dictionary__pb2._DICTIONARY
DESCRIPTOR.message_types_by_name['Node'] = _NODE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Node = _reflection.GeneratedProtocolMessageType('Node', (_message.Message,), dict(
  DESCRIPTOR = _NODE,
  __module__ = 'rst.graph.Node_pb2'
  # @@protoc_insertion_point(class_scope:rst.graph.Node)
  ))
_sym_db.RegisterMessage(Node)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\010NodeType'))
# @@protoc_insertion_point(module_scope)
