# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/calendar/Observance.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.calendar import DateTime_pb2 as rst_dot_calendar_dot_DateTime__pb2
from rst.calendar import Recurrence_pb2 as rst_dot_calendar_dot_Recurrence__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/calendar/Observance.proto',
  package='rst.calendar',
  syntax='proto2',
  serialized_pb=_b('\n\x1drst/calendar/Observance.proto\x12\x0crst.calendar\x1a\x1brst/calendar/DateTime.proto\x1a\x1drst/calendar/Recurrence.proto\"\xfc\x01\n\nObservance\x12\x35\n\x04type\x18\x03 \x02(\x0e\x32\x1d.rst.calendar.Observance.Type:\x08STANDARD\x12)\n\tstart_utc\x18\x04 \x02(\x0b\x32\x16.rst.calendar.DateTime\x12\x0c\n\x04name\x18\x06 \x01(\t\x12,\n\nrecurrence\x18\x07 \x01(\x0b\x32\x18.rst.calendar.Recurrence\x12\x16\n\x0boffset_from\x18\x08 \x02(\x12:\x01\x30\x12\x14\n\toffset_to\x18\t \x02(\x12:\x01\x30\"\"\n\x04Type\x12\x0c\n\x08STANDARD\x10\x01\x12\x0c\n\x08\x44\x41YLIGHT\x10\x02\x42\x10\x42\x0eObservanceType')
  ,
  dependencies=[rst_dot_calendar_dot_DateTime__pb2.DESCRIPTOR,rst_dot_calendar_dot_Recurrence__pb2.DESCRIPTOR,])



_OBSERVANCE_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='rst.calendar.Observance.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STANDARD', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DAYLIGHT', index=1, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=326,
  serialized_end=360,
)
_sym_db.RegisterEnumDescriptor(_OBSERVANCE_TYPE)


_OBSERVANCE = _descriptor.Descriptor(
  name='Observance',
  full_name='rst.calendar.Observance',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='rst.calendar.Observance.type', index=0,
      number=3, type=14, cpp_type=8, label=2,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='start_utc', full_name='rst.calendar.Observance.start_utc', index=1,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='rst.calendar.Observance.name', index=2,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='recurrence', full_name='rst.calendar.Observance.recurrence', index=3,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='offset_from', full_name='rst.calendar.Observance.offset_from', index=4,
      number=8, type=18, cpp_type=2, label=2,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='offset_to', full_name='rst.calendar.Observance.offset_to', index=5,
      number=9, type=18, cpp_type=2, label=2,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _OBSERVANCE_TYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=108,
  serialized_end=360,
)

_OBSERVANCE.fields_by_name['type'].enum_type = _OBSERVANCE_TYPE
_OBSERVANCE.fields_by_name['start_utc'].message_type = rst_dot_calendar_dot_DateTime__pb2._DATETIME
_OBSERVANCE.fields_by_name['recurrence'].message_type = rst_dot_calendar_dot_Recurrence__pb2._RECURRENCE
_OBSERVANCE_TYPE.containing_type = _OBSERVANCE
DESCRIPTOR.message_types_by_name['Observance'] = _OBSERVANCE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Observance = _reflection.GeneratedProtocolMessageType('Observance', (_message.Message,), dict(
  DESCRIPTOR = _OBSERVANCE,
  __module__ = 'rst.calendar.Observance_pb2'
  # @@protoc_insertion_point(class_scope:rst.calendar.Observance)
  ))
_sym_db.RegisterMessage(Observance)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\016ObservanceType'))
# @@protoc_insertion_point(module_scope)
