# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/math/VectorDouble.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/math/VectorDouble.proto',
  package='rst.math',
  syntax='proto2',
  serialized_pb=_b('\n\x1brst/math/VectorDouble.proto\x12\x08rst.math\" \n\x0cVectorDouble\x12\x10\n\x04\x64\x61ta\x18\x02 \x03(\x01\x42\x02\x10\x01\x42\x12\x42\x10VectorDoubleType')
)




_VECTORDOUBLE = _descriptor.Descriptor(
  name='VectorDouble',
  full_name='rst.math.VectorDouble',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='rst.math.VectorDouble.data', index=0,
      number=2, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=41,
  serialized_end=73,
)

DESCRIPTOR.message_types_by_name['VectorDouble'] = _VECTORDOUBLE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

VectorDouble = _reflection.GeneratedProtocolMessageType('VectorDouble', (_message.Message,), dict(
  DESCRIPTOR = _VECTORDOUBLE,
  __module__ = 'rst.math.VectorDouble_pb2'
  # @@protoc_insertion_point(class_scope:rst.math.VectorDouble)
  ))
_sym_db.RegisterMessage(VectorDouble)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\020VectorDoubleType'))
_VECTORDOUBLE.fields_by_name['data'].has_options = True
_VECTORDOUBLE.fields_by_name['data']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))
# @@protoc_insertion_point(module_scope)
