# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/bayesnetwork/BayesNetwork.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.bayesnetwork import BayesVariable_pb2 as rst_dot_bayesnetwork_dot_BayesVariable__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/bayesnetwork/BayesNetwork.proto',
  package='rst.bayesnetwork',
  syntax='proto2',
  serialized_pb=_b('\n#rst/bayesnetwork/BayesNetwork.proto\x12\x10rst.bayesnetwork\x1a$rst/bayesnetwork/BayesVariable.proto\"a\n\x0c\x42\x61yesNetwork\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08property\x18\x02 \x03(\t\x12\x31\n\x08variable\x18\x03 \x03(\x0b\x32\x1f.rst.bayesnetwork.BayesVariableB\x12\x42\x10\x42\x61yesNetworkType')
  ,
  dependencies=[rst_dot_bayesnetwork_dot_BayesVariable__pb2.DESCRIPTOR,])




_BAYESNETWORK = _descriptor.Descriptor(
  name='BayesNetwork',
  full_name='rst.bayesnetwork.BayesNetwork',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='rst.bayesnetwork.BayesNetwork.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='property', full_name='rst.bayesnetwork.BayesNetwork.property', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='variable', full_name='rst.bayesnetwork.BayesNetwork.variable', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=95,
  serialized_end=192,
)

_BAYESNETWORK.fields_by_name['variable'].message_type = rst_dot_bayesnetwork_dot_BayesVariable__pb2._BAYESVARIABLE
DESCRIPTOR.message_types_by_name['BayesNetwork'] = _BAYESNETWORK
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BayesNetwork = _reflection.GeneratedProtocolMessageType('BayesNetwork', (_message.Message,), dict(
  DESCRIPTOR = _BAYESNETWORK,
  __module__ = 'rst.bayesnetwork.BayesNetwork_pb2'
  # @@protoc_insertion_point(class_scope:rst.bayesnetwork.BayesNetwork)
  ))
_sym_db.RegisterMessage(BayesNetwork)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\020BayesNetworkType'))
# @@protoc_insertion_point(module_scope)
