# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/vision/LocatedFace.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.vision import Face_pb2 as rst_dot_vision_dot_Face__pb2
from rst.geometry import Translation_pb2 as rst_dot_geometry_dot_Translation__pb2
from rst.geometry import Rotation_pb2 as rst_dot_geometry_dot_Rotation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/vision/LocatedFace.proto',
  package='rst.vision',
  syntax='proto2',
  serialized_pb=_b('\n\x1crst/vision/LocatedFace.proto\x12\nrst.vision\x1a\x15rst/vision/Face.proto\x1a\x1erst/geometry/Translation.proto\x1a\x1brst/geometry/Rotation.proto\"\x87\x01\n\x0bLocatedFace\x12\x1e\n\x04\x66\x61\x63\x65\x18\x01 \x02(\x0b\x32\x10.rst.vision.Face\x12+\n\x08location\x18\x02 \x01(\x0b\x32\x19.rst.geometry.Translation\x12+\n\x0borientation\x18\x03 \x01(\x0b\x32\x16.rst.geometry.RotationB\x11\x42\x0fLocatedFaceType')
  ,
  dependencies=[rst_dot_vision_dot_Face__pb2.DESCRIPTOR,rst_dot_geometry_dot_Translation__pb2.DESCRIPTOR,rst_dot_geometry_dot_Rotation__pb2.DESCRIPTOR,])




_LOCATEDFACE = _descriptor.Descriptor(
  name='LocatedFace',
  full_name='rst.vision.LocatedFace',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='face', full_name='rst.vision.LocatedFace.face', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='location', full_name='rst.vision.LocatedFace.location', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='orientation', full_name='rst.vision.LocatedFace.orientation', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=129,
  serialized_end=264,
)

_LOCATEDFACE.fields_by_name['face'].message_type = rst_dot_vision_dot_Face__pb2._FACE
_LOCATEDFACE.fields_by_name['location'].message_type = rst_dot_geometry_dot_Translation__pb2._TRANSLATION
_LOCATEDFACE.fields_by_name['orientation'].message_type = rst_dot_geometry_dot_Rotation__pb2._ROTATION
DESCRIPTOR.message_types_by_name['LocatedFace'] = _LOCATEDFACE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LocatedFace = _reflection.GeneratedProtocolMessageType('LocatedFace', (_message.Message,), dict(
  DESCRIPTOR = _LOCATEDFACE,
  __module__ = 'rst.vision.LocatedFace_pb2'
  # @@protoc_insertion_point(class_scope:rst.vision.LocatedFace)
  ))
_sym_db.RegisterMessage(LocatedFace)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\017LocatedFaceType'))
# @@protoc_insertion_point(module_scope)
