# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/tracking/TrackedPose.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.tracking import TrackingInfo_pb2 as rst_dot_tracking_dot_TrackingInfo__pb2
from rst.geometry import Pose_pb2 as rst_dot_geometry_dot_Pose__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/tracking/TrackedPose.proto',
  package='rst.tracking',
  syntax='proto2',
  serialized_pb=_b('\n\x1erst/tracking/TrackedPose.proto\x12\x0crst.tracking\x1a\x1frst/tracking/TrackingInfo.proto\x1a\x17rst/geometry/Pose.proto\"\x96\x01\n\x0bTrackedPose\x12(\n\x04info\x18\x01 \x02(\x0b\x32\x1a.rst.tracking.TrackingInfo\x12 \n\x04pose\x18\x02 \x02(\x0b\x32\x12.rst.geometry.Pose\x12\x1e\n\x16translation_confidence\x18\x03 \x01(\x02\x12\x1b\n\x13rotation_confidence\x18\x04 \x01(\x02\x42\x11\x42\x0fTrackedPoseType')
  ,
  dependencies=[rst_dot_tracking_dot_TrackingInfo__pb2.DESCRIPTOR,rst_dot_geometry_dot_Pose__pb2.DESCRIPTOR,])




_TRACKEDPOSE = _descriptor.Descriptor(
  name='TrackedPose',
  full_name='rst.tracking.TrackedPose',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='info', full_name='rst.tracking.TrackedPose.info', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pose', full_name='rst.tracking.TrackedPose.pose', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='translation_confidence', full_name='rst.tracking.TrackedPose.translation_confidence', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rotation_confidence', full_name='rst.tracking.TrackedPose.rotation_confidence', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=107,
  serialized_end=257,
)

_TRACKEDPOSE.fields_by_name['info'].message_type = rst_dot_tracking_dot_TrackingInfo__pb2._TRACKINGINFO
_TRACKEDPOSE.fields_by_name['pose'].message_type = rst_dot_geometry_dot_Pose__pb2._POSE
DESCRIPTOR.message_types_by_name['TrackedPose'] = _TRACKEDPOSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TrackedPose = _reflection.GeneratedProtocolMessageType('TrackedPose', (_message.Message,), dict(
  DESCRIPTOR = _TRACKEDPOSE,
  __module__ = 'rst.tracking.TrackedPose_pb2'
  # @@protoc_insertion_point(class_scope:rst.tracking.TrackedPose)
  ))
_sym_db.RegisterMessage(TrackedPose)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\017TrackedPoseType'))
# @@protoc_insertion_point(module_scope)
