# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/vision/Face.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.geometry import BoundingBox_pb2 as rst_dot_geometry_dot_BoundingBox__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/vision/Face.proto',
  package='rst.vision',
  syntax='proto2',
  serialized_pb=_b('\n\x15rst/vision/Face.proto\x12\nrst.vision\x1a\x1erst/geometry/BoundingBox.proto\"E\n\x04\x46\x61\x63\x65\x12)\n\x06region\x18\x01 \x02(\x0b\x32\x19.rst.geometry.BoundingBox\x12\x12\n\nconfidence\x18\x02 \x01(\x01\x42\nB\x08\x46\x61\x63\x65Type')
  ,
  dependencies=[rst_dot_geometry_dot_BoundingBox__pb2.DESCRIPTOR,])




_FACE = _descriptor.Descriptor(
  name='Face',
  full_name='rst.vision.Face',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='region', full_name='rst.vision.Face.region', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='confidence', full_name='rst.vision.Face.confidence', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=69,
  serialized_end=138,
)

_FACE.fields_by_name['region'].message_type = rst_dot_geometry_dot_BoundingBox__pb2._BOUNDINGBOX
DESCRIPTOR.message_types_by_name['Face'] = _FACE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Face = _reflection.GeneratedProtocolMessageType('Face', (_message.Message,), dict(
  DESCRIPTOR = _FACE,
  __module__ = 'rst.vision.Face_pb2'
  # @@protoc_insertion_point(class_scope:rst.vision.Face)
  ))
_sym_db.RegisterMessage(Face)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\010FaceType'))
# @@protoc_insertion_point(module_scope)
