# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/graph/EdgeListGraph.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.graph import Node_pb2 as rst_dot_graph_dot_Node__pb2
from rst.graph import Edge_pb2 as rst_dot_graph_dot_Edge__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/graph/EdgeListGraph.proto',
  package='rst.graph',
  syntax='proto2',
  serialized_pb=_b('\n\x1drst/graph/EdgeListGraph.proto\x12\trst.graph\x1a\x14rst/graph/Node.proto\x1a\x14rst/graph/Edge.proto\"O\n\rEdgeListGraph\x12\x1e\n\x05nodes\x18\x01 \x03(\x0b\x32\x0f.rst.graph.Node\x12\x1e\n\x05\x65\x64ges\x18\x02 \x03(\x0b\x32\x0f.rst.graph.EdgeB\x13\x42\x11\x45\x64geListGraphType')
  ,
  dependencies=[rst_dot_graph_dot_Node__pb2.DESCRIPTOR,rst_dot_graph_dot_Edge__pb2.DESCRIPTOR,])




_EDGELISTGRAPH = _descriptor.Descriptor(
  name='EdgeListGraph',
  full_name='rst.graph.EdgeListGraph',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='nodes', full_name='rst.graph.EdgeListGraph.nodes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='edges', full_name='rst.graph.EdgeListGraph.edges', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=88,
  serialized_end=167,
)

_EDGELISTGRAPH.fields_by_name['nodes'].message_type = rst_dot_graph_dot_Node__pb2._NODE
_EDGELISTGRAPH.fields_by_name['edges'].message_type = rst_dot_graph_dot_Edge__pb2._EDGE
DESCRIPTOR.message_types_by_name['EdgeListGraph'] = _EDGELISTGRAPH
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

EdgeListGraph = _reflection.GeneratedProtocolMessageType('EdgeListGraph', (_message.Message,), dict(
  DESCRIPTOR = _EDGELISTGRAPH,
  __module__ = 'rst.graph.EdgeListGraph_pb2'
  # @@protoc_insertion_point(class_scope:rst.graph.EdgeListGraph)
  ))
_sym_db.RegisterMessage(EdgeListGraph)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\021EdgeListGraphType'))
# @@protoc_insertion_point(module_scope)
