# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/geometry/SphericalDirectionFloat.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/geometry/SphericalDirectionFloat.proto',
  package='rst.geometry',
  syntax='proto2',
  serialized_pb=_b('\n*rst/geometry/SphericalDirectionFloat.proto\x12\x0crst.geometry\"=\n\x17SphericalDirectionFloat\x12\x0f\n\x07\x61zimuth\x18\x01 \x02(\x02\x12\x11\n\televation\x18\x02 \x02(\x02\x42\x1d\x42\x1bSphericalDirectionFloatType')
)




_SPHERICALDIRECTIONFLOAT = _descriptor.Descriptor(
  name='SphericalDirectionFloat',
  full_name='rst.geometry.SphericalDirectionFloat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='azimuth', full_name='rst.geometry.SphericalDirectionFloat.azimuth', index=0,
      number=1, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='elevation', full_name='rst.geometry.SphericalDirectionFloat.elevation', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=60,
  serialized_end=121,
)

DESCRIPTOR.message_types_by_name['SphericalDirectionFloat'] = _SPHERICALDIRECTIONFLOAT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SphericalDirectionFloat = _reflection.GeneratedProtocolMessageType('SphericalDirectionFloat', (_message.Message,), dict(
  DESCRIPTOR = _SPHERICALDIRECTIONFLOAT,
  __module__ = 'rst.geometry.SphericalDirectionFloat_pb2'
  # @@protoc_insertion_point(class_scope:rst.geometry.SphericalDirectionFloat)
  ))
_sym_db.RegisterMessage(SphericalDirectionFloat)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\033SphericalDirectionFloatType'))
# @@protoc_insertion_point(module_scope)
