# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/classification/ClassificationResult.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/classification/ClassificationResult.proto',
  package='rst.classification',
  syntax='proto2',
  serialized_pb=_b('\n-rst/classification/ClassificationResult.proto\x12\x12rst.classification\"\xb7\x01\n\x14\x43lassificationResult\x12\x15\n\rdecided_class\x18\x01 \x02(\x0c\x12N\n\x07\x63lasses\x18\x02 \x03(\x0b\x32=.rst.classification.ClassificationResult.ClassWithProbability\x1a\x38\n\x14\x43lassWithProbability\x12\x0c\n\x04name\x18\x01 \x02(\x0c\x12\x12\n\nconfidence\x18\x02 \x02(\x02\x42\x1a\x42\x18\x43lassificationResultType')
)




_CLASSIFICATIONRESULT_CLASSWITHPROBABILITY = _descriptor.Descriptor(
  name='ClassWithProbability',
  full_name='rst.classification.ClassificationResult.ClassWithProbability',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='rst.classification.ClassificationResult.ClassWithProbability.name', index=0,
      number=1, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='confidence', full_name='rst.classification.ClassificationResult.ClassWithProbability.confidence', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=197,
  serialized_end=253,
)

_CLASSIFICATIONRESULT = _descriptor.Descriptor(
  name='ClassificationResult',
  full_name='rst.classification.ClassificationResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='decided_class', full_name='rst.classification.ClassificationResult.decided_class', index=0,
      number=1, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='classes', full_name='rst.classification.ClassificationResult.classes', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CLASSIFICATIONRESULT_CLASSWITHPROBABILITY, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=70,
  serialized_end=253,
)

_CLASSIFICATIONRESULT_CLASSWITHPROBABILITY.containing_type = _CLASSIFICATIONRESULT
_CLASSIFICATIONRESULT.fields_by_name['classes'].message_type = _CLASSIFICATIONRESULT_CLASSWITHPROBABILITY
DESCRIPTOR.message_types_by_name['ClassificationResult'] = _CLASSIFICATIONRESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ClassificationResult = _reflection.GeneratedProtocolMessageType('ClassificationResult', (_message.Message,), dict(

  ClassWithProbability = _reflection.GeneratedProtocolMessageType('ClassWithProbability', (_message.Message,), dict(
    DESCRIPTOR = _CLASSIFICATIONRESULT_CLASSWITHPROBABILITY,
    __module__ = 'rst.classification.ClassificationResult_pb2'
    # @@protoc_insertion_point(class_scope:rst.classification.ClassificationResult.ClassWithProbability)
    ))
  ,
  DESCRIPTOR = _CLASSIFICATIONRESULT,
  __module__ = 'rst.classification.ClassificationResult_pb2'
  # @@protoc_insertion_point(class_scope:rst.classification.ClassificationResult)
  ))
_sym_db.RegisterMessage(ClassificationResult)
_sym_db.RegisterMessage(ClassificationResult.ClassWithProbability)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\030ClassificationResultType'))
# @@protoc_insertion_point(module_scope)
