# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/navigation/MotionParameters.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/navigation/MotionParameters.proto',
  package='rst.navigation',
  syntax='proto2',
  serialized_pb=_b('\n%rst/navigation/MotionParameters.proto\x12\x0erst.navigation\"\xa2\x01\n\x10MotionParameters\x12\x14\n\x0cmax_velocity\x18\x01 \x01(\x02\x12\x18\n\x10max_acceleration\x18\x02 \x01(\x02\x12\x1c\n\x14translation_accuracy\x18\x03 \x01(\x02\x12\x1c\n\x14orientation_accuracy\x18\x04 \x01(\x02\x12\"\n\x1aprefer_forward_orientation\x18\x05 \x01(\x08\x42\x16\x42\x14MotionParametersType')
)




_MOTIONPARAMETERS = _descriptor.Descriptor(
  name='MotionParameters',
  full_name='rst.navigation.MotionParameters',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_velocity', full_name='rst.navigation.MotionParameters.max_velocity', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_acceleration', full_name='rst.navigation.MotionParameters.max_acceleration', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='translation_accuracy', full_name='rst.navigation.MotionParameters.translation_accuracy', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='orientation_accuracy', full_name='rst.navigation.MotionParameters.orientation_accuracy', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='prefer_forward_orientation', full_name='rst.navigation.MotionParameters.prefer_forward_orientation', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=58,
  serialized_end=220,
)

DESCRIPTOR.message_types_by_name['MotionParameters'] = _MOTIONPARAMETERS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MotionParameters = _reflection.GeneratedProtocolMessageType('MotionParameters', (_message.Message,), dict(
  DESCRIPTOR = _MOTIONPARAMETERS,
  __module__ = 'rst.navigation.MotionParameters_pb2'
  # @@protoc_insertion_point(class_scope:rst.navigation.MotionParameters)
  ))
_sym_db.RegisterMessage(MotionParameters)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\024MotionParametersType'))
# @@protoc_insertion_point(module_scope)
