# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/classification/ClassificationResultMap.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.classification import ClassificationResult_pb2 as rst_dot_classification_dot_ClassificationResult__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/classification/ClassificationResultMap.proto',
  package='rst.classification',
  syntax='proto2',
  serialized_pb=_b('\n0rst/classification/ClassificationResultMap.proto\x12\x12rst.classification\x1a-rst/classification/ClassificationResult.proto\"\xae\x01\n\x17\x43lassificationResultMap\x12\x42\n\x07\x61spects\x18\x01 \x03(\x0b\x32\x31.rst.classification.ClassificationResultMap.Entry\x1aO\n\x05\x45ntry\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x38\n\x06result\x18\x02 \x02(\x0b\x32(.rst.classification.ClassificationResultB\x1d\x42\x1b\x43lassificationResultMapType')
  ,
  dependencies=[rst_dot_classification_dot_ClassificationResult__pb2.DESCRIPTOR,])




_CLASSIFICATIONRESULTMAP_ENTRY = _descriptor.Descriptor(
  name='Entry',
  full_name='rst.classification.ClassificationResultMap.Entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='rst.classification.ClassificationResultMap.Entry.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='result', full_name='rst.classification.ClassificationResultMap.Entry.result', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=215,
  serialized_end=294,
)

_CLASSIFICATIONRESULTMAP = _descriptor.Descriptor(
  name='ClassificationResultMap',
  full_name='rst.classification.ClassificationResultMap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='aspects', full_name='rst.classification.ClassificationResultMap.aspects', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CLASSIFICATIONRESULTMAP_ENTRY, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=120,
  serialized_end=294,
)

_CLASSIFICATIONRESULTMAP_ENTRY.fields_by_name['result'].message_type = rst_dot_classification_dot_ClassificationResult__pb2._CLASSIFICATIONRESULT
_CLASSIFICATIONRESULTMAP_ENTRY.containing_type = _CLASSIFICATIONRESULTMAP
_CLASSIFICATIONRESULTMAP.fields_by_name['aspects'].message_type = _CLASSIFICATIONRESULTMAP_ENTRY
DESCRIPTOR.message_types_by_name['ClassificationResultMap'] = _CLASSIFICATIONRESULTMAP
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ClassificationResultMap = _reflection.GeneratedProtocolMessageType('ClassificationResultMap', (_message.Message,), dict(

  Entry = _reflection.GeneratedProtocolMessageType('Entry', (_message.Message,), dict(
    DESCRIPTOR = _CLASSIFICATIONRESULTMAP_ENTRY,
    __module__ = 'rst.classification.ClassificationResultMap_pb2'
    # @@protoc_insertion_point(class_scope:rst.classification.ClassificationResultMap.Entry)
    ))
  ,
  DESCRIPTOR = _CLASSIFICATIONRESULTMAP,
  __module__ = 'rst.classification.ClassificationResultMap_pb2'
  # @@protoc_insertion_point(class_scope:rst.classification.ClassificationResultMap)
  ))
_sym_db.RegisterMessage(ClassificationResultMap)
_sym_db.RegisterMessage(ClassificationResultMap.Entry)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\033ClassificationResultMapType'))
# @@protoc_insertion_point(module_scope)
