# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/geometry/PointPair.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.math import Vec2DFloat_pb2 as rst_dot_math_dot_Vec2DFloat__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/geometry/PointPair.proto',
  package='rst.geometry',
  syntax='proto2',
  serialized_pb=_b('\n\x1crst/geometry/PointPair.proto\x12\x0crst.geometry\x1a\x19rst/math/Vec2DFloat.proto\"V\n\tPointPair\x12#\n\x05\x66irst\x18\x01 \x02(\x0b\x32\x14.rst.math.Vec2DFloat\x12$\n\x06second\x18\x02 \x02(\x0b\x32\x14.rst.math.Vec2DFloatB\x0f\x42\rPointPairType')
  ,
  dependencies=[rst_dot_math_dot_Vec2DFloat__pb2.DESCRIPTOR,])




_POINTPAIR = _descriptor.Descriptor(
  name='PointPair',
  full_name='rst.geometry.PointPair',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='first', full_name='rst.geometry.PointPair.first', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='second', full_name='rst.geometry.PointPair.second', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=73,
  serialized_end=159,
)

_POINTPAIR.fields_by_name['first'].message_type = rst_dot_math_dot_Vec2DFloat__pb2._VEC2DFLOAT
_POINTPAIR.fields_by_name['second'].message_type = rst_dot_math_dot_Vec2DFloat__pb2._VEC2DFLOAT
DESCRIPTOR.message_types_by_name['PointPair'] = _POINTPAIR
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PointPair = _reflection.GeneratedProtocolMessageType('PointPair', (_message.Message,), dict(
  DESCRIPTOR = _POINTPAIR,
  __module__ = 'rst.geometry.PointPair_pb2'
  # @@protoc_insertion_point(class_scope:rst.geometry.PointPair)
  ))
_sym_db.RegisterMessage(PointPair)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\rPointPairType'))
# @@protoc_insertion_point(module_scope)
