# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/calendar/RecurrenceRule.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.calendar import DateTime_pb2 as rst_dot_calendar_dot_DateTime__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/calendar/RecurrenceRule.proto',
  package='rst.calendar',
  syntax='proto2',
  serialized_pb=_b('\n!rst/calendar/RecurrenceRule.proto\x12\x0crst.calendar\x1a\x1brst/calendar/DateTime.proto\"\xa7\x05\n\x0eRecurrenceRule\x12.\n\x0euntil_date_utc\x18\x02 \x01(\x0b\x32\x16.rst.calendar.DateTime\x12\r\n\x05\x63ount\x18\x03 \x01(\r\x12\x41\n\tfrequency\x18\x04 \x02(\x0e\x32&.rst.calendar.RecurrenceRule.Frequency:\x06YEARLY\x12\x13\n\x08interval\x18\x05 \x01(\r:\x01\x31\x12\x11\n\tby_second\x18\x06 \x03(\r\x12\x11\n\tby_minute\x18\x07 \x03(\r\x12\x0f\n\x07\x62y_hour\x18\x08 \x03(\r\x12\x39\n\x0b\x62y_week_day\x18\t \x03(\x0e\x32$.rst.calendar.RecurrenceRule.Weekday\x12\x15\n\rby_day_number\x18\n \x03(\x11\x12\x14\n\x0c\x62y_month_day\x18\x0b \x03(\x11\x12\x13\n\x0b\x62y_year_day\x18\x0c \x03(\x11\x12\x16\n\x0e\x62y_week_number\x18\r \x03(\x11\x12\x10\n\x08\x62y_month\x18\x0e \x03(\r\x12\x12\n\nby_set_pos\x18\x0f \x03(\x11\x12@\n\nweek_start\x18\x10 \x01(\x0e\x32$.rst.calendar.RecurrenceRule.Weekday:\x06MONDAY\"c\n\tFrequency\x12\x0c\n\x08SECONDLY\x10\x01\x12\x0c\n\x08MINUTELY\x10\x02\x12\n\n\x06HOURLY\x10\x03\x12\t\n\x05\x44\x41ILY\x10\x04\x12\n\n\x06WEEKLY\x10\x05\x12\x0b\n\x07MONTHLY\x10\x06\x12\n\n\x06YEARLY\x10\x07\"e\n\x07Weekday\x12\n\n\x06SUNDAY\x10\x01\x12\n\n\x06MONDAY\x10\x02\x12\x0b\n\x07TUESDAY\x10\x03\x12\r\n\tWEDNESDAY\x10\x04\x12\x0c\n\x08THURSDAY\x10\x05\x12\n\n\x06\x46RIDAY\x10\x06\x12\x0c\n\x08SATURDAY\x10\x07\x42\x14\x42\x12RecurrenceRuleType')
  ,
  dependencies=[rst_dot_calendar_dot_DateTime__pb2.DESCRIPTOR,])



_RECURRENCERULE_FREQUENCY = _descriptor.EnumDescriptor(
  name='Frequency',
  full_name='rst.calendar.RecurrenceRule.Frequency',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SECONDLY', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MINUTELY', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HOURLY', index=2, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DAILY', index=3, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WEEKLY', index=4, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MONTHLY', index=5, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='YEARLY', index=6, number=7,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=558,
  serialized_end=657,
)
_sym_db.RegisterEnumDescriptor(_RECURRENCERULE_FREQUENCY)

_RECURRENCERULE_WEEKDAY = _descriptor.EnumDescriptor(
  name='Weekday',
  full_name='rst.calendar.RecurrenceRule.Weekday',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUNDAY', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MONDAY', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TUESDAY', index=2, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WEDNESDAY', index=3, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='THURSDAY', index=4, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FRIDAY', index=5, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SATURDAY', index=6, number=7,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=659,
  serialized_end=760,
)
_sym_db.RegisterEnumDescriptor(_RECURRENCERULE_WEEKDAY)


_RECURRENCERULE = _descriptor.Descriptor(
  name='RecurrenceRule',
  full_name='rst.calendar.RecurrenceRule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='until_date_utc', full_name='rst.calendar.RecurrenceRule.until_date_utc', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='count', full_name='rst.calendar.RecurrenceRule.count', index=1,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='frequency', full_name='rst.calendar.RecurrenceRule.frequency', index=2,
      number=4, type=14, cpp_type=8, label=2,
      has_default_value=True, default_value=7,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='interval', full_name='rst.calendar.RecurrenceRule.interval', index=3,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='by_second', full_name='rst.calendar.RecurrenceRule.by_second', index=4,
      number=6, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='by_minute', full_name='rst.calendar.RecurrenceRule.by_minute', index=5,
      number=7, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='by_hour', full_name='rst.calendar.RecurrenceRule.by_hour', index=6,
      number=8, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='by_week_day', full_name='rst.calendar.RecurrenceRule.by_week_day', index=7,
      number=9, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='by_day_number', full_name='rst.calendar.RecurrenceRule.by_day_number', index=8,
      number=10, type=17, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='by_month_day', full_name='rst.calendar.RecurrenceRule.by_month_day', index=9,
      number=11, type=17, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='by_year_day', full_name='rst.calendar.RecurrenceRule.by_year_day', index=10,
      number=12, type=17, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='by_week_number', full_name='rst.calendar.RecurrenceRule.by_week_number', index=11,
      number=13, type=17, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='by_month', full_name='rst.calendar.RecurrenceRule.by_month', index=12,
      number=14, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='by_set_pos', full_name='rst.calendar.RecurrenceRule.by_set_pos', index=13,
      number=15, type=17, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='week_start', full_name='rst.calendar.RecurrenceRule.week_start', index=14,
      number=16, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _RECURRENCERULE_FREQUENCY,
    _RECURRENCERULE_WEEKDAY,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=81,
  serialized_end=760,
)

_RECURRENCERULE.fields_by_name['until_date_utc'].message_type = rst_dot_calendar_dot_DateTime__pb2._DATETIME
_RECURRENCERULE.fields_by_name['frequency'].enum_type = _RECURRENCERULE_FREQUENCY
_RECURRENCERULE.fields_by_name['by_week_day'].enum_type = _RECURRENCERULE_WEEKDAY
_RECURRENCERULE.fields_by_name['week_start'].enum_type = _RECURRENCERULE_WEEKDAY
_RECURRENCERULE_FREQUENCY.containing_type = _RECURRENCERULE
_RECURRENCERULE_WEEKDAY.containing_type = _RECURRENCERULE
DESCRIPTOR.message_types_by_name['RecurrenceRule'] = _RECURRENCERULE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RecurrenceRule = _reflection.GeneratedProtocolMessageType('RecurrenceRule', (_message.Message,), dict(
  DESCRIPTOR = _RECURRENCERULE,
  __module__ = 'rst.calendar.RecurrenceRule_pb2'
  # @@protoc_insertion_point(class_scope:rst.calendar.RecurrenceRule)
  ))
_sym_db.RegisterMessage(RecurrenceRule)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\022RecurrenceRuleType'))
# @@protoc_insertion_point(module_scope)
