# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/timing/Frequency.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/timing/Frequency.proto',
  package='rst.timing',
  syntax='proto2',
  serialized_pb=_b('\n\x1arst/timing/Frequency.proto\x12\nrst.timing\"\x17\n\tFrequency\x12\n\n\x02hz\x18\x01 \x02(\x01\x42\x0f\x42\rFrequencyType')
)




_FREQUENCY = _descriptor.Descriptor(
  name='Frequency',
  full_name='rst.timing.Frequency',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hz', full_name='rst.timing.Frequency.hz', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=42,
  serialized_end=65,
)

DESCRIPTOR.message_types_by_name['Frequency'] = _FREQUENCY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Frequency = _reflection.GeneratedProtocolMessageType('Frequency', (_message.Message,), dict(
  DESCRIPTOR = _FREQUENCY,
  __module__ = 'rst.timing.Frequency_pb2'
  # @@protoc_insertion_point(class_scope:rst.timing.Frequency)
  ))
_sym_db.RegisterMessage(Frequency)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\rFrequencyType'))
# @@protoc_insertion_point(module_scope)
