# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/geometry/ViewFrustum.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.geometry import FieldOfView_pb2 as rst_dot_geometry_dot_FieldOfView__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/geometry/ViewFrustum.proto',
  package='rst.geometry',
  syntax='proto2',
  serialized_pb=_b('\n\x1erst/geometry/ViewFrustum.proto\x12\x0crst.geometry\x1a\x1erst/geometry/FieldOfView.proto\"s\n\x0bViewFrustum\x12&\n\x03\x66ov\x18\x01 \x02(\x0b\x32\x19.rst.geometry.FieldOfView\x12\x1b\n\x10minimal_distance\x18\x02 \x01(\x02:\x01\x30\x12\x1f\n\x10maximal_distance\x18\x03 \x01(\x02:\x05\x39\x39\x39\x39\x39\x42\x11\x42\x0fViewFrustumType')
  ,
  dependencies=[rst_dot_geometry_dot_FieldOfView__pb2.DESCRIPTOR,])




_VIEWFRUSTUM = _descriptor.Descriptor(
  name='ViewFrustum',
  full_name='rst.geometry.ViewFrustum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fov', full_name='rst.geometry.ViewFrustum.fov', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='minimal_distance', full_name='rst.geometry.ViewFrustum.minimal_distance', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='maximal_distance', full_name='rst.geometry.ViewFrustum.maximal_distance', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(99999),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=80,
  serialized_end=195,
)

_VIEWFRUSTUM.fields_by_name['fov'].message_type = rst_dot_geometry_dot_FieldOfView__pb2._FIELDOFVIEW
DESCRIPTOR.message_types_by_name['ViewFrustum'] = _VIEWFRUSTUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ViewFrustum = _reflection.GeneratedProtocolMessageType('ViewFrustum', (_message.Message,), dict(
  DESCRIPTOR = _VIEWFRUSTUM,
  __module__ = 'rst.geometry.ViewFrustum_pb2'
  # @@protoc_insertion_point(class_scope:rst.geometry.ViewFrustum)
  ))
_sym_db.RegisterMessage(ViewFrustum)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\017ViewFrustumType'))
# @@protoc_insertion_point(module_scope)
