# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/stochastics/Gaussian1D.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/stochastics/Gaussian1D.proto',
  package='rst.stochastics',
  syntax='proto2',
  serialized_pb=_b('\n rst/stochastics/Gaussian1D.proto\x12\x0frst.stochastics\",\n\nGaussian1D\x12\x0c\n\x04mean\x18\x01 \x02(\x02\x12\x10\n\x08variance\x18\x02 \x02(\x02\x42\x10\x42\x0eGaussian1DType')
)




_GAUSSIAN1D = _descriptor.Descriptor(
  name='Gaussian1D',
  full_name='rst.stochastics.Gaussian1D',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mean', full_name='rst.stochastics.Gaussian1D.mean', index=0,
      number=1, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='variance', full_name='rst.stochastics.Gaussian1D.variance', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=53,
  serialized_end=97,
)

DESCRIPTOR.message_types_by_name['Gaussian1D'] = _GAUSSIAN1D
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Gaussian1D = _reflection.GeneratedProtocolMessageType('Gaussian1D', (_message.Message,), dict(
  DESCRIPTOR = _GAUSSIAN1D,
  __module__ = 'rst.stochastics.Gaussian1D_pb2'
  # @@protoc_insertion_point(class_scope:rst.stochastics.Gaussian1D)
  ))
_sym_db.RegisterMessage(Gaussian1D)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\016Gaussian1DType'))
# @@protoc_insertion_point(module_scope)
