# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/dynamics/MotorCurrents.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/dynamics/MotorCurrents.proto',
  package='rst.dynamics',
  syntax='proto2',
  serialized_pb=_b('\n rst/dynamics/MotorCurrents.proto\x12\x0crst.dynamics\"%\n\rMotorCurrents\x12\x14\n\x08\x63urrents\x18\x01 \x03(\x02\x42\x02\x10\x01\x42\x13\x42\x11MotorCurrentsType')
)




_MOTORCURRENTS = _descriptor.Descriptor(
  name='MotorCurrents',
  full_name='rst.dynamics.MotorCurrents',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='currents', full_name='rst.dynamics.MotorCurrents.currents', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=50,
  serialized_end=87,
)

DESCRIPTOR.message_types_by_name['MotorCurrents'] = _MOTORCURRENTS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MotorCurrents = _reflection.GeneratedProtocolMessageType('MotorCurrents', (_message.Message,), dict(
  DESCRIPTOR = _MOTORCURRENTS,
  __module__ = 'rst.dynamics.MotorCurrents_pb2'
  # @@protoc_insertion_point(class_scope:rst.dynamics.MotorCurrents)
  ))
_sym_db.RegisterMessage(MotorCurrents)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\021MotorCurrentsType'))
_MOTORCURRENTS.fields_by_name['currents'].has_options = True
_MOTORCURRENTS.fields_by_name['currents']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))
# @@protoc_insertion_point(module_scope)
