# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/geometry/Rotation.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/geometry/Rotation.proto',
  package='rst.geometry',
  syntax='proto2',
  serialized_pb=_b('\n\x1brst/geometry/Rotation.proto\x12\x0crst.geometry\"L\n\x08Rotation\x12\n\n\x02qw\x18\x04 \x02(\x01\x12\n\n\x02qx\x18\x05 \x02(\x01\x12\n\n\x02qy\x18\x06 \x02(\x01\x12\n\n\x02qz\x18\x07 \x02(\x01\x12\x10\n\x08\x66rame_id\x18\x08 \x01(\tB\x0e\x42\x0cRotationType')
)




_ROTATION = _descriptor.Descriptor(
  name='Rotation',
  full_name='rst.geometry.Rotation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='qw', full_name='rst.geometry.Rotation.qw', index=0,
      number=4, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='qx', full_name='rst.geometry.Rotation.qx', index=1,
      number=5, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='qy', full_name='rst.geometry.Rotation.qy', index=2,
      number=6, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='qz', full_name='rst.geometry.Rotation.qz', index=3,
      number=7, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='frame_id', full_name='rst.geometry.Rotation.frame_id', index=4,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=45,
  serialized_end=121,
)

DESCRIPTOR.message_types_by_name['Rotation'] = _ROTATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Rotation = _reflection.GeneratedProtocolMessageType('Rotation', (_message.Message,), dict(
  DESCRIPTOR = _ROTATION,
  __module__ = 'rst.geometry.Rotation_pb2'
  # @@protoc_insertion_point(class_scope:rst.geometry.Rotation)
  ))
_sym_db.RegisterMessage(Rotation)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\014RotationType'))
# @@protoc_insertion_point(module_scope)
