# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/geometry/PolygonalPatch3D.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.geometry import Pose_pb2 as rst_dot_geometry_dot_Pose__pb2
from rst.math import Vec2DFloat_pb2 as rst_dot_math_dot_Vec2DFloat__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/geometry/PolygonalPatch3D.proto',
  package='rst.geometry',
  syntax='proto2',
  serialized_pb=_b('\n#rst/geometry/PolygonalPatch3D.proto\x12\x0crst.geometry\x1a\x17rst/geometry/Pose.proto\x1a\x19rst/math/Vec2DFloat.proto\"Z\n\x10PolygonalPatch3D\x12 \n\x04\x62\x61se\x18\x01 \x02(\x0b\x32\x12.rst.geometry.Pose\x12$\n\x06\x62order\x18\x02 \x03(\x0b\x32\x14.rst.math.Vec2DFloatB\x16\x42\x14PolygonalPatch3DType')
  ,
  dependencies=[rst_dot_geometry_dot_Pose__pb2.DESCRIPTOR,rst_dot_math_dot_Vec2DFloat__pb2.DESCRIPTOR,])




_POLYGONALPATCH3D = _descriptor.Descriptor(
  name='PolygonalPatch3D',
  full_name='rst.geometry.PolygonalPatch3D',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='rst.geometry.PolygonalPatch3D.base', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='border', full_name='rst.geometry.PolygonalPatch3D.border', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=105,
  serialized_end=195,
)

_POLYGONALPATCH3D.fields_by_name['base'].message_type = rst_dot_geometry_dot_Pose__pb2._POSE
_POLYGONALPATCH3D.fields_by_name['border'].message_type = rst_dot_math_dot_Vec2DFloat__pb2._VEC2DFLOAT
DESCRIPTOR.message_types_by_name['PolygonalPatch3D'] = _POLYGONALPATCH3D
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PolygonalPatch3D = _reflection.GeneratedProtocolMessageType('PolygonalPatch3D', (_message.Message,), dict(
  DESCRIPTOR = _POLYGONALPATCH3D,
  __module__ = 'rst.geometry.PolygonalPatch3D_pb2'
  # @@protoc_insertion_point(class_scope:rst.geometry.PolygonalPatch3D)
  ))
_sym_db.RegisterMessage(PolygonalPatch3D)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\024PolygonalPatch3DType'))
# @@protoc_insertion_point(module_scope)
