# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/hri/Body.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.geometry import Translation_pb2 as rst_dot_geometry_dot_Translation__pb2
from rst.geometry import Rotation_pb2 as rst_dot_geometry_dot_Rotation__pb2
from rst.geometry import BoundingBox3DFloat_pb2 as rst_dot_geometry_dot_BoundingBox3DFloat__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/hri/Body.proto',
  package='rst.hri',
  syntax='proto2',
  serialized_pb=_b('\n\x12rst/hri/Body.proto\x12\x07rst.hri\x1a\x1erst/geometry/Translation.proto\x1a\x1brst/geometry/Rotation.proto\x1a%rst/geometry/BoundingBox3DFloat.proto\"\x91\x01\n\x04\x42ody\x12+\n\x08location\x18\n \x01(\x0b\x32\x19.rst.geometry.Translation\x12+\n\x0borientation\x18\x14 \x01(\x0b\x32\x16.rst.geometry.Rotation\x12/\n\x05shape\x18\x1e \x01(\x0b\x32 .rst.geometry.BoundingBox3DFloatB\nB\x08\x42odyType')
  ,
  dependencies=[rst_dot_geometry_dot_Translation__pb2.DESCRIPTOR,rst_dot_geometry_dot_Rotation__pb2.DESCRIPTOR,rst_dot_geometry_dot_BoundingBox3DFloat__pb2.DESCRIPTOR,])




_BODY = _descriptor.Descriptor(
  name='Body',
  full_name='rst.hri.Body',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='location', full_name='rst.hri.Body.location', index=0,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='orientation', full_name='rst.hri.Body.orientation', index=1,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='shape', full_name='rst.hri.Body.shape', index=2,
      number=30, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=132,
  serialized_end=277,
)

_BODY.fields_by_name['location'].message_type = rst_dot_geometry_dot_Translation__pb2._TRANSLATION
_BODY.fields_by_name['orientation'].message_type = rst_dot_geometry_dot_Rotation__pb2._ROTATION
_BODY.fields_by_name['shape'].message_type = rst_dot_geometry_dot_BoundingBox3DFloat__pb2._BOUNDINGBOX3DFLOAT
DESCRIPTOR.message_types_by_name['Body'] = _BODY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Body = _reflection.GeneratedProtocolMessageType('Body', (_message.Message,), dict(
  DESCRIPTOR = _BODY,
  __module__ = 'rst.hri.Body_pb2'
  # @@protoc_insertion_point(class_scope:rst.hri.Body)
  ))
_sym_db.RegisterMessage(Body)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\010BodyType'))
# @@protoc_insertion_point(module_scope)
