# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/calendar/Relationship.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/calendar/Relationship.proto',
  package='rst.calendar',
  syntax='proto2',
  serialized_pb=_b('\n\x1frst/calendar/Relationship.proto\x12\x0crst.calendar\"\x8b\x01\n\x0cRelationship\x12\x42\n\x11relationship_type\x18\x01 \x01(\x0e\x32\x1f.rst.calendar.Relationship.Type:\x06PARENT\x12\x0b\n\x03uid\x18\x02 \x02(\t\"*\n\x04Type\x12\n\n\x06PARENT\x10\x01\x12\t\n\x05\x43HILD\x10\x02\x12\x0b\n\x07SIBLING\x10\x03\x42\x12\x42\x10RelationshipType')
)



_RELATIONSHIP_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='rst.calendar.Relationship.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PARENT', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CHILD', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SIBLING', index=2, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=147,
  serialized_end=189,
)
_sym_db.RegisterEnumDescriptor(_RELATIONSHIP_TYPE)


_RELATIONSHIP = _descriptor.Descriptor(
  name='Relationship',
  full_name='rst.calendar.Relationship',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='relationship_type', full_name='rst.calendar.Relationship.relationship_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='uid', full_name='rst.calendar.Relationship.uid', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _RELATIONSHIP_TYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=50,
  serialized_end=189,
)

_RELATIONSHIP.fields_by_name['relationship_type'].enum_type = _RELATIONSHIP_TYPE
_RELATIONSHIP_TYPE.containing_type = _RELATIONSHIP
DESCRIPTOR.message_types_by_name['Relationship'] = _RELATIONSHIP
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Relationship = _reflection.GeneratedProtocolMessageType('Relationship', (_message.Message,), dict(
  DESCRIPTOR = _RELATIONSHIP,
  __module__ = 'rst.calendar.Relationship_pb2'
  # @@protoc_insertion_point(class_scope:rst.calendar.Relationship)
  ))
_sym_db.RegisterMessage(Relationship)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\020RelationshipType'))
# @@protoc_insertion_point(module_scope)
