# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/hri/HighlightTarget.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.timing import Duration_pb2 as rst_dot_timing_dot_Duration__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/hri/HighlightTarget.proto',
  package='rst.hri',
  syntax='proto2',
  serialized_pb=_b('\n\x1drst/hri/HighlightTarget.proto\x12\x07rst.hri\x1a\x19rst/timing/Duration.proto\"\xd2\x01\n\x0fHighlightTarget\x12\x11\n\ttarget_id\x18\x01 \x02(\t\x12&\n\x08\x64uration\x18\x02 \x02(\x0b\x32\x14.rst.timing.Duration\x12\x33\n\x08modality\x18\x03 \x03(\x0e\x32!.rst.hri.HighlightTarget.Modality\"O\n\x08Modality\x12\x08\n\x04GAZE\x10\x01\x12\x0b\n\x07GESTURE\x10\x02\x12\x11\n\rAMBIENT_LIGHT\x10\x03\x12\t\n\x05SOUND\x10\x04\x12\x0e\n\nSPOT_LIGHT\x10\x05\x42\x15\x42\x13HighlightTargetType')
  ,
  dependencies=[rst_dot_timing_dot_Duration__pb2.DESCRIPTOR,])



_HIGHLIGHTTARGET_MODALITY = _descriptor.EnumDescriptor(
  name='Modality',
  full_name='rst.hri.HighlightTarget.Modality',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='GAZE', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GESTURE', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AMBIENT_LIGHT', index=2, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SOUND', index=3, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SPOT_LIGHT', index=4, number=5,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=201,
  serialized_end=280,
)
_sym_db.RegisterEnumDescriptor(_HIGHLIGHTTARGET_MODALITY)


_HIGHLIGHTTARGET = _descriptor.Descriptor(
  name='HighlightTarget',
  full_name='rst.hri.HighlightTarget',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='target_id', full_name='rst.hri.HighlightTarget.target_id', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='duration', full_name='rst.hri.HighlightTarget.duration', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='modality', full_name='rst.hri.HighlightTarget.modality', index=2,
      number=3, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _HIGHLIGHTTARGET_MODALITY,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=70,
  serialized_end=280,
)

_HIGHLIGHTTARGET.fields_by_name['duration'].message_type = rst_dot_timing_dot_Duration__pb2._DURATION
_HIGHLIGHTTARGET.fields_by_name['modality'].enum_type = _HIGHLIGHTTARGET_MODALITY
_HIGHLIGHTTARGET_MODALITY.containing_type = _HIGHLIGHTTARGET
DESCRIPTOR.message_types_by_name['HighlightTarget'] = _HIGHLIGHTTARGET
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

HighlightTarget = _reflection.GeneratedProtocolMessageType('HighlightTarget', (_message.Message,), dict(
  DESCRIPTOR = _HIGHLIGHTTARGET,
  __module__ = 'rst.hri.HighlightTarget_pb2'
  # @@protoc_insertion_point(class_scope:rst.hri.HighlightTarget)
  ))
_sym_db.RegisterMessage(HighlightTarget)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\023HighlightTargetType'))
# @@protoc_insertion_point(module_scope)
