# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/kinematics/AngularAccelerations.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/kinematics/AngularAccelerations.proto',
  package='rst.kinematics',
  syntax='proto2',
  serialized_pb=_b('\n)rst/kinematics/AngularAccelerations.proto\x12\x0erst.kinematics\"7\n\x14\x41ngularAccelerations\x12\t\n\x01\x61\x18\x01 \x02(\x02\x12\t\n\x01\x62\x18\x02 \x02(\x02\x12\t\n\x01\x63\x18\x03 \x02(\x02\x42\x1a\x42\x18\x41ngularAccelerationsType')
)




_ANGULARACCELERATIONS = _descriptor.Descriptor(
  name='AngularAccelerations',
  full_name='rst.kinematics.AngularAccelerations',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='a', full_name='rst.kinematics.AngularAccelerations.a', index=0,
      number=1, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='b', full_name='rst.kinematics.AngularAccelerations.b', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='c', full_name='rst.kinematics.AngularAccelerations.c', index=2,
      number=3, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=61,
  serialized_end=116,
)

DESCRIPTOR.message_types_by_name['AngularAccelerations'] = _ANGULARACCELERATIONS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AngularAccelerations = _reflection.GeneratedProtocolMessageType('AngularAccelerations', (_message.Message,), dict(
  DESCRIPTOR = _ANGULARACCELERATIONS,
  __module__ = 'rst.kinematics.AngularAccelerations_pb2'
  # @@protoc_insertion_point(class_scope:rst.kinematics.AngularAccelerations)
  ))
_sym_db.RegisterMessage(AngularAccelerations)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\030AngularAccelerationsType'))
# @@protoc_insertion_point(module_scope)
