# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/devices/generic/DiskState.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/devices/generic/DiskState.proto',
  package='rst.devices.generic',
  syntax='proto2',
  serialized_pb=_b('\n#rst/devices/generic/DiskState.proto\x12\x13rst.devices.generic\"\xee\x02\n\tDiskState\x12<\n\npartitions\x18\x01 \x03(\x0b\x32(.rst.devices.generic.DiskState.Partition\x12\x36\n\x07\x64\x65vices\x18\x02 \x03(\x0b\x32%.rst.devices.generic.DiskState.Device\x1aY\n\tPartition\x12\x13\n\x0bmount_point\x18\x01 \x02(\x0c\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x0c\x12\x13\n\x0bspace_total\x18\n \x01(\x04\x12\x12\n\nspace_used\x18\x0b \x01(\x04\x1a\x8f\x01\n\x06\x44\x65vice\x12\x0c\n\x04name\x18\x01 \x02(\x0c\x12\x12\n\nread_count\x18\n \x01(\x04\x12\x13\n\x0bwrite_count\x18\x0b \x01(\x04\x12\x12\n\nread_bytes\x18\x0c \x01(\x04\x12\x13\n\x0bwrite_bytes\x18\r \x01(\x04\x12\x11\n\tread_time\x18\x0e \x01(\x04\x12\x12\n\nwrite_time\x18\x0f \x01(\x04\x42\x0f\x42\rDiskStateType')
)




_DISKSTATE_PARTITION = _descriptor.Descriptor(
  name='Partition',
  full_name='rst.devices.generic.DiskState.Partition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mount_point', full_name='rst.devices.generic.DiskState.Partition.mount_point', index=0,
      number=1, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='device', full_name='rst.devices.generic.DiskState.Partition.device', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='space_total', full_name='rst.devices.generic.DiskState.Partition.space_total', index=2,
      number=10, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='space_used', full_name='rst.devices.generic.DiskState.Partition.space_used', index=3,
      number=11, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=192,
  serialized_end=281,
)

_DISKSTATE_DEVICE = _descriptor.Descriptor(
  name='Device',
  full_name='rst.devices.generic.DiskState.Device',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='rst.devices.generic.DiskState.Device.name', index=0,
      number=1, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='read_count', full_name='rst.devices.generic.DiskState.Device.read_count', index=1,
      number=10, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='write_count', full_name='rst.devices.generic.DiskState.Device.write_count', index=2,
      number=11, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='read_bytes', full_name='rst.devices.generic.DiskState.Device.read_bytes', index=3,
      number=12, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='write_bytes', full_name='rst.devices.generic.DiskState.Device.write_bytes', index=4,
      number=13, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='read_time', full_name='rst.devices.generic.DiskState.Device.read_time', index=5,
      number=14, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='write_time', full_name='rst.devices.generic.DiskState.Device.write_time', index=6,
      number=15, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=284,
  serialized_end=427,
)

_DISKSTATE = _descriptor.Descriptor(
  name='DiskState',
  full_name='rst.devices.generic.DiskState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='partitions', full_name='rst.devices.generic.DiskState.partitions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='devices', full_name='rst.devices.generic.DiskState.devices', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_DISKSTATE_PARTITION, _DISKSTATE_DEVICE, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=61,
  serialized_end=427,
)

_DISKSTATE_PARTITION.containing_type = _DISKSTATE
_DISKSTATE_DEVICE.containing_type = _DISKSTATE
_DISKSTATE.fields_by_name['partitions'].message_type = _DISKSTATE_PARTITION
_DISKSTATE.fields_by_name['devices'].message_type = _DISKSTATE_DEVICE
DESCRIPTOR.message_types_by_name['DiskState'] = _DISKSTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DiskState = _reflection.GeneratedProtocolMessageType('DiskState', (_message.Message,), dict(

  Partition = _reflection.GeneratedProtocolMessageType('Partition', (_message.Message,), dict(
    DESCRIPTOR = _DISKSTATE_PARTITION,
    __module__ = 'rst.devices.generic.DiskState_pb2'
    # @@protoc_insertion_point(class_scope:rst.devices.generic.DiskState.Partition)
    ))
  ,

  Device = _reflection.GeneratedProtocolMessageType('Device', (_message.Message,), dict(
    DESCRIPTOR = _DISKSTATE_DEVICE,
    __module__ = 'rst.devices.generic.DiskState_pb2'
    # @@protoc_insertion_point(class_scope:rst.devices.generic.DiskState.Device)
    ))
  ,
  DESCRIPTOR = _DISKSTATE,
  __module__ = 'rst.devices.generic.DiskState_pb2'
  # @@protoc_insertion_point(class_scope:rst.devices.generic.DiskState)
  ))
_sym_db.RegisterMessage(DiskState)
_sym_db.RegisterMessage(DiskState.Partition)
_sym_db.RegisterMessage(DiskState.Device)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\rDiskStateType'))
# @@protoc_insertion_point(module_scope)
