# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/calendar/Event.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.calendar import DateTime_pb2 as rst_dot_calendar_dot_DateTime__pb2
from rst.calendar import Entry_pb2 as rst_dot_calendar_dot_Entry__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/calendar/Event.proto',
  package='rst.calendar',
  syntax='proto2',
  serialized_pb=_b('\n\x18rst/calendar/Event.proto\x12\x0crst.calendar\x1a\x1brst/calendar/DateTime.proto\x1a\x18rst/calendar/Entry.proto\"\xd6\x02\n\x05\x45vent\x12\"\n\x05\x65ntry\x18\x01 \x01(\x0b\x32\x13.rst.calendar.Entry\x12@\n\x0c\x65vent_status\x18\x02 \x01(\x0e\x32\x1f.rst.calendar.Event.EventStatus:\tCONFIRMED\x12>\n\x0ctransparency\x18\x03 \x01(\x0e\x32 .rst.calendar.Event.Transparency:\x06OPAQUE\x12-\n\rend_date_time\x18\x04 \x01(\x0b\x32\x16.rst.calendar.DateTime\x12\x10\n\x08\x64uration\x18\x05 \x01(\x12\"9\n\x0b\x45ventStatus\x12\r\n\tTENTATIVE\x10\x01\x12\r\n\tCONFIRMED\x10\x02\x12\x0c\n\x08\x43\x41NCELED\x10\x03\"+\n\x0cTransparency\x12\x0f\n\x0bTRANSPARENT\x10\x01\x12\n\n\x06OPAQUE\x10\x02\x42\x0b\x42\tEventType')
  ,
  dependencies=[rst_dot_calendar_dot_DateTime__pb2.DESCRIPTOR,rst_dot_calendar_dot_Entry__pb2.DESCRIPTOR,])



_EVENT_EVENTSTATUS = _descriptor.EnumDescriptor(
  name='EventStatus',
  full_name='rst.calendar.Event.EventStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TENTATIVE', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONFIRMED', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANCELED', index=2, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=338,
  serialized_end=395,
)
_sym_db.RegisterEnumDescriptor(_EVENT_EVENTSTATUS)

_EVENT_TRANSPARENCY = _descriptor.EnumDescriptor(
  name='Transparency',
  full_name='rst.calendar.Event.Transparency',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TRANSPARENT', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OPAQUE', index=1, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=397,
  serialized_end=440,
)
_sym_db.RegisterEnumDescriptor(_EVENT_TRANSPARENCY)


_EVENT = _descriptor.Descriptor(
  name='Event',
  full_name='rst.calendar.Event',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entry', full_name='rst.calendar.Event.entry', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='event_status', full_name='rst.calendar.Event.event_status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='transparency', full_name='rst.calendar.Event.transparency', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='end_date_time', full_name='rst.calendar.Event.end_date_time', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='duration', full_name='rst.calendar.Event.duration', index=4,
      number=5, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _EVENT_EVENTSTATUS,
    _EVENT_TRANSPARENCY,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=98,
  serialized_end=440,
)

_EVENT.fields_by_name['entry'].message_type = rst_dot_calendar_dot_Entry__pb2._ENTRY
_EVENT.fields_by_name['event_status'].enum_type = _EVENT_EVENTSTATUS
_EVENT.fields_by_name['transparency'].enum_type = _EVENT_TRANSPARENCY
_EVENT.fields_by_name['end_date_time'].message_type = rst_dot_calendar_dot_DateTime__pb2._DATETIME
_EVENT_EVENTSTATUS.containing_type = _EVENT
_EVENT_TRANSPARENCY.containing_type = _EVENT
DESCRIPTOR.message_types_by_name['Event'] = _EVENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Event = _reflection.GeneratedProtocolMessageType('Event', (_message.Message,), dict(
  DESCRIPTOR = _EVENT,
  __module__ = 'rst.calendar.Event_pb2'
  # @@protoc_insertion_point(class_scope:rst.calendar.Event)
  ))
_sym_db.RegisterMessage(Event)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\tEventType'))
# @@protoc_insertion_point(module_scope)
