# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/hri/Legs.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/hri/Legs.proto',
  package='rst.hri',
  syntax='proto2',
  serialized_pb=_b('\n\x12rst/hri/Legs.proto\x12\x07rst.hri\"h\n\x04Legs\x12\r\n\x05\x61ngle\x18\x01 \x02(\x02\x12\x16\n\x0e\x61ngle_variance\x18\x02 \x02(\x02\x12\x10\n\x08\x64istance\x18\x03 \x02(\x02\x12\x19\n\x11\x64istance_variance\x18\x04 \x02(\x02\x12\x0c\n\x04pair\x18\x05 \x02(\x08\x42\nB\x08LegsType')
)




_LEGS = _descriptor.Descriptor(
  name='Legs',
  full_name='rst.hri.Legs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='angle', full_name='rst.hri.Legs.angle', index=0,
      number=1, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='angle_variance', full_name='rst.hri.Legs.angle_variance', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='distance', full_name='rst.hri.Legs.distance', index=2,
      number=3, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='distance_variance', full_name='rst.hri.Legs.distance_variance', index=3,
      number=4, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pair', full_name='rst.hri.Legs.pair', index=4,
      number=5, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=31,
  serialized_end=135,
)

DESCRIPTOR.message_types_by_name['Legs'] = _LEGS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Legs = _reflection.GeneratedProtocolMessageType('Legs', (_message.Message,), dict(
  DESCRIPTOR = _LEGS,
  __module__ = 'rst.hri.Legs_pb2'
  # @@protoc_insertion_point(class_scope:rst.hri.Legs)
  ))
_sym_db.RegisterMessage(Legs)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\010LegsType'))
# @@protoc_insertion_point(module_scope)
