# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/devices/generic/NetworkState.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/devices/generic/NetworkState.proto',
  package='rst.devices.generic',
  syntax='proto2',
  serialized_pb=_b('\n&rst/devices/generic/NetworkState.proto\x12\x13rst.devices.generic\"\x9f\x08\n\x0cNetworkState\x12J\n\x04nics\x18\x01 \x03(\x0b\x32<.rst.devices.generic.NetworkState.NetworkInterfaceController\x12I\n\x0b\x63onnections\x18\x02 \x03(\x0b\x32\x34.rst.devices.generic.NetworkState.NetworkConnections\x1a\xde\x01\n\x1aNetworkInterfaceController\x12\x0c\n\x04name\x18\x01 \x02(\x0c\x12\x16\n\x0e\x62ytes_received\x18\n \x01(\x04\x12\x12\n\nbytes_sent\x18\x0b \x01(\x04\x12\x18\n\x10packets_received\x18\x0c \x01(\x04\x12\x14\n\x0cpackets_sent\x18\r \x01(\x04\x12\x16\n\x0ereceive_errors\x18\x0e \x01(\x04\x12\x13\n\x0bsend_errors\x18\x0f \x01(\x04\x12\x15\n\rreceive_drops\x18\x10 \x01(\x04\x12\x12\n\nsend_drops\x18\x11 \x01(\x04\x1a\x96\x05\n\x12NetworkConnections\x12O\n\x08protocol\x18\x01 \x02(\x0e\x32=.rst.devices.generic.NetworkState.NetworkConnections.Protocol\x12R\n\x06\x66\x61mily\x18\x02 \x02(\x0e\x32\x42.rst.devices.generic.NetworkState.NetworkConnections.AddressFamily\x12\x17\n\x0fnum_established\x18\n \x01(\r\x12\x14\n\x0cnum_syn_sent\x18\x0b \x01(\r\x12\x14\n\x0cnum_syn_recv\x18\x0c \x01(\r\x12\x15\n\rnum_fin_wait1\x18\r \x01(\r\x12\x15\n\rnum_fin_wait2\x18\x0e \x01(\r\x12\x15\n\rnum_time_wait\x18\x0f \x01(\r\x12\x11\n\tnum_close\x18\x10 \x01(\r\x12\x16\n\x0enum_close_wait\x18\x11 \x01(\r\x12\x14\n\x0cnum_last_ack\x18\x12 \x01(\r\x12\x12\n\nnum_listen\x18\x13 \x01(\r\x12\x13\n\x0bnum_closing\x18\x14 \x01(\r\x12\x16\n\x0enum_delete_tcb\x18\x15 \x01(\r\x12\x10\n\x08num_idle\x18\x16 \x01(\r\x12\x11\n\tnum_bound\x18\x17 \x01(\r\x12\x10\n\x08num_none\x18( \x01(\r\"B\n\x08Protocol\x12\x10\n\x0cPROTOCOL_TCP\x10\x01\x12\x10\n\x0cPROTOCOL_UDP\x10\x02\x12\x12\n\x0ePROTOCOL_OTHER\x10\x64\"T\n\rAddressFamily\x12\x0f\n\x0b\x46\x41MILY_IPV4\x10\x01\x12\x0f\n\x0b\x46\x41MILY_IPV6\x10\x02\x12\x0f\n\x0b\x46\x41MILY_UNIX\x10\x03\x12\x10\n\x0c\x46\x41MILY_OTHER\x10\x64\x42\x12\x42\x10NetworkStateType')
)



_NETWORKSTATE_NETWORKCONNECTIONS_PROTOCOL = _descriptor.EnumDescriptor(
  name='Protocol',
  full_name='rst.devices.generic.NetworkState.NetworkConnections.Protocol',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PROTOCOL_TCP', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROTOCOL_UDP', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROTOCOL_OTHER', index=2, number=100,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=967,
  serialized_end=1033,
)
_sym_db.RegisterEnumDescriptor(_NETWORKSTATE_NETWORKCONNECTIONS_PROTOCOL)

_NETWORKSTATE_NETWORKCONNECTIONS_ADDRESSFAMILY = _descriptor.EnumDescriptor(
  name='AddressFamily',
  full_name='rst.devices.generic.NetworkState.NetworkConnections.AddressFamily',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FAMILY_IPV4', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAMILY_IPV6', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAMILY_UNIX', index=2, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAMILY_OTHER', index=3, number=100,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1035,
  serialized_end=1119,
)
_sym_db.RegisterEnumDescriptor(_NETWORKSTATE_NETWORKCONNECTIONS_ADDRESSFAMILY)


_NETWORKSTATE_NETWORKINTERFACECONTROLLER = _descriptor.Descriptor(
  name='NetworkInterfaceController',
  full_name='rst.devices.generic.NetworkState.NetworkInterfaceController',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='rst.devices.generic.NetworkState.NetworkInterfaceController.name', index=0,
      number=1, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bytes_received', full_name='rst.devices.generic.NetworkState.NetworkInterfaceController.bytes_received', index=1,
      number=10, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bytes_sent', full_name='rst.devices.generic.NetworkState.NetworkInterfaceController.bytes_sent', index=2,
      number=11, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='packets_received', full_name='rst.devices.generic.NetworkState.NetworkInterfaceController.packets_received', index=3,
      number=12, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='packets_sent', full_name='rst.devices.generic.NetworkState.NetworkInterfaceController.packets_sent', index=4,
      number=13, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='receive_errors', full_name='rst.devices.generic.NetworkState.NetworkInterfaceController.receive_errors', index=5,
      number=14, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='send_errors', full_name='rst.devices.generic.NetworkState.NetworkInterfaceController.send_errors', index=6,
      number=15, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='receive_drops', full_name='rst.devices.generic.NetworkState.NetworkInterfaceController.receive_drops', index=7,
      number=16, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='send_drops', full_name='rst.devices.generic.NetworkState.NetworkInterfaceController.send_drops', index=8,
      number=17, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=232,
  serialized_end=454,
)

_NETWORKSTATE_NETWORKCONNECTIONS = _descriptor.Descriptor(
  name='NetworkConnections',
  full_name='rst.devices.generic.NetworkState.NetworkConnections',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='protocol', full_name='rst.devices.generic.NetworkState.NetworkConnections.protocol', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='family', full_name='rst.devices.generic.NetworkState.NetworkConnections.family', index=1,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='num_established', full_name='rst.devices.generic.NetworkState.NetworkConnections.num_established', index=2,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='num_syn_sent', full_name='rst.devices.generic.NetworkState.NetworkConnections.num_syn_sent', index=3,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='num_syn_recv', full_name='rst.devices.generic.NetworkState.NetworkConnections.num_syn_recv', index=4,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='num_fin_wait1', full_name='rst.devices.generic.NetworkState.NetworkConnections.num_fin_wait1', index=5,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='num_fin_wait2', full_name='rst.devices.generic.NetworkState.NetworkConnections.num_fin_wait2', index=6,
      number=14, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='num_time_wait', full_name='rst.devices.generic.NetworkState.NetworkConnections.num_time_wait', index=7,
      number=15, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='num_close', full_name='rst.devices.generic.NetworkState.NetworkConnections.num_close', index=8,
      number=16, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='num_close_wait', full_name='rst.devices.generic.NetworkState.NetworkConnections.num_close_wait', index=9,
      number=17, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='num_last_ack', full_name='rst.devices.generic.NetworkState.NetworkConnections.num_last_ack', index=10,
      number=18, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='num_listen', full_name='rst.devices.generic.NetworkState.NetworkConnections.num_listen', index=11,
      number=19, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='num_closing', full_name='rst.devices.generic.NetworkState.NetworkConnections.num_closing', index=12,
      number=20, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='num_delete_tcb', full_name='rst.devices.generic.NetworkState.NetworkConnections.num_delete_tcb', index=13,
      number=21, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='num_idle', full_name='rst.devices.generic.NetworkState.NetworkConnections.num_idle', index=14,
      number=22, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='num_bound', full_name='rst.devices.generic.NetworkState.NetworkConnections.num_bound', index=15,
      number=23, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='num_none', full_name='rst.devices.generic.NetworkState.NetworkConnections.num_none', index=16,
      number=40, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _NETWORKSTATE_NETWORKCONNECTIONS_PROTOCOL,
    _NETWORKSTATE_NETWORKCONNECTIONS_ADDRESSFAMILY,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=457,
  serialized_end=1119,
)

_NETWORKSTATE = _descriptor.Descriptor(
  name='NetworkState',
  full_name='rst.devices.generic.NetworkState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='nics', full_name='rst.devices.generic.NetworkState.nics', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='connections', full_name='rst.devices.generic.NetworkState.connections', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_NETWORKSTATE_NETWORKINTERFACECONTROLLER, _NETWORKSTATE_NETWORKCONNECTIONS, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=64,
  serialized_end=1119,
)

_NETWORKSTATE_NETWORKINTERFACECONTROLLER.containing_type = _NETWORKSTATE
_NETWORKSTATE_NETWORKCONNECTIONS.fields_by_name['protocol'].enum_type = _NETWORKSTATE_NETWORKCONNECTIONS_PROTOCOL
_NETWORKSTATE_NETWORKCONNECTIONS.fields_by_name['family'].enum_type = _NETWORKSTATE_NETWORKCONNECTIONS_ADDRESSFAMILY
_NETWORKSTATE_NETWORKCONNECTIONS.containing_type = _NETWORKSTATE
_NETWORKSTATE_NETWORKCONNECTIONS_PROTOCOL.containing_type = _NETWORKSTATE_NETWORKCONNECTIONS
_NETWORKSTATE_NETWORKCONNECTIONS_ADDRESSFAMILY.containing_type = _NETWORKSTATE_NETWORKCONNECTIONS
_NETWORKSTATE.fields_by_name['nics'].message_type = _NETWORKSTATE_NETWORKINTERFACECONTROLLER
_NETWORKSTATE.fields_by_name['connections'].message_type = _NETWORKSTATE_NETWORKCONNECTIONS
DESCRIPTOR.message_types_by_name['NetworkState'] = _NETWORKSTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

NetworkState = _reflection.GeneratedProtocolMessageType('NetworkState', (_message.Message,), dict(

  NetworkInterfaceController = _reflection.GeneratedProtocolMessageType('NetworkInterfaceController', (_message.Message,), dict(
    DESCRIPTOR = _NETWORKSTATE_NETWORKINTERFACECONTROLLER,
    __module__ = 'rst.devices.generic.NetworkState_pb2'
    # @@protoc_insertion_point(class_scope:rst.devices.generic.NetworkState.NetworkInterfaceController)
    ))
  ,

  NetworkConnections = _reflection.GeneratedProtocolMessageType('NetworkConnections', (_message.Message,), dict(
    DESCRIPTOR = _NETWORKSTATE_NETWORKCONNECTIONS,
    __module__ = 'rst.devices.generic.NetworkState_pb2'
    # @@protoc_insertion_point(class_scope:rst.devices.generic.NetworkState.NetworkConnections)
    ))
  ,
  DESCRIPTOR = _NETWORKSTATE,
  __module__ = 'rst.devices.generic.NetworkState_pb2'
  # @@protoc_insertion_point(class_scope:rst.devices.generic.NetworkState)
  ))
_sym_db.RegisterMessage(NetworkState)
_sym_db.RegisterMessage(NetworkState.NetworkInterfaceController)
_sym_db.RegisterMessage(NetworkState.NetworkConnections)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\020NetworkStateType'))
# @@protoc_insertion_point(module_scope)
