# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/calendar/DateTime.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/calendar/DateTime.proto',
  package='rst.calendar',
  syntax='proto2',
  serialized_pb=_b('\n\x1brst/calendar/DateTime.proto\x12\x0crst.calendar\"\xad\x01\n\x08\x44\x61teTime\x12\x38\n\x0e\x64\x61te_time_type\x18\x01 \x01(\x0e\x32\x1b.rst.calendar.DateTime.Type:\x03UTC\x12\x18\n\x0btimezone_id\x18\x02 \x01(\t:\x03UTC\x12#\n\x18milliseconds_since_epoch\x18\x03 \x01(\x04:\x01\x30\"(\n\x04Type\x12\x07\n\x03UTC\x10\x01\x12\x0c\n\x08\x46LOATING\x10\x02\x12\t\n\x05LOCAL\x10\x03\x42\x0e\x42\x0c\x44\x61teTimeType')
)



_DATETIME_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='rst.calendar.DateTime.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UTC', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FLOATING', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOCAL', index=2, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=179,
  serialized_end=219,
)
_sym_db.RegisterEnumDescriptor(_DATETIME_TYPE)


_DATETIME = _descriptor.Descriptor(
  name='DateTime',
  full_name='rst.calendar.DateTime',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='date_time_type', full_name='rst.calendar.DateTime.date_time_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timezone_id', full_name='rst.calendar.DateTime.timezone_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=_b("UTC").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='milliseconds_since_epoch', full_name='rst.calendar.DateTime.milliseconds_since_epoch', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _DATETIME_TYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=46,
  serialized_end=219,
)

_DATETIME.fields_by_name['date_time_type'].enum_type = _DATETIME_TYPE
_DATETIME_TYPE.containing_type = _DATETIME
DESCRIPTOR.message_types_by_name['DateTime'] = _DATETIME
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DateTime = _reflection.GeneratedProtocolMessageType('DateTime', (_message.Message,), dict(
  DESCRIPTOR = _DATETIME,
  __module__ = 'rst.calendar.DateTime_pb2'
  # @@protoc_insertion_point(class_scope:rst.calendar.DateTime)
  ))
_sym_db.RegisterMessage(DateTime)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\014DateTimeType'))
# @@protoc_insertion_point(module_scope)
