# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/bayesnetwork/BayesVariable.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/bayesnetwork/BayesVariable.proto',
  package='rst.bayesnetwork',
  syntax='proto2',
  serialized_pb=_b('\n$rst/bayesnetwork/BayesVariable.proto\x12\x10rst.bayesnetwork\"\xd0\x01\n\rBayesVariable\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x32\n\x04type\x18\x02 \x01(\x0e\x32$.rst.bayesnetwork.BayesVariable.Type\x12\x10\n\x08outcomes\x18\x03 \x03(\t\x12\x10\n\x08property\x18\x04 \x03(\t\x12\x0f\n\x07parents\x18\x05 \x03(\t\x12\x19\n\rprobabilities\x18\x06 \x03(\x01\x42\x02\x10\x01\"-\n\x04Type\x12\n\n\x06NATURE\x10\x01\x12\x0c\n\x08\x44\x45\x43ISION\x10\x02\x12\x0b\n\x07UTILITY\x10\x03\x42\x13\x42\x11\x42\x61yesVariableType')
)



_BAYESVARIABLE_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='rst.bayesnetwork.BayesVariable.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NATURE', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DECISION', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UTILITY', index=2, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=222,
  serialized_end=267,
)
_sym_db.RegisterEnumDescriptor(_BAYESVARIABLE_TYPE)


_BAYESVARIABLE = _descriptor.Descriptor(
  name='BayesVariable',
  full_name='rst.bayesnetwork.BayesVariable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='rst.bayesnetwork.BayesVariable.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='rst.bayesnetwork.BayesVariable.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='outcomes', full_name='rst.bayesnetwork.BayesVariable.outcomes', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='property', full_name='rst.bayesnetwork.BayesVariable.property', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='parents', full_name='rst.bayesnetwork.BayesVariable.parents', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='probabilities', full_name='rst.bayesnetwork.BayesVariable.probabilities', index=5,
      number=6, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _BAYESVARIABLE_TYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=59,
  serialized_end=267,
)

_BAYESVARIABLE.fields_by_name['type'].enum_type = _BAYESVARIABLE_TYPE
_BAYESVARIABLE_TYPE.containing_type = _BAYESVARIABLE
DESCRIPTOR.message_types_by_name['BayesVariable'] = _BAYESVARIABLE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BayesVariable = _reflection.GeneratedProtocolMessageType('BayesVariable', (_message.Message,), dict(
  DESCRIPTOR = _BAYESVARIABLE,
  __module__ = 'rst.bayesnetwork.BayesVariable_pb2'
  # @@protoc_insertion_point(class_scope:rst.bayesnetwork.BayesVariable)
  ))
_sym_db.RegisterMessage(BayesVariable)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\021BayesVariableType'))
_BAYESVARIABLE.fields_by_name['probabilities'].has_options = True
_BAYESVARIABLE.fields_by_name['probabilities']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))
# @@protoc_insertion_point(module_scope)
