# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/calendar/CalendarQueryResult.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.calendar import DateTime_pb2 as rst_dot_calendar_dot_DateTime__pb2
from rst.calendar import Event_pb2 as rst_dot_calendar_dot_Event__pb2
from rst.calendar import Todo_pb2 as rst_dot_calendar_dot_Todo__pb2
from rst.calendar import TimeZone_pb2 as rst_dot_calendar_dot_TimeZone__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/calendar/CalendarQueryResult.proto',
  package='rst.calendar',
  syntax='proto2',
  serialized_pb=_b('\n&rst/calendar/CalendarQueryResult.proto\x12\x0crst.calendar\x1a\x1brst/calendar/DateTime.proto\x1a\x18rst/calendar/Event.proto\x1a\x17rst/calendar/Todo.proto\x1a\x1brst/calendar/TimeZone.proto\"\xee\x02\n\x13\x43\x61lendarQueryResult\x12(\n\x08timezone\x18\x01 \x03(\x0b\x32\x16.rst.calendar.TimeZone\x12?\n\x05\x65vent\x18\x02 \x03(\x0b\x32\x30.rst.calendar.CalendarQueryResult.EventWithTimes\x12 \n\x04todo\x18\x03 \x03(\x0b\x32\x12.rst.calendar.Todo\x1aX\n\nTimePeriod\x12%\n\x05start\x18\x01 \x02(\x0b\x32\x16.rst.calendar.DateTime\x12#\n\x03\x65nd\x18\x02 \x02(\x0b\x32\x16.rst.calendar.DateTime\x1ap\n\x0e\x45ventWithTimes\x12\"\n\x05\x65vent\x18\x01 \x02(\x0b\x32\x13.rst.calendar.Event\x12:\n\x04time\x18\x02 \x03(\x0b\x32,.rst.calendar.CalendarQueryResult.TimePeriodB\x19\x42\x17\x43\x61lendarQueryResultType')
  ,
  dependencies=[rst_dot_calendar_dot_DateTime__pb2.DESCRIPTOR,rst_dot_calendar_dot_Event__pb2.DESCRIPTOR,rst_dot_calendar_dot_Todo__pb2.DESCRIPTOR,rst_dot_calendar_dot_TimeZone__pb2.DESCRIPTOR,])




_CALENDARQUERYRESULT_TIMEPERIOD = _descriptor.Descriptor(
  name='TimePeriod',
  full_name='rst.calendar.CalendarQueryResult.TimePeriod',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='rst.calendar.CalendarQueryResult.TimePeriod.start', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='end', full_name='rst.calendar.CalendarQueryResult.TimePeriod.end', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=330,
  serialized_end=418,
)

_CALENDARQUERYRESULT_EVENTWITHTIMES = _descriptor.Descriptor(
  name='EventWithTimes',
  full_name='rst.calendar.CalendarQueryResult.EventWithTimes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event', full_name='rst.calendar.CalendarQueryResult.EventWithTimes.event', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time', full_name='rst.calendar.CalendarQueryResult.EventWithTimes.time', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=420,
  serialized_end=532,
)

_CALENDARQUERYRESULT = _descriptor.Descriptor(
  name='CalendarQueryResult',
  full_name='rst.calendar.CalendarQueryResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timezone', full_name='rst.calendar.CalendarQueryResult.timezone', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='event', full_name='rst.calendar.CalendarQueryResult.event', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='todo', full_name='rst.calendar.CalendarQueryResult.todo', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CALENDARQUERYRESULT_TIMEPERIOD, _CALENDARQUERYRESULT_EVENTWITHTIMES, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=166,
  serialized_end=532,
)

_CALENDARQUERYRESULT_TIMEPERIOD.fields_by_name['start'].message_type = rst_dot_calendar_dot_DateTime__pb2._DATETIME
_CALENDARQUERYRESULT_TIMEPERIOD.fields_by_name['end'].message_type = rst_dot_calendar_dot_DateTime__pb2._DATETIME
_CALENDARQUERYRESULT_TIMEPERIOD.containing_type = _CALENDARQUERYRESULT
_CALENDARQUERYRESULT_EVENTWITHTIMES.fields_by_name['event'].message_type = rst_dot_calendar_dot_Event__pb2._EVENT
_CALENDARQUERYRESULT_EVENTWITHTIMES.fields_by_name['time'].message_type = _CALENDARQUERYRESULT_TIMEPERIOD
_CALENDARQUERYRESULT_EVENTWITHTIMES.containing_type = _CALENDARQUERYRESULT
_CALENDARQUERYRESULT.fields_by_name['timezone'].message_type = rst_dot_calendar_dot_TimeZone__pb2._TIMEZONE
_CALENDARQUERYRESULT.fields_by_name['event'].message_type = _CALENDARQUERYRESULT_EVENTWITHTIMES
_CALENDARQUERYRESULT.fields_by_name['todo'].message_type = rst_dot_calendar_dot_Todo__pb2._TODO
DESCRIPTOR.message_types_by_name['CalendarQueryResult'] = _CALENDARQUERYRESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CalendarQueryResult = _reflection.GeneratedProtocolMessageType('CalendarQueryResult', (_message.Message,), dict(

  TimePeriod = _reflection.GeneratedProtocolMessageType('TimePeriod', (_message.Message,), dict(
    DESCRIPTOR = _CALENDARQUERYRESULT_TIMEPERIOD,
    __module__ = 'rst.calendar.CalendarQueryResult_pb2'
    # @@protoc_insertion_point(class_scope:rst.calendar.CalendarQueryResult.TimePeriod)
    ))
  ,

  EventWithTimes = _reflection.GeneratedProtocolMessageType('EventWithTimes', (_message.Message,), dict(
    DESCRIPTOR = _CALENDARQUERYRESULT_EVENTWITHTIMES,
    __module__ = 'rst.calendar.CalendarQueryResult_pb2'
    # @@protoc_insertion_point(class_scope:rst.calendar.CalendarQueryResult.EventWithTimes)
    ))
  ,
  DESCRIPTOR = _CALENDARQUERYRESULT,
  __module__ = 'rst.calendar.CalendarQueryResult_pb2'
  # @@protoc_insertion_point(class_scope:rst.calendar.CalendarQueryResult)
  ))
_sym_db.RegisterMessage(CalendarQueryResult)
_sym_db.RegisterMessage(CalendarQueryResult.TimePeriod)
_sym_db.RegisterMessage(CalendarQueryResult.EventWithTimes)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\027CalendarQueryResultType'))
# @@protoc_insertion_point(module_scope)
