# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/vision/AugmentedPointCloud3DFloat.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.geometry import PointCloud3DFloat_pb2 as rst_dot_geometry_dot_PointCloud3DFloat__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/vision/AugmentedPointCloud3DFloat.proto',
  package='rst.vision',
  syntax='proto2',
  serialized_pb=_b('\n+rst/vision/AugmentedPointCloud3DFloat.proto\x12\nrst.vision\x1a$rst/geometry/PointCloud3DFloat.proto\"\xbc\x01\n\x1a\x41ugmentedPointCloud3DFloat\x12/\n\x06points\x18\x01 \x02(\x0b\x32\x1f.rst.geometry.PointCloud3DFloat\x12@\n\x08\x63hannels\x18\x02 \x03(\x0b\x32..rst.vision.AugmentedPointCloud3DFloat.Channel\x1a+\n\x07\x43hannel\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x12\n\x06values\x18\x02 \x03(\x02\x42\x02\x10\x01\x42 B\x1e\x41ugmentedPointCloud3DFloatType')
  ,
  dependencies=[rst_dot_geometry_dot_PointCloud3DFloat__pb2.DESCRIPTOR,])




_AUGMENTEDPOINTCLOUD3DFLOAT_CHANNEL = _descriptor.Descriptor(
  name='Channel',
  full_name='rst.vision.AugmentedPointCloud3DFloat.Channel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='rst.vision.AugmentedPointCloud3DFloat.Channel.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='values', full_name='rst.vision.AugmentedPointCloud3DFloat.Channel.values', index=1,
      number=2, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=243,
  serialized_end=286,
)

_AUGMENTEDPOINTCLOUD3DFLOAT = _descriptor.Descriptor(
  name='AugmentedPointCloud3DFloat',
  full_name='rst.vision.AugmentedPointCloud3DFloat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='points', full_name='rst.vision.AugmentedPointCloud3DFloat.points', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='channels', full_name='rst.vision.AugmentedPointCloud3DFloat.channels', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_AUGMENTEDPOINTCLOUD3DFLOAT_CHANNEL, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=98,
  serialized_end=286,
)

_AUGMENTEDPOINTCLOUD3DFLOAT_CHANNEL.containing_type = _AUGMENTEDPOINTCLOUD3DFLOAT
_AUGMENTEDPOINTCLOUD3DFLOAT.fields_by_name['points'].message_type = rst_dot_geometry_dot_PointCloud3DFloat__pb2._POINTCLOUD3DFLOAT
_AUGMENTEDPOINTCLOUD3DFLOAT.fields_by_name['channels'].message_type = _AUGMENTEDPOINTCLOUD3DFLOAT_CHANNEL
DESCRIPTOR.message_types_by_name['AugmentedPointCloud3DFloat'] = _AUGMENTEDPOINTCLOUD3DFLOAT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AugmentedPointCloud3DFloat = _reflection.GeneratedProtocolMessageType('AugmentedPointCloud3DFloat', (_message.Message,), dict(

  Channel = _reflection.GeneratedProtocolMessageType('Channel', (_message.Message,), dict(
    DESCRIPTOR = _AUGMENTEDPOINTCLOUD3DFLOAT_CHANNEL,
    __module__ = 'rst.vision.AugmentedPointCloud3DFloat_pb2'
    # @@protoc_insertion_point(class_scope:rst.vision.AugmentedPointCloud3DFloat.Channel)
    ))
  ,
  DESCRIPTOR = _AUGMENTEDPOINTCLOUD3DFLOAT,
  __module__ = 'rst.vision.AugmentedPointCloud3DFloat_pb2'
  # @@protoc_insertion_point(class_scope:rst.vision.AugmentedPointCloud3DFloat)
  ))
_sym_db.RegisterMessage(AugmentedPointCloud3DFloat)
_sym_db.RegisterMessage(AugmentedPointCloud3DFloat.Channel)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\036AugmentedPointCloud3DFloatType'))
_AUGMENTEDPOINTCLOUD3DFLOAT_CHANNEL.fields_by_name['values'].has_options = True
_AUGMENTEDPOINTCLOUD3DFLOAT_CHANNEL.fields_by_name['values']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))
# @@protoc_insertion_point(module_scope)
