# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/dynamics/Wrench.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.dynamics import Forces_pb2 as rst_dot_dynamics_dot_Forces__pb2
from rst.dynamics import Torques_pb2 as rst_dot_dynamics_dot_Torques__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/dynamics/Wrench.proto',
  package='rst.dynamics',
  syntax='proto2',
  serialized_pb=_b('\n\x19rst/dynamics/Wrench.proto\x12\x0crst.dynamics\x1a\x19rst/dynamics/Forces.proto\x1a\x1arst/dynamics/Torques.proto\"V\n\x06Wrench\x12$\n\x06\x66orces\x18\x01 \x02(\x0b\x32\x14.rst.dynamics.Forces\x12&\n\x07torques\x18\x02 \x02(\x0b\x32\x15.rst.dynamics.TorquesB\x0c\x42\nWrenchType')
  ,
  dependencies=[rst_dot_dynamics_dot_Forces__pb2.DESCRIPTOR,rst_dot_dynamics_dot_Torques__pb2.DESCRIPTOR,])




_WRENCH = _descriptor.Descriptor(
  name='Wrench',
  full_name='rst.dynamics.Wrench',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='forces', full_name='rst.dynamics.Wrench.forces', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='torques', full_name='rst.dynamics.Wrench.torques', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=98,
  serialized_end=184,
)

_WRENCH.fields_by_name['forces'].message_type = rst_dot_dynamics_dot_Forces__pb2._FORCES
_WRENCH.fields_by_name['torques'].message_type = rst_dot_dynamics_dot_Torques__pb2._TORQUES
DESCRIPTOR.message_types_by_name['Wrench'] = _WRENCH
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Wrench = _reflection.GeneratedProtocolMessageType('Wrench', (_message.Message,), dict(
  DESCRIPTOR = _WRENCH,
  __module__ = 'rst.dynamics.Wrench_pb2'
  # @@protoc_insertion_point(class_scope:rst.dynamics.Wrench)
  ))
_sym_db.RegisterMessage(Wrench)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\nWrenchType'))
# @@protoc_insertion_point(module_scope)
