# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/devices/generic/CpuState.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/devices/generic/CpuState.proto',
  package='rst.devices.generic',
  syntax='proto2',
  serialized_pb=_b('\n\"rst/devices/generic/CpuState.proto\x12\x13rst.devices.generic\"\xb2\x02\n\x08\x43puState\x12\x14\n\x0cjiffy_length\x18\n \x01(\r\x12/\n\x04\x63pus\x18\x14 \x03(\x0b\x32!.rst.devices.generic.CpuState.Cpu\x12\x0e\n\x06load_1\x18( \x01(\x02\x12\x0e\n\x06load_5\x18) \x01(\x02\x12\x0f\n\x07load_15\x18* \x01(\x02\x1a\xad\x01\n\x03\x43pu\x12\r\n\x05index\x18\x01 \x02(\x05\x12\r\n\x05total\x18\x64 \x02(\x04\x12\x0c\n\x04idle\x18\x05 \x02(\x04\x12\x0c\n\x04user\x18\x02 \x01(\x04\x12\x10\n\x08user_low\x18\x03 \x01(\x04\x12\x0e\n\x06system\x18\x04 \x01(\x04\x12\x0e\n\x06iowait\x18\x06 \x01(\x04\x12\x0b\n\x03irq\x18\x07 \x01(\x04\x12\x0f\n\x07softirq\x18\x08 \x01(\x04\x12\r\n\x05steal\x18\t \x01(\x04\x12\r\n\x05guest\x18\n \x01(\x04\x42\x0e\x42\x0c\x43puStateType')
)




_CPUSTATE_CPU = _descriptor.Descriptor(
  name='Cpu',
  full_name='rst.devices.generic.CpuState.Cpu',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='rst.devices.generic.CpuState.Cpu.index', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='total', full_name='rst.devices.generic.CpuState.Cpu.total', index=1,
      number=100, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='idle', full_name='rst.devices.generic.CpuState.Cpu.idle', index=2,
      number=5, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='user', full_name='rst.devices.generic.CpuState.Cpu.user', index=3,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='user_low', full_name='rst.devices.generic.CpuState.Cpu.user_low', index=4,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='system', full_name='rst.devices.generic.CpuState.Cpu.system', index=5,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='iowait', full_name='rst.devices.generic.CpuState.Cpu.iowait', index=6,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='irq', full_name='rst.devices.generic.CpuState.Cpu.irq', index=7,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='softirq', full_name='rst.devices.generic.CpuState.Cpu.softirq', index=8,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='steal', full_name='rst.devices.generic.CpuState.Cpu.steal', index=9,
      number=9, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='guest', full_name='rst.devices.generic.CpuState.Cpu.guest', index=10,
      number=10, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=193,
  serialized_end=366,
)

_CPUSTATE = _descriptor.Descriptor(
  name='CpuState',
  full_name='rst.devices.generic.CpuState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='jiffy_length', full_name='rst.devices.generic.CpuState.jiffy_length', index=0,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cpus', full_name='rst.devices.generic.CpuState.cpus', index=1,
      number=20, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='load_1', full_name='rst.devices.generic.CpuState.load_1', index=2,
      number=40, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='load_5', full_name='rst.devices.generic.CpuState.load_5', index=3,
      number=41, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='load_15', full_name='rst.devices.generic.CpuState.load_15', index=4,
      number=42, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CPUSTATE_CPU, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=60,
  serialized_end=366,
)

_CPUSTATE_CPU.containing_type = _CPUSTATE
_CPUSTATE.fields_by_name['cpus'].message_type = _CPUSTATE_CPU
DESCRIPTOR.message_types_by_name['CpuState'] = _CPUSTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CpuState = _reflection.GeneratedProtocolMessageType('CpuState', (_message.Message,), dict(

  Cpu = _reflection.GeneratedProtocolMessageType('Cpu', (_message.Message,), dict(
    DESCRIPTOR = _CPUSTATE_CPU,
    __module__ = 'rst.devices.generic.CpuState_pb2'
    # @@protoc_insertion_point(class_scope:rst.devices.generic.CpuState.Cpu)
    ))
  ,
  DESCRIPTOR = _CPUSTATE,
  __module__ = 'rst.devices.generic.CpuState_pb2'
  # @@protoc_insertion_point(class_scope:rst.devices.generic.CpuState)
  ))
_sym_db.RegisterMessage(CpuState)
_sym_db.RegisterMessage(CpuState.Cpu)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\014CpuStateType'))
# @@protoc_insertion_point(module_scope)
