# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/geometry/TriangleMesh3DFloat.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.geometry import PointCloud3DFloat_pb2 as rst_dot_geometry_dot_PointCloud3DFloat__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/geometry/TriangleMesh3DFloat.proto',
  package='rst.geometry',
  syntax='proto2',
  serialized_pb=_b('\n&rst/geometry/TriangleMesh3DFloat.proto\x12\x0crst.geometry\x1a$rst/geometry/PointCloud3DFloat.proto\"\xc3\x01\n\x13TriangleMesh3DFloat\x12\x31\n\x08vertices\x18\x01 \x02(\x0b\x32\x1f.rst.geometry.PointCloud3DFloat\x12=\n\ttriangles\x18\x02 \x03(\x0b\x32*.rst.geometry.TriangleMesh3DFloat.Triangle\x1a:\n\x08Triangle\x12\x0e\n\x06point1\x18\x01 \x02(\r\x12\x0e\n\x06point2\x18\x02 \x02(\r\x12\x0e\n\x06point3\x18\x03 \x02(\rB\x19\x42\x17TriangleMesh3DFloatType')
  ,
  dependencies=[rst_dot_geometry_dot_PointCloud3DFloat__pb2.DESCRIPTOR,])




_TRIANGLEMESH3DFLOAT_TRIANGLE = _descriptor.Descriptor(
  name='Triangle',
  full_name='rst.geometry.TriangleMesh3DFloat.Triangle',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='point1', full_name='rst.geometry.TriangleMesh3DFloat.Triangle.point1', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='point2', full_name='rst.geometry.TriangleMesh3DFloat.Triangle.point2', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='point3', full_name='rst.geometry.TriangleMesh3DFloat.Triangle.point3', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=232,
  serialized_end=290,
)

_TRIANGLEMESH3DFLOAT = _descriptor.Descriptor(
  name='TriangleMesh3DFloat',
  full_name='rst.geometry.TriangleMesh3DFloat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='vertices', full_name='rst.geometry.TriangleMesh3DFloat.vertices', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='triangles', full_name='rst.geometry.TriangleMesh3DFloat.triangles', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_TRIANGLEMESH3DFLOAT_TRIANGLE, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=95,
  serialized_end=290,
)

_TRIANGLEMESH3DFLOAT_TRIANGLE.containing_type = _TRIANGLEMESH3DFLOAT
_TRIANGLEMESH3DFLOAT.fields_by_name['vertices'].message_type = rst_dot_geometry_dot_PointCloud3DFloat__pb2._POINTCLOUD3DFLOAT
_TRIANGLEMESH3DFLOAT.fields_by_name['triangles'].message_type = _TRIANGLEMESH3DFLOAT_TRIANGLE
DESCRIPTOR.message_types_by_name['TriangleMesh3DFloat'] = _TRIANGLEMESH3DFLOAT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TriangleMesh3DFloat = _reflection.GeneratedProtocolMessageType('TriangleMesh3DFloat', (_message.Message,), dict(

  Triangle = _reflection.GeneratedProtocolMessageType('Triangle', (_message.Message,), dict(
    DESCRIPTOR = _TRIANGLEMESH3DFLOAT_TRIANGLE,
    __module__ = 'rst.geometry.TriangleMesh3DFloat_pb2'
    # @@protoc_insertion_point(class_scope:rst.geometry.TriangleMesh3DFloat.Triangle)
    ))
  ,
  DESCRIPTOR = _TRIANGLEMESH3DFLOAT,
  __module__ = 'rst.geometry.TriangleMesh3DFloat_pb2'
  # @@protoc_insertion_point(class_scope:rst.geometry.TriangleMesh3DFloat)
  ))
_sym_db.RegisterMessage(TriangleMesh3DFloat)
_sym_db.RegisterMessage(TriangleMesh3DFloat.Triangle)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\027TriangleMesh3DFloatType'))
# @@protoc_insertion_point(module_scope)
