# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/devices/generic/HostInformation.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.devices.generic import MemoryState_pb2 as rst_dot_devices_dot_generic_dot_MemoryState__pb2
from rst.devices.generic import CpuState_pb2 as rst_dot_devices_dot_generic_dot_CpuState__pb2
from rst.devices.generic import DiskState_pb2 as rst_dot_devices_dot_generic_dot_DiskState__pb2
from rst.devices.generic import NetworkState_pb2 as rst_dot_devices_dot_generic_dot_NetworkState__pb2
from rst.devices.generic import UserState_pb2 as rst_dot_devices_dot_generic_dot_UserState__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/devices/generic/HostInformation.proto',
  package='rst.devices.generic',
  syntax='proto2',
  serialized_pb=_b('\n)rst/devices/generic/HostInformation.proto\x12\x13rst.devices.generic\x1a%rst/devices/generic/MemoryState.proto\x1a\"rst/devices/generic/CpuState.proto\x1a#rst/devices/generic/DiskState.proto\x1a&rst/devices/generic/NetworkState.proto\x1a#rst/devices/generic/UserState.proto\"\xc4\x02\n\x0fHostInformation\x12\x10\n\x08hostname\x18\x01 \x01(\t\x12\x36\n\x0cmemory_state\x18\x02 \x01(\x0b\x32 .rst.devices.generic.MemoryState\x12\x30\n\tcpu_state\x18\x03 \x01(\x0b\x32\x1d.rst.devices.generic.CpuState\x12\x13\n\x0bprocess_num\x18\x04 \x01(\x04\x12\x32\n\ndisk_state\x18\x05 \x01(\x0b\x32\x1e.rst.devices.generic.DiskState\x12\x38\n\rnetwork_state\x18\x06 \x01(\x0b\x32!.rst.devices.generic.NetworkState\x12\x32\n\nuser_state\x18\x07 \x01(\x0b\x32\x1e.rst.devices.generic.UserStateB\x15\x42\x13HostInformationType')
  ,
  dependencies=[rst_dot_devices_dot_generic_dot_MemoryState__pb2.DESCRIPTOR,rst_dot_devices_dot_generic_dot_CpuState__pb2.DESCRIPTOR,rst_dot_devices_dot_generic_dot_DiskState__pb2.DESCRIPTOR,rst_dot_devices_dot_generic_dot_NetworkState__pb2.DESCRIPTOR,rst_dot_devices_dot_generic_dot_UserState__pb2.DESCRIPTOR,])




_HOSTINFORMATION = _descriptor.Descriptor(
  name='HostInformation',
  full_name='rst.devices.generic.HostInformation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hostname', full_name='rst.devices.generic.HostInformation.hostname', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='memory_state', full_name='rst.devices.generic.HostInformation.memory_state', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cpu_state', full_name='rst.devices.generic.HostInformation.cpu_state', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='process_num', full_name='rst.devices.generic.HostInformation.process_num', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='disk_state', full_name='rst.devices.generic.HostInformation.disk_state', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='network_state', full_name='rst.devices.generic.HostInformation.network_state', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='user_state', full_name='rst.devices.generic.HostInformation.user_state', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=256,
  serialized_end=580,
)

_HOSTINFORMATION.fields_by_name['memory_state'].message_type = rst_dot_devices_dot_generic_dot_MemoryState__pb2._MEMORYSTATE
_HOSTINFORMATION.fields_by_name['cpu_state'].message_type = rst_dot_devices_dot_generic_dot_CpuState__pb2._CPUSTATE
_HOSTINFORMATION.fields_by_name['disk_state'].message_type = rst_dot_devices_dot_generic_dot_DiskState__pb2._DISKSTATE
_HOSTINFORMATION.fields_by_name['network_state'].message_type = rst_dot_devices_dot_generic_dot_NetworkState__pb2._NETWORKSTATE
_HOSTINFORMATION.fields_by_name['user_state'].message_type = rst_dot_devices_dot_generic_dot_UserState__pb2._USERSTATE
DESCRIPTOR.message_types_by_name['HostInformation'] = _HOSTINFORMATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

HostInformation = _reflection.GeneratedProtocolMessageType('HostInformation', (_message.Message,), dict(
  DESCRIPTOR = _HOSTINFORMATION,
  __module__ = 'rst.devices.generic.HostInformation_pb2'
  # @@protoc_insertion_point(class_scope:rst.devices.generic.HostInformation)
  ))
_sym_db.RegisterMessage(HostInformation)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\023HostInformationType'))
# @@protoc_insertion_point(module_scope)
