# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/calendar/RecurrenceId.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.calendar import DateTime_pb2 as rst_dot_calendar_dot_DateTime__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/calendar/RecurrenceId.proto',
  package='rst.calendar',
  syntax='proto2',
  serialized_pb=_b('\n\x1frst/calendar/RecurrenceId.proto\x12\x0crst.calendar\x1a\x1brst/calendar/DateTime.proto\"\x85\x02\n\x0cRecurrenceId\x12\x38\n\x04type\x18\x01 \x01(\x0e\x32\x1f.rst.calendar.RecurrenceId.Type:\tDATE_TIME\x12\x37\n\x05range\x18\x02 \x01(\x0e\x32 .rst.calendar.RecurrenceId.Range:\x06SINGLE\x12#\n\x03rid\x18\x03 \x01(\x0b\x32\x16.rst.calendar.DateTime\"\x1f\n\x04Type\x12\r\n\tDATE_TIME\x10\x01\x12\x08\n\x04\x44\x41TE\x10\x02\"<\n\x05Range\x12\n\n\x06SINGLE\x10\x01\x12\x13\n\x0fTHIS_AND_FUTURE\x10\x02\x12\x12\n\x0eTHIS_AND_PRIOR\x10\x03\x42\x12\x42\x10RecurrenceIdType')
  ,
  dependencies=[rst_dot_calendar_dot_DateTime__pb2.DESCRIPTOR,])



_RECURRENCEID_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='rst.calendar.RecurrenceId.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DATE_TIME', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DATE', index=1, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=247,
  serialized_end=278,
)
_sym_db.RegisterEnumDescriptor(_RECURRENCEID_TYPE)

_RECURRENCEID_RANGE = _descriptor.EnumDescriptor(
  name='Range',
  full_name='rst.calendar.RecurrenceId.Range',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SINGLE', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='THIS_AND_FUTURE', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='THIS_AND_PRIOR', index=2, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=280,
  serialized_end=340,
)
_sym_db.RegisterEnumDescriptor(_RECURRENCEID_RANGE)


_RECURRENCEID = _descriptor.Descriptor(
  name='RecurrenceId',
  full_name='rst.calendar.RecurrenceId',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='rst.calendar.RecurrenceId.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='range', full_name='rst.calendar.RecurrenceId.range', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rid', full_name='rst.calendar.RecurrenceId.rid', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _RECURRENCEID_TYPE,
    _RECURRENCEID_RANGE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=79,
  serialized_end=340,
)

_RECURRENCEID.fields_by_name['type'].enum_type = _RECURRENCEID_TYPE
_RECURRENCEID.fields_by_name['range'].enum_type = _RECURRENCEID_RANGE
_RECURRENCEID.fields_by_name['rid'].message_type = rst_dot_calendar_dot_DateTime__pb2._DATETIME
_RECURRENCEID_TYPE.containing_type = _RECURRENCEID
_RECURRENCEID_RANGE.containing_type = _RECURRENCEID
DESCRIPTOR.message_types_by_name['RecurrenceId'] = _RECURRENCEID
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RecurrenceId = _reflection.GeneratedProtocolMessageType('RecurrenceId', (_message.Message,), dict(
  DESCRIPTOR = _RECURRENCEID,
  __module__ = 'rst.calendar.RecurrenceId_pb2'
  # @@protoc_insertion_point(class_scope:rst.calendar.RecurrenceId)
  ))
_sym_db.RegisterMessage(RecurrenceId)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\020RecurrenceIdType'))
# @@protoc_insertion_point(module_scope)
