# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/animation/HeadAnimation.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/animation/HeadAnimation.proto',
  package='rst.animation',
  syntax='proto2',
  serialized_pb=_b('\n!rst/animation/HeadAnimation.proto\x12\rrst.animation\"\xd7\x02\n\rHeadAnimation\x12\x39\n\tanimation\x18\x01 \x02(\x0e\x32&.rst.animation.HeadAnimation.Animation\x12\x16\n\x0brepetitions\x18\x02 \x02(\r:\x01\x31\x12\x15\n\rduration_each\x18\x03 \x02(\r\x12\x19\n\x0e\x65mphasis_scale\x18\x04 \x02(\x02:\x01\x31\"\xc0\x01\n\tAnimation\x12\x08\n\x04IDLE\x10\x00\x12\x0c\n\x08HEAD_NOD\x10\x01\x12\x0e\n\nHEAD_SHAKE\x10\x02\x12\x11\n\rEYEBLINK_LEFT\x10\x03\x12\x12\n\x0e\x45YEBLINK_RIGHT\x10\x04\x12\x11\n\rEYEBLINK_BOTH\x10\x05\x12\x12\n\x0e\x45YEBROWS_RAISE\x10\x06\x12\x12\n\x0e\x45YEBROWS_LOWER\x10\x07\x12\x13\n\x0f\x45NGAGEMENT_LEFT\x10\x08\x12\x14\n\x10\x45NGAGEMENT_RIGHT\x10\tB\x13\x42\x11HeadAnimationType')
)



_HEADANIMATION_ANIMATION = _descriptor.EnumDescriptor(
  name='Animation',
  full_name='rst.animation.HeadAnimation.Animation',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='IDLE', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HEAD_NOD', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HEAD_SHAKE', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EYEBLINK_LEFT', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EYEBLINK_RIGHT', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EYEBLINK_BOTH', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EYEBROWS_RAISE', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EYEBROWS_LOWER', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ENGAGEMENT_LEFT', index=8, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ENGAGEMENT_RIGHT', index=9, number=9,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=204,
  serialized_end=396,
)
_sym_db.RegisterEnumDescriptor(_HEADANIMATION_ANIMATION)


_HEADANIMATION = _descriptor.Descriptor(
  name='HeadAnimation',
  full_name='rst.animation.HeadAnimation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='animation', full_name='rst.animation.HeadAnimation.animation', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='repetitions', full_name='rst.animation.HeadAnimation.repetitions', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='duration_each', full_name='rst.animation.HeadAnimation.duration_each', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='emphasis_scale', full_name='rst.animation.HeadAnimation.emphasis_scale', index=3,
      number=4, type=2, cpp_type=6, label=2,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _HEADANIMATION_ANIMATION,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=53,
  serialized_end=396,
)

_HEADANIMATION.fields_by_name['animation'].enum_type = _HEADANIMATION_ANIMATION
_HEADANIMATION_ANIMATION.containing_type = _HEADANIMATION
DESCRIPTOR.message_types_by_name['HeadAnimation'] = _HEADANIMATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

HeadAnimation = _reflection.GeneratedProtocolMessageType('HeadAnimation', (_message.Message,), dict(
  DESCRIPTOR = _HEADANIMATION,
  __module__ = 'rst.animation.HeadAnimation_pb2'
  # @@protoc_insertion_point(class_scope:rst.animation.HeadAnimation)
  ))
_sym_db.RegisterMessage(HeadAnimation)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\021HeadAnimationType'))
# @@protoc_insertion_point(module_scope)
