# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/animation/BinocularHeadGaze.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.geometry import SphericalDirectionFloat_pb2 as rst_dot_geometry_dot_SphericalDirectionFloat__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/animation/BinocularHeadGaze.proto',
  package='rst.animation',
  syntax='proto2',
  serialized_pb=_b('\n%rst/animation/BinocularHeadGaze.proto\x12\rrst.animation\x1a*rst/geometry/SphericalDirectionFloat.proto\"\x9a\x01\n\x11\x42inocularHeadGaze\x12\x35\n\x06target\x18\x01 \x02(\x0b\x32%.rst.geometry.SphericalDirectionFloat\x12\x17\n\x0c\x65ye_vergence\x18\x02 \x02(\x02:\x01\x30\x12\x35\n\x06offset\x18\x03 \x02(\x0b\x32%.rst.geometry.SphericalDirectionFloatB\x17\x42\x15\x42inocularHeadGazeType')
  ,
  dependencies=[rst_dot_geometry_dot_SphericalDirectionFloat__pb2.DESCRIPTOR,])




_BINOCULARHEADGAZE = _descriptor.Descriptor(
  name='BinocularHeadGaze',
  full_name='rst.animation.BinocularHeadGaze',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='target', full_name='rst.animation.BinocularHeadGaze.target', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='eye_vergence', full_name='rst.animation.BinocularHeadGaze.eye_vergence', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='offset', full_name='rst.animation.BinocularHeadGaze.offset', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=101,
  serialized_end=255,
)

_BINOCULARHEADGAZE.fields_by_name['target'].message_type = rst_dot_geometry_dot_SphericalDirectionFloat__pb2._SPHERICALDIRECTIONFLOAT
_BINOCULARHEADGAZE.fields_by_name['offset'].message_type = rst_dot_geometry_dot_SphericalDirectionFloat__pb2._SPHERICALDIRECTIONFLOAT
DESCRIPTOR.message_types_by_name['BinocularHeadGaze'] = _BINOCULARHEADGAZE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BinocularHeadGaze = _reflection.GeneratedProtocolMessageType('BinocularHeadGaze', (_message.Message,), dict(
  DESCRIPTOR = _BINOCULARHEADGAZE,
  __module__ = 'rst.animation.BinocularHeadGaze_pb2'
  # @@protoc_insertion_point(class_scope:rst.animation.BinocularHeadGaze)
  ))
_sym_db.RegisterMessage(BinocularHeadGaze)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\025BinocularHeadGazeType'))
# @@protoc_insertion_point(module_scope)
