# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/geometry/BoundingBox.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.math import Vec2DInt_pb2 as rst_dot_math_dot_Vec2DInt__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/geometry/BoundingBox.proto',
  package='rst.geometry',
  syntax='proto2',
  serialized_pb=_b('\n\x1erst/geometry/BoundingBox.proto\x12\x0crst.geometry\x1a\x17rst/math/Vec2DInt.proto\"}\n\x0b\x42oundingBox\x12$\n\x08top_left\x18\x01 \x02(\x0b\x32\x12.rst.math.Vec2DInt\x12\r\n\x05width\x18\x02 \x02(\r\x12\x0e\n\x06height\x18\x03 \x02(\r\x12\x13\n\x0bimage_width\x18\x04 \x01(\r\x12\x14\n\x0cimage_height\x18\x05 \x01(\rB\x11\x42\x0f\x42oundingBoxType')
  ,
  dependencies=[rst_dot_math_dot_Vec2DInt__pb2.DESCRIPTOR,])




_BOUNDINGBOX = _descriptor.Descriptor(
  name='BoundingBox',
  full_name='rst.geometry.BoundingBox',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='top_left', full_name='rst.geometry.BoundingBox.top_left', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='width', full_name='rst.geometry.BoundingBox.width', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='height', full_name='rst.geometry.BoundingBox.height', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='image_width', full_name='rst.geometry.BoundingBox.image_width', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='image_height', full_name='rst.geometry.BoundingBox.image_height', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=73,
  serialized_end=198,
)

_BOUNDINGBOX.fields_by_name['top_left'].message_type = rst_dot_math_dot_Vec2DInt__pb2._VEC2DINT
DESCRIPTOR.message_types_by_name['BoundingBox'] = _BOUNDINGBOX
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BoundingBox = _reflection.GeneratedProtocolMessageType('BoundingBox', (_message.Message,), dict(
  DESCRIPTOR = _BOUNDINGBOX,
  __module__ = 'rst.geometry.BoundingBox_pb2'
  # @@protoc_insertion_point(class_scope:rst.geometry.BoundingBox)
  ))
_sym_db.RegisterMessage(BoundingBox)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\017BoundingBoxType'))
# @@protoc_insertion_point(module_scope)
